@@ -9,4 +9,7 @@
 #undef HAVE_GDK_IMLIB
 #undef HAVE_SESSION
 #undef HAVE_GDK_PIXBUF
+#undef GTK_ENGINE_DIR
 #undef DMALLOC
+#undef HAVE_GETHOSTNAME_PROTO
+#undef OLD_STYLE
