@@ -15,6 +15,10 @@
 #include <X11/Xatom.h>
 #include <X11/Xutil.h>
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 Atom _XA_WM_PROTOCOLS = None;
 
 void
