@@ -5,6 +5,10 @@
 
 #include <X11/Xlib.h>
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 static int xgrabcount = 0;
 
 void
