@@ -11,6 +11,10 @@
 
 #include "utils.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 /************************************************************************
  *
  * Concatentates 3 strings
