@@ -32,6 +32,10 @@
 #define FD_SETSIZE 2048
 #endif
 
+#ifndef HAVE_GETHOSTNAME_PROTO
+extern int gethostname (char *, int);
+#endif
+
 int
 GetFdWidth (void)
 {
