@@ -1,5 +1,4 @@
-static char *empty[] =
-{
+static char *empty[] = {
   "2 2 1 1",
   ". c none",
   "..",
