@@ -22,6 +22,10 @@
 
 #include "utils.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 #ifndef NULL
 #define NULL 0
 #endif
