@@ -24,8 +24,10 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <string.h>
+#include <signal.h>
 #include <sys/time.h>
 #include <sys/stat.h>
+#include <sys/wait.h>
 #include "constant.h"
 #include "sendinfo.h"
 #include "my_string.h"
@@ -34,6 +36,8 @@
 #  include "dmalloc.h"
 #endif
 
+static  int diag [2] = { -1, -1 };
+
 int
 existfile (const char *s)
 {
@@ -58,11 +62,25 @@ my_sleep (int n)
     }
 }
 
+int initdiag (void)
+{
+  if (diag[0] == -1)
+    {
+      pipe (diag);
+      /*
+      fcntl (diag[0], F_SETFL, O_NONBLOCK);
+      fcntl (diag[1], F_SETFL, O_NONBLOCK);
+       */
+    }
+  return (diag [0]);
+}
+
 void
 exec_comm (char *comm, int wm)
 {
   char *command;
   char *toexec;
+  int nulldev;
 
   command = (char *) malloc ((MAXSTRLEN + 1) * sizeof (char));
   if (comm)
@@ -103,10 +121,22 @@ exec_comm (char *comm, int wm)
 	      switch (fork ())
 		{
 		case 0:
+                  /* The following is to avoid X locking when executing 
+                     terminal based application that requires user input */
+                  if ((nulldev = open ("/dev/null", O_RDWR)))
+                    {
+                      close (0); dup (nulldev);
+                    }
+                  if ((diag [0] != -1) && (diag [1] != -1))
+                    {
+                      close (1); dup (diag [1]);
+                      close (2); dup (diag [1]);
+                      close (diag [0]);
+                      close (diag [1]);
+                    }
 		  execl (DEFAULT_SHELL, DEFAULT_SHELL, "-c", command, NULL);
-		  perror ("XFce");
-		  break;
-		  exit (-1);
+		  perror ("exec failed");
+		  _exit (0);
 		  break;
 		case -1:
 		  fprintf (stderr, "XFce : cannot execute fork()\n");
