@@ -67,6 +67,9 @@ gnome_change_desk (int desk)
 void
 gnome_set_desk_count (int desk)
 {
+  if (desk <= 0)
+    desk = 1;
+    
   if (!_XA_WIN_WORKSPACE_COUNT)
     create_gnome_atoms ();
 
