@@ -22,16 +22,21 @@
 #include <ctype.h>
 #include "my_string.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 char buffer[512];
 char hexnum[] =
-{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
+  { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e',
+    'f' };
 
 char *
 skiphead (char *s)
 {
   char *res = s;
   if (res)
-    while (((isspace(*res)) || (iscntrl(*res))) && (*res != 0))
+    while (((isspace (*res)) || (iscntrl (*res))) && (*res != 0))
       res++;
   return (res);
 }
@@ -43,9 +48,9 @@ nextl (char *s)
   static char *blank = " ";
 
   if (s)
-  {
-    strncpy (buffer, s, 512);
-  }
+    {
+      strncpy (buffer, s, 512);
+    }
   res = strtok (s ? buffer : NULL, "\n");
   return (res ? res : blank);
 }
@@ -60,8 +65,9 @@ skiptail (char *s)
       i = 0;
       j = strlen (s);
       res = (char *) (s + (strlen (s) - 1) * sizeof (char));
-      while (((isspace(*res)) || (iscntrl(*res)) || (*res == '&')) && (i++ < j))
-        res--;
+      while (((isspace (*res)) || (iscntrl (*res)) || (*res == '&'))
+	     && (i++ < j))
+	res--;
       *(++res) = 0;
     }
   return (s);
@@ -79,13 +85,13 @@ cleanup (char *s)
   return (t);
 }
 
-char 
+char
 my_casecmp (char a, char b)
 {
   return (((a == b) || (a == toupper (b)) || (toupper (a) == b)));
 }
 
-char 
+char
 my_strncasecmp (char *a, char *b, int n)
 {
   char *p1, *p2;
@@ -96,57 +102,61 @@ my_strncasecmp (char *a, char *b, int n)
     return (1);
   for (;;)
     {
-      if (!n) {
-	return (0); }
-      if (!my_casecmp (*p1, *p2)) {
-	return (*p1 - *p2); }
+      if (!n)
+	{
+	  return (0);
+	}
+      if (!my_casecmp (*p1, *p2))
+	{
+	  return (*p1 - *p2);
+	}
       p1++;
       p2++;
       n--;
     }
 }
 
-char 
+char
 my_strcasecmp (char *a, char *b)
 {
   int x, y, min;
-  
+
   if (!a || !b)
     return (1);
-  x    = strlen (a); 
-  y    = strlen (b);
-  min  = ((x < y) ? x : y);
+  x = strlen (a);
+  y = strlen (b);
+  min = ((x < y) ? x : y);
   return (my_strncasecmp (a, b, min));
 }
 
 char *
-tohex(char *s, short int n)
+tohex (char *s, short int n)
 {
-   if (s)
-   {
+  if (s)
+    {
       s[0] = hexnum[(n / 16)];
       s[1] = hexnum[(n % 16)];
       s[2] = '\0';
-   }
-   return (s);
+    }
+  return (s);
 }
 
 char *
-my_strrchr(char *s, char c)
+my_strrchr (char *s, char c)
 {
   char *p1, *p2;
-  
-  if (!s) 
+
+  if (!s)
     return (NULL);
   if (!(*s))
     return (s);
   p1 = p2 = s;
-  for (;;) {
-    if (*p1++ == c)
-      p2 = p1;
-    if (!(*p1))
-      return (p2);
-  }
+  for (;;)
+    {
+      if (*p1++ == c)
+	p2 = p1;
+      if (!(*p1))
+	return (p2);
+    }
   return (s);
 }
-  
