@@ -28,31 +28,38 @@
 #include <glib.h>
 #include "constant.h"
 
-static GList    *tooltips = NULL;
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
 
-GtkTooltips*     
+static GList *tooltips = NULL;
+
+GtkTooltips *
 my_tooltips_new (guint delay)
 {
-  GtkTooltips* res = gtk_tooltips_new();
+  GtkTooltips *res = gtk_tooltips_new ();
+
+  gtk_tooltips_set_delay (res, delay);
 
-  gtk_tooltips_set_delay(res, delay);
- 
   tooltips = g_list_append (tooltips, (gpointer) res);
-  
+
   return res;
 }
 
-void update_delay_tooltips(guint delay)
+void
+update_delay_tooltips (guint delay)
 {
   GList *tmp;
   tmp = tooltips;
-  while (tmp) {
-    gtk_tooltips_set_delay(GTK_TOOLTIPS(tmp->data), delay);
-    tmp = tmp->next;
-  }
+  while (tmp)
+    {
+      gtk_tooltips_set_delay (GTK_TOOLTIPS (tmp->data), delay);
+      tmp = tmp->next;
+    }
 }
 
-void free_tooltips_list(void)
+void
+free_tooltips_list (void)
 {
   g_list_free (tooltips);
 }
