@@ -3,6 +3,10 @@
 #include <stdlib.h>
 #include <stdio.h>
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 /***********************************************************************
  *
  *  Procedure:
