@@ -36,6 +36,7 @@
 #include "xfce-common.h"
 #include "my_string.h"
 #include "gnome_protocol.h"
+#include "xpmext.h"
 #include "constant.h"
 
 #ifndef HAVE_SNPRINTF
@@ -46,80 +47,90 @@
 #  include "dmalloc.h"
 #endif
 
+#ifdef HAVE_GDK_IMLIB
+#include <gdk_imlib.h>
+#endif
+
 static char *question[] = {
-  "    32    32        2            1",
-  ". s mask  c none",
-  "# c #000000",
-  "................................",
-  "................................",
-  "................................",
-  "................................",
-  "................................",
-  ".........##########.............",
-  "........##.#.#.#.#.#............",
-  ".......##.#.#.#.#.#.#...........",
-  "......##.#.#######.#.#..........",
-  "......#.#.###########.#.........",
-  "......##.###########.#..........",
-  "......#.#.###.#.#####.#.........",
-  "......##.#####.#####.#.#........",
-  "......#.#.###.#.#####.#.#.......",
-  "......##.#.#.#.#####.#.#.#......",
-  "......#.#.#.#.#####.#.#.........",
-  "......##.#.#.#####.#.#..........",
-  ".......##.#.#####.#.#.#.........",
-  "........##.#.###.#.#.#..........",
-  ".........##.#####.#.#...........",
-  "..........##.#.#.#.#.#..........",
-  "..........#.#.#.#.#.#...........",
-  "..........##.###.#..............",
-  "..........#.#####.#.............",
-  "..........##.###.#..............",
-  ".........##.#.#.#.#.............",
-  ".........#.#.#.#.#.#............",
-  "................................",
-  "................................",
-  "................................",
-  "................................",
-  "................................"
+"32 32 5 1",
+". c none",
+"# c #183c59",
+"a c #bebebe",
+"b c #ffffff",
+"c c #0000ff",
+"................................",
+"................................",
+"................................",
+"................................",
+"................................",
+".........##########.............",
+"........##aaaaaaaaab............",
+".......##aaaaccccaaab...........",
+"......##aaaccccccccaab..........",
+"......#aaaccccccccccaab.........",
+"......#aaaccccccccccaab.........",
+"......#aaacccaaaacccaab.........",
+"......#aaacccaaaacccaaab........",
+"......#aaacccaaaccccaaaab.......",
+"......#aaaaaaaacccccaaabb.......",
+"......#aaaaaaacccccaaab.........",
+"......##aaaaacccccaaabb.........",
+".......##aaaaccccaaaab..........",
+"........##aaacccaaaaab..........",
+".........##aacccaaaaab..........",
+"..........#aaaaaaaaaab..........",
+"..........#aaaaaaabbb...........",
+"..........#aacccaab.............",
+"..........#aacccaab.............",
+"..........#aacccaab.............",
+".........##aaaaaaab.............",
+".........#bbbbbbbbbb............",
+"................................",
+"................................",
+"................................",
+"................................",
+"................................"
 };
 
 static char *warning[] = {
-  "    32    32        2            1",
-  ". s mask  c none",
-  "# c #000000",
-  "................................",
-  "................................",
-  "................................",
-  "................................",
-  "................................",
-  ".........##########.............",
-  "........##.#.#.#.#.#............",
-  ".......##.#.#.#.#.#.#...........",
-  "......##.#.#.###.#.#.#..........",
-  "......#.#.#.#####.#.#.#.........",
-  "......##.#.#######.#.#..........",
-  "......#.#.#.#####.#.#.#.........",
-  "......##.#.#######.###.#........",
-  "......#.#.#.#####.#.#.#.#.......",
-  "......##.#.#.###.#.#.#.#.#......",
-  "......#.#.#.#####.#.#.#.........",
-  "......##.#.#.###.#.#.#..........",
-  ".......##.#.#####.#.#.#.........",
-  "........##.#.###.#.#.#..........",
-  ".........##.#####.#.#...........",
-  "..........##.#.#.#.#.#..........",
-  "..........#.#.#.#.#.#...........",
-  "..........##.###.#..............",
-  "..........#.#####.#.............",
-  "..........##.###.#..............",
-  ".........##.#.#.#.#.............",
-  ".........#.#.#.#.#.#............",
-  "................................",
-  "................................",
-  "................................",
-  "................................",
-  "................................"
+"32 32 5 1",
+". c none",
+"# c #183c59",
+"a c #bebebe",
+"b c #ffffff",
+"c c #ff0000",
+"................................",
+"................................",
+"................................",
+"................................",
+"................................",
+".........##########.............",
+"........##aaaaaaaaab............",
+".......##aaaaacaaaaab...........",
+"......##aaaaacccaaaaab..........",
+"......#aaaaacccccaaaaab.........",
+"......#aaaaacccccaaaaab.........",
+"......#aaaaacccccaaa#ab.........",
+"......#aaaaacccccaa##aab........",
+"......#aaaaacccccaaa#aaab.......",
+"......#aaaaaacccaaaaaaabb.......",
+"......#aaaaaacccaaaaaab.........",
+"......##aaaaacccaaaaabb.........",
+".......##aaaacccaaaaab..........",
+"........##aaacccaaaaab..........",
+".........##aacccaaaaab..........",
+"..........#aaaaaaaaaab..........",
+"..........#aaaaaaabbb...........",
+"..........#aacccaab.............",
+"..........#aacccaab.............",
+"..........#aacccaab.............",
+".........##aaaaaaab.............",
+".........#bbbbbbbbbb............",
+"................................",
+"................................",
+"................................",
+"................................",
+"................................"
 };
 
 GtkWidget *
@@ -183,54 +194,44 @@ lock_size (GtkWidget * toplevel)
 void
 set_icon (GtkWidget * toplevel, gchar * name, gchar ** data)
 {
-  GdkPixmap *icon;
-  GdkBitmap *mask;
-  GtkStyle *style;
+  GdkPixmap *icon = NULL;
+  GdkBitmap *mask = NULL;
 
   if (!GTK_WIDGET_REALIZED (toplevel))
     gtk_widget_realize (toplevel);
-  style = gtk_widget_get_style (toplevel);
-  icon =
-    gdk_pixmap_create_from_xpm_d (toplevel->window, &mask,
-				  &style->bg[GTK_STATE_NORMAL],
-				  (gchar **) data);
 
+  icon = MyCreateGdkPixmapFromData (data, toplevel,&mask, FALSE);
   gdk_window_set_icon (toplevel->window, NULL, icon, mask);
-
   gdk_window_set_icon_name (toplevel->window, name);
 }
 
 /* This shows a simple dialog box with a label and an 'OK' button.
    Example usage:
-    my_util_show_message ("Error saving file");
+    my_show_message ("Error saving file");
  */
 
-static GtkWidget *dialog_show_message;
-
 static void
-on_ok_show_message (GtkWidget * twidget)
+on_ok_show_message (GtkWidget * twidget, gpointer data)
 {
-  gtk_widget_destroy (dialog_show_message);
   gtk_main_quit ();
 }
 
 static gboolean
 delete_event_show_message (GtkWidget * widget,
-			   GdkEvent * event, gpointer data)
+                           GdkEvent  *event,
+                           gpointer data)
 {
-  gtk_widget_destroy (dialog_show_message);
   gtk_main_quit ();
-  return (TRUE);
+  return(TRUE);
 }
 
 void
 my_show_message (gchar * message)
 {
+  GtkWidget *dialog_show_message;
   GtkWidget *label, *button, *hbox, *pixmapwid;
-  GdkPixmap *pixmap;
-  GdkBitmap *mask;
-  GtkStyle *style;
-
+  GdkPixmap *pixmap = NULL;
+  GdkBitmap *mask = NULL;
 
   dialog_show_message = gtk_dialog_new ();
   gtk_window_position (GTK_WINDOW (dialog_show_message), GTK_WIN_POS_CENTER);
@@ -245,14 +246,10 @@ my_show_message (gchar * message)
 		      TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
-  style = gtk_widget_get_style (dialog_show_message);
-  pixmap = gdk_pixmap_create_from_xpm_d (dialog_show_message->window, &mask,
-					 &style->bg[GTK_STATE_NORMAL],
-					 (gchar **) warning);
+  pixmap = MyCreateGdkPixmapFromData (warning, dialog_show_message, &mask, FALSE);
 
   /* a pixmap widget to contain the pixmap */
   pixmapwid = gtk_pixmap_new (pixmap, mask);
-  gdk_pixmap_unref (pixmap);
   gtk_widget_show (pixmapwid);
   gtk_box_pack_start (GTK_BOX (hbox), pixmapwid, FALSE, FALSE, 0);
 
@@ -272,21 +269,16 @@ my_show_message (gchar * message)
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      GTK_SIGNAL_FUNC (on_ok_show_message),
 		      GTK_OBJECT (dialog_show_message));
-
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (gtk_widget_destroy),
-		      GTK_OBJECT (dialog_show_message));
   gtk_signal_connect (GTK_OBJECT (dialog_show_message), "delete_event",
-		      GTK_SIGNAL_FUNC (delete_event_show_message), NULL);
-  gtk_signal_connect (GTK_OBJECT (dialog_show_message), "destroy",
-		      GTK_SIGNAL_FUNC (on_ok_show_message), NULL);
+		      GTK_SIGNAL_FUNC (delete_event_show_message), 
+                      GTK_OBJECT (dialog_show_message));
   gtk_window_set_modal (GTK_WINDOW (dialog_show_message), TRUE);
   gtk_window_set_title (GTK_WINDOW (dialog_show_message), _("Message"));
   gtk_widget_show (dialog_show_message);
   gtk_main ();
+  gtk_widget_destroy (dialog_show_message);
 }
 
-
 /* This shows a dialog box with a message and a number of buttons.
  * Signal handlers can be supplied for any of the buttons.
  * NOTE: The dialog is automatically destroyed when any button is clicked.
@@ -306,12 +298,12 @@ my_show_dialog (gchar * message,
 		gint nbuttons,
 		gchar * buttons[],
 		gint default_button,
-		GtkSignalFunc signal_handlers[], gpointer data)
+		GtkSignalFunc signal_handlers[], 
+                gpointer data)
 {
   GtkWidget *dialog, *hbox, *label, *button, *bbox, *pixmapwid;
-  GdkPixmap *pixmap;
-  GdkBitmap *mask;
-  GtkStyle *style;
+  GdkPixmap *pixmap = NULL;
+  GdkBitmap *mask = NULL;
   int i;
 
   dialog = gtk_dialog_new ();
@@ -320,6 +312,7 @@ my_show_dialog (gchar * message,
   gtk_container_border_width (GTK_CONTAINER (dialog), 5);
 
   gtk_widget_realize (dialog);
+  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
   gnome_sticky (dialog->window);
 
   hbox = gtk_hbox_new (FALSE, 0);
@@ -328,14 +321,10 @@ my_show_dialog (gchar * message,
 		      TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
-  style = gtk_widget_get_style (dialog);
-  pixmap = gdk_pixmap_create_from_xpm_d (dialog->window, &mask,
-					 &style->bg[GTK_STATE_NORMAL],
-					 (gchar **) question);
+  pixmap = MyCreateGdkPixmapFromData (question, dialog, &mask, FALSE);
 
   /* a pixmap widget to contain the pixmap */
   pixmapwid = gtk_pixmap_new (pixmap, mask);
-  gdk_pixmap_unref (pixmap);
   gtk_widget_show (pixmapwid);
   gtk_box_pack_start (GTK_BOX (hbox), pixmapwid, FALSE, FALSE, 0);
 
@@ -363,60 +352,67 @@ my_show_dialog (gchar * message,
 
       if (signal_handlers[i])
 	gtk_signal_connect (GTK_OBJECT (button), "clicked",
-			    signal_handlers[i], data);
-
-      gtk_signal_connect (GTK_OBJECT (button), "clicked",
-			  GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			  GTK_OBJECT (dialog));
+			    signal_handlers[i], 
+                            GTK_OBJECT (dialog));
+      else
+        gtk_signal_connect (GTK_OBJECT (button), "clicked",
+			    GTK_SIGNAL_FUNC (gtk_widget_destroy),
+			    GTK_OBJECT (dialog));
     }
   return dialog;
 }
 
-static GtkWidget *dialog_yesno_dialog;
 static int rep_yesno_dialog = 0;
 
 static void
-on_yes_yesno_dialog (GtkWidget * twidget)
+on_yes_yesno_dialog (GtkWidget * twidget,
+                     gpointer data)
 {
-  rep_yesno_dialog = 1;
-  gtk_widget_destroy (dialog_yesno_dialog);
   gtk_main_quit ();
+  rep_yesno_dialog = 1;
 }
 
 static void
-on_no_yesno_dialog (GtkWidget * twidget)
+on_no_yesno_dialog (GtkWidget * twidget,
+                    gpointer data)
 {
   rep_yesno_dialog = 0;
-  gtk_widget_destroy (dialog_yesno_dialog);
   gtk_main_quit ();
 }
 
 static gboolean
 delete_event_yesno_dialog (GtkWidget * widget,
-			   GdkEvent * event, gpointer data)
+                           GdkEvent  *event,
+                           gpointer data)
 {
-  gtk_widget_destroy (dialog_yesno_dialog);
+  rep_yesno_dialog = 0;
   gtk_main_quit ();
-  return (TRUE);
+  return(TRUE);
 }
 
 gint my_yesno_dialog (gchar * message)
 {
   /* FIXME : how make this short and ANSI ? */
+  GtkWidget *dialog_yesno_dialog;
   gchar *buttons[] = { _("Yes"), _("No") };
 
-  GtkSignalFunc signal_handlers[] =
-    { on_yes_yesno_dialog, on_no_yesno_dialog };
-  dialog_yesno_dialog =
-    my_show_dialog (message, 2, buttons, 2, signal_handlers, NULL);
+  GtkSignalFunc signal_handlers[] = { on_yes_yesno_dialog, 
+                                      on_no_yesno_dialog };
+                                      
+  dialog_yesno_dialog = my_show_dialog (message, 
+                                        2, 
+                                        buttons, 
+                                        2, 
+                                        signal_handlers, 
+                                        NULL);
   gtk_signal_connect (GTK_OBJECT (dialog_yesno_dialog), "delete_event",
-		      GTK_SIGNAL_FUNC (delete_event_yesno_dialog), NULL);
-  gtk_signal_connect (GTK_OBJECT (dialog_yesno_dialog), "destroy",
-		      GTK_SIGNAL_FUNC (delete_event_yesno_dialog), NULL);
+		      GTK_SIGNAL_FUNC (delete_event_yesno_dialog), 
+                      GTK_OBJECT (dialog_yesno_dialog));
   gtk_window_set_modal (GTK_WINDOW (dialog_yesno_dialog), TRUE);
   gtk_window_set_title (GTK_WINDOW (dialog_yesno_dialog), _("Question"));
   gtk_widget_show (dialog_yesno_dialog);
   gtk_main ();
+  gtk_widget_destroy (dialog_yesno_dialog);
   return rep_yesno_dialog;
 }
 
@@ -636,15 +632,15 @@ on_signal (int sig_num)
     case SIGABRT:
       terminate ("sigabrt caught");
       break;
+    case SIGPIPE:
+      terminate ("sigpipe caught");
+      break;
     case SIGBUS:
       terminate ("sigbus caught");
       break;
     case SIGSEGV:
       terminate ("sigsegv caught");
       break;
-    case SIGPIPE:
-      terminate ("sigpipe caught");
-      break;
     case SIGTERM:
       terminate ("sigterm caught");
       break;
@@ -667,7 +663,34 @@ signal_setup (void)
   signal (SIGABRT, on_signal);
   signal (SIGBUS, on_signal);
   signal (SIGSEGV, on_signal);
-  signal (SIGPIPE, on_signal);
   signal (SIGTERM, on_signal);
   signal (SIGFPE, on_signal);
 }
+
+void
+xfce_init (int *argc, char **argv[])
+{
+  signal_setup ();
+
+  gtk_set_locale ();
+  bindtextdomain (PACKAGE, XFCE_LOCALE_DIR);
+  textdomain (PACKAGE);
+  gtk_init (argc, argv);
+  init_xfce_rcfile();
+
+  #ifdef HAVE_GDK_IMLIB
+  gdk_imlib_init ();
+/* Get gdk to use imlib's visual and colormap */
+  gtk_widget_push_visual (gdk_imlib_get_visual ());
+  gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+#endif
+}
+
+void
+xfce_end (gpointer data, int status)
+{
+  /* We'll be able to add more stuff here, but for the moment,
+   * that's all we do here ...
+   */
+  exit (status);
+}
