@@ -37,16 +37,17 @@
 
 typedef struct
 {
-  GtkStyle *cm[NB_XFCE_COLORS];
+  /* GtkStyle *cm[NB_XFCE_COLORS]; */
   int r[NB_XFCE_COLORS];
   int g[NB_XFCE_COLORS];
   int b[NB_XFCE_COLORS];
   char *fnt;
   char *texture;
+  char *engine;
 }
 XFCE_palette;
 
-extern unsigned long get_pixel_from_palette (XFCE_palette *, short int);
+extern void apply_xpalette (XFCE_palette *, gboolean);
 extern void get_rgb_from_palette (XFCE_palette *, short int, int *, int *,
 				  int *);
 extern int brightness_pal (const XFCE_palette *, int);
@@ -54,18 +55,18 @@ extern char *color_to_hex (char *, const XFCE_palette *, int);
 extern void set_color_table (XFCE_palette *, int, gdouble color_table[]);
 extern void set_selcolor (XFCE_palette *, int, gdouble color_table[]);
 extern void set_palcolor (XFCE_palette *, int, gdouble color_table[]);
+extern unsigned long get_pixel_from_palette (XFCE_palette *, int);
 extern XFCE_palette *newpal (void);
 extern void set_font (XFCE_palette *, char *);
 extern void set_texture (XFCE_palette *, char *);
-extern GtkStyle *palcolor (XFCE_palette *, short int);
+extern void set_engine (XFCE_palette *, char *);
 extern void freepal (XFCE_palette *);
 extern XFCE_palette *copypal (XFCE_palette *, const XFCE_palette *);
 extern XFCE_palette *copyvaluepal (XFCE_palette *, const XFCE_palette *);
-extern void makepalstyle (XFCE_palette *, int);
 extern void initpal (XFCE_palette *);
-extern void create_gtkrc_file (XFCE_palette *);
-extern GtkStyle *applycolor (XFCE_palette *, short int, int, int, int);
-extern void applypal (XFCE_palette *, GtkWidget *);
+extern void create_gtkrc_file (XFCE_palette *, char *name);
+extern void create_temp_gtkrc_file (XFCE_palette *);
+extern void apply_temp_gtkrc_file (XFCE_palette *, GtkWidget *);
 extern void defpal (XFCE_palette *);
 extern int savenamepal (XFCE_palette *, const char *);
 extern int loadnamepal (XFCE_palette *, const char *);
@@ -74,5 +75,6 @@ extern int loadpal (XFCE_palette *);
 extern void reg_xfce_app (GtkWidget * widget, XFCE_palette * p);
 extern void applypal_to_all (void);
 extern gboolean repaint_in_progress (void);
+extern void init_xfce_rcfile (void);
 
 #endif
