@@ -394,7 +394,7 @@ MyCreatePixmapFromXpmImage (XpmImage * Img, Pixmap * pixmap, Pixmap * mask)
 
 GdkPixmap *
 MyCreateGdkPixmapFromFile (char *filename, GtkWidget * widget,
-			   GdkBitmap ** mask)
+			   GdkBitmap ** mask, gboolean fit)
 {
 #ifdef HAVE_GDK_IMLIB
   GdkImlibImage *im;
@@ -427,7 +427,7 @@ MyCreateGdkPixmapFromFile (char *filename, GtkWidget * widget,
       gtk_widget_size_request ((GtkWidget *) widget, &requisition);
       w = requisition.width - (GTK_CONTAINER (widget)->border_width + 2) * 2;
       h = requisition.height - (GTK_CONTAINER (widget)->border_width + 2) * 2;
-      if ((w > 0) && (h > 0) && ((im->rgb_width > w) || (im->rgb_height > h)))
+      if ((fit) && (w > 0) && (h > 0) && ((im->rgb_width > w) || (im->rgb_height > h)))
 	gdk_imlib_render (im, w, h);
       else
 	gdk_imlib_render (im, im->rgb_width, im->rgb_height);
@@ -449,16 +449,16 @@ MyCreateGdkPixmapFromFile (char *filename, GtkWidget * widget,
       gtk_widget_size_request ((GtkWidget *) widget, &requisition);
       w = requisition.width - (GTK_CONTAINER (widget)->border_width + 2) * 2;
       h = requisition.height - (GTK_CONTAINER (widget)->border_width + 2) * 2;
-      if ((w > 0) && (h > 0) &&
+      if ((fit) && (w > 0) && (h > 0) &&
 	  ((gdk_pixbuf_get_width (source) > w)
 	   || gdk_pixbuf_get_height (source) > h))
 	destination =
-	  gdk_pixbuf_scale_simple (source, w, h, GDK_INTERP_NEAREST);
+	  gdk_pixbuf_scale_simple (source, w, h, GDK_INTERP_BILINEAR);
       else
 	destination =
 	  gdk_pixbuf_scale_simple (source, gdk_pixbuf_get_width (source),
 				   gdk_pixbuf_get_height (source),
-				   GDK_INTERP_NEAREST);
+				   GDK_INTERP_BILINEAR);
       gdk_pixbuf_render_pixmap_and_mask (destination, &pixmap, mask,
 					 gdk_pixbuf_get_has_alpha
 					 (destination));
@@ -480,7 +480,7 @@ MyCreateGdkPixmapFromFile (char *filename, GtkWidget * widget,
       w = requisition.width - (GTK_CONTAINER (widget)->border_width + 2) * 2;
       h = requisition.height - (GTK_CONTAINER (widget)->border_width + 2) * 2;
       colormap = gdk_colormap_get_system ();
-      if (((w > 0) && (h > 0) && ((I.width > w) || (I.height > h)))
+      if ((fit) && ((w > 0) && (h > 0) && ((I.width > w) || (I.height > h)))
 	  || DEFAULT_DEPTH <= 8)
 	{
 	  XpmShapeToFit (((I.width > w) ? w : I.width),
@@ -504,7 +504,7 @@ MyCreateGdkPixmapFromFile (char *filename, GtkWidget * widget,
 }
 
 GdkPixmap *
-MyCreateGdkPixmapFromData (char **data, GtkWidget * widget, GdkBitmap ** mask)
+MyCreateGdkPixmapFromData (char **data, GtkWidget * widget, GdkBitmap ** mask, gboolean fit)
 {
 #ifdef HAVE_GDK_IMLIB
   GdkImlibImage *im;
@@ -533,7 +533,7 @@ MyCreateGdkPixmapFromData (char **data, GtkWidget * widget, GdkBitmap ** mask)
       gtk_widget_size_request ((GtkWidget *) widget, &requisition);
       w = requisition.width - (GTK_CONTAINER (widget)->border_width + 2) * 2;
       h = requisition.height - (GTK_CONTAINER (widget)->border_width + 2) * 2;
-      if ((w > 0) && (h > 0) && ((im->rgb_width > w) || (im->rgb_height > h)))
+      if ((fit) && (w > 0) && (h > 0) && ((im->rgb_width > w) || (im->rgb_height > h)))
 	gdk_imlib_render (im, w, h);
       else
 	gdk_imlib_render (im, im->rgb_width, im->rgb_height);
@@ -551,16 +551,16 @@ MyCreateGdkPixmapFromData (char **data, GtkWidget * widget, GdkBitmap ** mask)
       gtk_widget_size_request ((GtkWidget *) widget, &requisition);
       w = requisition.width - (GTK_CONTAINER (widget)->border_width + 2) * 2;
       h = requisition.height - (GTK_CONTAINER (widget)->border_width + 2) * 2;
-      if ((w > 0) && (h > 0) &&
+      if ((fit) && (w > 0) && (h > 0) &&
 	  ((gdk_pixbuf_get_width (source) > w)
 	   || (gdk_pixbuf_get_height (source) > h)))
 	destination =
-	  gdk_pixbuf_scale_simple (source, w, h, GDK_INTERP_NEAREST);
+	  gdk_pixbuf_scale_simple (source, w, h, GDK_INTERP_BILINEAR);
       else
 	destination =
 	  gdk_pixbuf_scale_simple (source, gdk_pixbuf_get_width (source),
 				   gdk_pixbuf_get_height (source),
-				   GDK_INTERP_NEAREST);
+				   GDK_INTERP_BILINEAR);
       gdk_pixbuf_render_pixmap_and_mask (destination, &pixmap, mask,
 					 gdk_pixbuf_get_has_alpha
 					 (destination));
@@ -575,7 +575,7 @@ MyCreateGdkPixmapFromData (char **data, GtkWidget * widget, GdkBitmap ** mask)
       w = requisition.width - (GTK_CONTAINER (widget)->border_width + 2) * 2;
       h = requisition.height - (GTK_CONTAINER (widget)->border_width + 2) * 2;
       colormap = gdk_colormap_get_system ();
-      if ((w > 0) && (h > 0) && ((I.width > w) || (I.height > h)))
+      if ((fit) && (w > 0) && (h > 0) && ((I.width > w) || (I.height > h)))
 	{
 	  XpmShapeToFit (((I.width > w) ? w : I.width),
 			 ((I.height > h) ? h : I.height), &I, &I2);
@@ -603,7 +603,7 @@ MySetPixmapData (GtkWidget * widget, GtkWidget * parent, char **data)
   GdkPixmap *pixmap = NULL;
   GdkBitmap *mask = NULL;
 
-  pixmap = MyCreateGdkPixmapFromData (data, parent, &mask);
+  pixmap = MyCreateGdkPixmapFromData (data, parent, &mask, TRUE);
   gtk_pixmap_set (GTK_PIXMAP (widget), pixmap, mask);
   /*
      if (pixmap) gdk_pixmap_unref (pixmap);
@@ -617,7 +617,7 @@ MySetPixmapFile (GtkWidget * widget, GtkWidget * parent, char *filename)
   GdkPixmap *pixmap = NULL;
   GdkBitmap *mask = NULL;
 
-  pixmap = MyCreateGdkPixmapFromFile (filename, parent, &mask);
+  pixmap = MyCreateGdkPixmapFromFile (filename, parent, &mask, TRUE);
   gtk_pixmap_set (GTK_PIXMAP (widget), pixmap, mask);
   /*
      if (pixmap) gdk_pixmap_unref (pixmap);
@@ -632,7 +632,7 @@ MyCreateFromPixmapData (GtkWidget * widget, char **data)
   GdkBitmap *mask = NULL;
   GtkWidget *result;
 
-  pixmap = MyCreateGdkPixmapFromData (data, widget, &mask);
+  pixmap = MyCreateGdkPixmapFromData (data, widget, &mask, TRUE);
   result = gtk_pixmap_new (pixmap, mask);
   /*
      if (pixmap) gdk_pixmap_unref (pixmap);
@@ -648,7 +648,7 @@ MyCreateFromPixmapFile (GtkWidget * widget, char *file)
   GdkBitmap *mask = NULL;
   GtkWidget *result;
 
-  pixmap = MyCreateGdkPixmapFromFile (file, widget, &mask);
+  pixmap = MyCreateGdkPixmapFromFile (file, widget, &mask, TRUE);
   result = gtk_pixmap_new (pixmap, mask);
   /*
      if (pixmap) gdk_pixmap_unref (pixmap);
@@ -740,3 +740,4 @@ ApplyRootColor (XFCE_palette * pal, gboolean gradient, int col_index)
       XFlush (GDK_DISPLAY ());
     }
 }
+
