@@ -20,7 +20,6 @@
 #define __XFBD_H__
 
 #include <gtk/gtk.h>
-#include "xfcolor.h"
 
 #define RCFILE          "xfbdrc"
 #define NOBACK          "None"
@@ -38,6 +37,6 @@ void readstr (char *str);
 int writestr (char *str);
 void display_back (char *str);
 
-GtkWidget *create_xfbd (XFCE_palette *);
+GtkWidget *create_xfbd ();
 
 #endif
