@@ -21,13 +21,11 @@
 
 #include <gtk/gtk.h>
 
-void browse_cb( GtkWidget *widget, gpointer   data );
-void apply_cb( GtkWidget *widget, gpointer   data );
-void cancel_cb( GtkWidget *widget, gpointer   data );
-void ok_cb( GtkWidget *widget, gpointer   data );
-void clear_cb( GtkWidget *widget, gpointer   data );
-gboolean delete_event( GtkWidget *widget,
-                   GdkEvent  *event,
-                   gpointer   data );
+void browse_cb (GtkWidget * widget, gpointer data);
+void apply_cb (GtkWidget * widget, gpointer data);
+void cancel_cb (GtkWidget * widget, gpointer data);
+void ok_cb (GtkWidget * widget, gpointer data);
+void clear_cb (GtkWidget * widget, gpointer data);
+gboolean delete_event (GtkWidget * widget, GdkEvent * event, gpointer data);
 
 #endif
