@@ -21,20 +21,14 @@
 
 #include <gtk/gtk.h>
 
-void action_cancel_cb( GtkWidget *widget,
-                     gpointer   data );
+void action_cancel_cb (GtkWidget * widget, gpointer data);
 
-void action_ok_cb( GtkWidget *widget,
-                     gpointer   data );
+void action_ok_cb (GtkWidget * widget, gpointer data);
 
 gboolean
-action_delete_event( GtkWidget *widget,
-                   GdkEvent  *event,
-                   gpointer   data );
-		   
-void action_browse_command_cb( GtkWidget *widget,
-                               gpointer   data );
+action_delete_event (GtkWidget * widget, GdkEvent * event, gpointer data);
 
-void action_browse_icon_cb( GtkWidget *widget,
-                            gpointer   data );
+void action_browse_command_cb (GtkWidget * widget, gpointer data);
+
+void action_browse_icon_cb (GtkWidget * widget, gpointer data);
 #endif
