@@ -31,6 +31,7 @@
 #include "selects.h"
 #include "popup.h"
 #include "xfce.h"
+#include "xfwm.h"
 #include "fileutil.h"
 #include "my_intl.h"
 
@@ -95,6 +96,8 @@ initconfig (config * newconf)
   newconf->clicktofocus = 1;
   newconf->opaquemove = 1;
   newconf->opaqueresize = 1;
+  newconf->show_diagnostic = 1;
+  newconf->apply_xcolors = 1;
   newconf->snapsize = 10;
   newconf->autoraise = 0;
   newconf->tooltipsdelay = 250;
@@ -273,6 +276,12 @@ writeconfig (void)
 	default:
 	  fprintf (configfile, "\tMediumMenuIcons\n");
 	}
+      fprintf (configfile, "[XColors]\n");
+      fprintf (configfile,
+	       current_config.apply_xcolors ? "\tApply\n" : "\tIgnore\n");
+      fprintf (configfile, "[Diagnostic]\n");
+      fprintf (configfile,
+	       current_config.show_diagnostic ? "\tShow\n" : "\tIgnore\n");
       fprintf (configfile, "[Commands]\n");
       for (i = 0; i < NBSELECTS; i++)
 	if (strlen (selects[i].command))
@@ -357,6 +366,10 @@ resetconfig (void)
       fprintf (configfile, "[Sizes]\n");
       fprintf (configfile, "\tMediumPanelIcons\n");
       fprintf (configfile, "\tSmallMenuIcons\n");
+      fprintf (configfile, "[XColors]\n");
+      fprintf (configfile, "\tApply\n");
+      fprintf (configfile, "[Diagnostic]\n");
+      fprintf (configfile, "\tShow\n");
       fprintf (configfile, "[Commands]\n");
       for (i = 0; i < NBSELECTS; i++)
 	fprintf (configfile, "\tNone\n");
@@ -751,7 +764,6 @@ readconfig (void)
 	    current_config.select_icon_size = 2;
 	  else
 	    current_config.select_icon_size = 1;
-	  update_gxfce_size ();
 	  p = nextline (configfile, lineread);
 	  if (!my_strncasecmp
 	      (p, "SmallMenuIcons", strlen ("SmallMenuIcons")))
@@ -765,17 +777,34 @@ readconfig (void)
 	  update_popup_size ();
 	  p = nextline (configfile, lineread);
 	}
+      if (!my_strncasecmp (p, "[XColors]", strlen ("[XColors]")))
+	{
+	  p = nextline (configfile, lineread);
+	  current_config.apply_xcolors =
+	    (my_strncasecmp (p, "Apply", strlen ("Apply")) == 0);
+	  p = nextline (configfile, lineread);
+	}
+      if (!my_strncasecmp (p, "[Diagnostic]", strlen ("[Diagnostic]")))
+	{
+	  p = nextline (configfile, lineread);
+	  current_config.show_diagnostic =
+	    (my_strncasecmp (p, "Show", strlen ("Show")) == 0);
+	  p = nextline (configfile, lineread);
+	}
       if (!my_strncasecmp (p, "[Commands]", strlen ("[Commands]")))
 	{
 	  p = nextline (configfile, lineread);
-	  for (i = 0; i < NBSELECTS; i++)
-	    {
-	      if (newconf == 1)
-		set_command (i, get_first_ok (p));
-	      else
-		set_command (i, p);
-	      p = nextline (configfile, lineread);
-	    }
+          if (p)
+            {
+	      for (i = 0; i < NBSELECTS; i++)
+	        {
+	          if (newconf == 1)
+		    set_command (i, get_first_ok (p));
+	          else
+		    set_command (i, p);
+	          p = nextline (configfile, lineread);
+	        }
+            }
 	}
       i = 0;
       sprintf (dummy, "[Menu%u]", i + 1);
@@ -813,4 +842,5 @@ update_config_screen_visible (int i)
     current_config.visible_screen = i;
   else
     current_config.visible_screen = NBSCREENS;
+  apply_wm_desk_names (current_config.visible_screen);
 }
