@@ -47,6 +47,8 @@ typedef struct
   gboolean autoraise;
   gboolean gradient_active_title;
   gboolean gradient_inactive_title;
+  gboolean show_diagnostic;
+  gboolean apply_xcolors;
   int iconpos;
   int tooltipsdelay;
   int snapsize;
