@@ -37,14 +37,13 @@
 #include "modify.h"
 #include "popup.h"
 #include "xpmext.h"
-#include "xfcolor.h"
 #include "modify_cb.h"
 #include "gnome_protocol.h"
 #include "empty.h"
 #include "defaulticon.h"
 
 GtkWidget *
-create_modify (XFCE_palette * pal)
+create_modify ()
 {
   GtkWidget *modify;
   GtkWidget *modify_mainframe;
@@ -114,7 +113,6 @@ create_modify (XFCE_palette * pal)
   gtk_widget_set_name (modify_preview_frame, "popup_addicon_frame");
   gtk_object_set_data (GTK_OBJECT (modify_preview_frame),
 		       "modify_preview_frame", modify_preview_frame);
-  /* gtk_widget_set_style(modify_preview_frame, pal->cm[7]); */
   gtk_frame_set_shadow_type (GTK_FRAME (modify_preview_frame), GTK_SHADOW_IN);
   gtk_container_border_width (GTK_CONTAINER (modify_preview_frame), 5);
   gtk_widget_show (modify_preview_frame);
@@ -129,7 +127,6 @@ create_modify (XFCE_palette * pal)
   gtk_widget_set_name (modify_preview_pixmap, "modify_preview_pixmap");
   gtk_object_set_data (GTK_OBJECT (modify), "modify_preview_pixmap",
 		       modify_preview_pixmap);
-  /* gtk_widget_set_style(modify_preview_pixmap, pal->cm[7]); */
   gtk_widget_show (modify_preview_pixmap);
   gtk_container_add (GTK_CONTAINER (modify_preview_frame),
 		     modify_preview_pixmap);
@@ -201,7 +198,6 @@ create_modify (XFCE_palette * pal)
   gtk_widget_set_name (modify_command_entry, "modify_command_entry");
   gtk_object_set_data (GTK_OBJECT (modify), "modify_command_entry",
 		       modify_command_entry);
-  /* gtk_widget_set_style(modify_command_entry, pal->cm[4]); */
   gtk_widget_show (modify_command_entry);
   gtk_table_attach (GTK_TABLE (modify_table), modify_command_entry, 1, 2, 0,
 		    1, (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
@@ -211,7 +207,6 @@ create_modify (XFCE_palette * pal)
   gtk_widget_set_name (modify_icon_entry, "modify_icon_entry");
   gtk_object_set_data (GTK_OBJECT (modify), "modify_icon_entry",
 		       modify_icon_entry);
-  /* gtk_widget_set_style(modify_icon_entry, pal->cm[4]); */
   gtk_widget_show (modify_icon_entry);
   gtk_table_attach (GTK_TABLE (modify_table), modify_icon_entry, 1, 2, 1, 2,
 		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
@@ -221,7 +216,6 @@ create_modify (XFCE_palette * pal)
   gtk_widget_set_name (modify_displayed_entry, "modify_displayed_entry");
   gtk_object_set_data (GTK_OBJECT (modify), "modify_displayed_entry",
 		       modify_displayed_entry);
-  /* gtk_widget_set_style(modify_displayed_entry, pal->cm[4]); */
   gtk_widget_show (modify_displayed_entry);
   gtk_table_attach (GTK_TABLE (modify_table), modify_displayed_entry, 1, 2, 2,
 		    3, (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
@@ -287,15 +281,7 @@ create_modify (XFCE_palette * pal)
   gtk_container_add (GTK_CONTAINER (modify_hbuttonbox), modify_ok_button);
   gtk_container_border_width (GTK_CONTAINER (modify_ok_button), 5);
   GTK_WIDGET_SET_FLAGS (modify_ok_button, GTK_CAN_DEFAULT);
-
-  modify_cancel_button = gtk_button_new_with_label (_("Cancel"));
-  gtk_widget_set_name (modify_cancel_button, "modify_cancel_button");
-  gtk_object_set_data (GTK_OBJECT (modify), "modify_cancel_button",
-		       modify_cancel_button);
-  gtk_widget_show (modify_cancel_button);
-  gtk_container_add (GTK_CONTAINER (modify_hbuttonbox), modify_cancel_button);
-  gtk_container_border_width (GTK_CONTAINER (modify_cancel_button), 5);
-  GTK_WIDGET_SET_FLAGS (modify_cancel_button, GTK_CAN_DEFAULT);
+  gtk_widget_grab_default (modify_ok_button);
 
   modify_remove_button = gtk_button_new_with_label (_("Remove"));
   gtk_widget_set_name (modify_remove_button, "modify_remove_button");
@@ -306,8 +292,19 @@ create_modify (XFCE_palette * pal)
   gtk_container_border_width (GTK_CONTAINER (modify_remove_button), 5);
   GTK_WIDGET_SET_FLAGS (modify_remove_button, GTK_CAN_DEFAULT);
 
+  modify_cancel_button = gtk_button_new_with_label (_("Cancel"));
+  gtk_widget_set_name (modify_cancel_button, "modify_cancel_button");
+  gtk_object_set_data (GTK_OBJECT (modify), "modify_cancel_button",
+		       modify_cancel_button);
+  gtk_widget_show (modify_cancel_button);
+  gtk_container_add (GTK_CONTAINER (modify_hbuttonbox), modify_cancel_button);
+  gtk_container_border_width (GTK_CONTAINER (modify_cancel_button), 5);
+  GTK_WIDGET_SET_FLAGS (modify_cancel_button, GTK_CAN_DEFAULT);
+
   gtk_widget_add_accelerator (modify_ok_button, "clicked", accel_group,
 			      GDK_Return, 0, GTK_ACCEL_VISIBLE);
+  gtk_widget_add_accelerator (modify_ok_button, "clicked", accel_group,
+			      GDK_Return, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
   gtk_widget_add_accelerator (modify_ok_button, "clicked", accel_group,
 			      GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
@@ -323,9 +320,6 @@ create_modify (XFCE_palette * pal)
   gtk_signal_connect (GTK_OBJECT (modify), "delete_event",
 		      GTK_SIGNAL_FUNC (modify_delete_event), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (modify), "destroy",
-		      GTK_SIGNAL_FUNC (modify_cancel_cb), NULL);
-
   gtk_signal_connect (GTK_OBJECT (modify_cancel_button), "clicked",
 		      GTK_SIGNAL_FUNC (modify_cancel_cb), NULL);
 
@@ -340,7 +334,7 @@ create_modify (XFCE_palette * pal)
 }
 
 void
-open_modify (GtkWidget * modify, int menu, int item)
+open_modify (GtkWidget * modify, gint menu, gint item)
 {
   GdkPixmap *pixmap = NULL;
   GdkBitmap *mask = NULL;
@@ -352,18 +346,18 @@ open_modify (GtkWidget * modify, int menu, int item)
       gtk_entry_set_text (GTK_ENTRY (modify_command_entry), "");
       gtk_entry_set_text (GTK_ENTRY (modify_icon_entry), "");
       gtk_entry_set_text (GTK_ENTRY (modify_displayed_entry), "");
-      pixmap = MyCreateGdkPixmapFromData (empty, modify_preview_frame, &mask);
+      pixmap = MyCreateGdkPixmapFromData (empty, modify_preview_frame, &mask, TRUE);
       gtk_pixmap_set (GTK_PIXMAP (modify_preview_pixmap), pixmap, mask);
       gtk_widget_hide (modify_remove_button);
       signal_id1 =
 	gtk_signal_connect (GTK_OBJECT (modify_ok_button), "clicked",
 			    GTK_SIGNAL_FUNC (modify_add_cb),
-			    (gpointer) (menu * NBMAXITEMS));
+			    (gpointer)((long) (menu * NBMAXITEMS)));
 
       signal_id2 =
 	gtk_signal_connect (GTK_OBJECT (modify_remove_button), "clicked",
 			    GTK_SIGNAL_FUNC (modify_cancel_cb),
-			    (gpointer) (menu * NBMAXITEMS));
+			    (gpointer)((long) (menu * NBMAXITEMS)));
     }
   else
     {
@@ -377,7 +371,7 @@ open_modify (GtkWidget * modify, int menu, int item)
 	{
 	  gtk_entry_set_text (GTK_ENTRY (modify_icon_entry), pixfile);
 	  pixmap =
-	    MyCreateGdkPixmapFromFile (pixfile, modify_preview_frame, &mask);
+	    MyCreateGdkPixmapFromFile (pixfile, modify_preview_frame, &mask, TRUE);
 	  gtk_pixmap_set (GTK_PIXMAP (modify_preview_pixmap), pixmap, mask);
 	}
       else
@@ -385,19 +379,19 @@ open_modify (GtkWidget * modify, int menu, int item)
 	  gtk_entry_set_text (GTK_ENTRY (modify_icon_entry), "Default icon");
 	  pixmap =
 	    MyCreateGdkPixmapFromData (defaulticon, modify_preview_frame,
-				       &mask);
+				       &mask, TRUE);
 	  gtk_pixmap_set (GTK_PIXMAP (modify_preview_pixmap), pixmap, mask);
 	}
       gtk_widget_show (modify_remove_button);
       signal_id1 =
 	gtk_signal_connect (GTK_OBJECT (modify_ok_button), "clicked",
 			    GTK_SIGNAL_FUNC (modify_change_cb),
-			    (gpointer) (menu * NBMAXITEMS + item));
+			    (gpointer)((long) (menu * NBMAXITEMS + item)));
 
       signal_id2 =
 	gtk_signal_connect (GTK_OBJECT (modify_remove_button), "clicked",
 			    GTK_SIGNAL_FUNC (modify_remove_cb),
-			    (gpointer) (menu * NBMAXITEMS + item));
+			    (gpointer)((long) (menu * NBMAXITEMS + item)));
     }
   gtk_entry_set_position (GTK_ENTRY (modify_command_entry), 0);
   gtk_entry_set_position (GTK_ENTRY (modify_icon_entry), 0);
