@@ -18,7 +18,6 @@
 
 #ifndef __MODIFY_H__
 #define __MODIFY_H__
-#include "xfcolor.h"
 
 GtkWidget *modify_command_entry;
 GtkWidget *modify_icon_entry;
@@ -32,8 +31,8 @@ GtkWidget *modify_remove_button;
 guint signal_id1;
 guint signal_id2;
 
-GtkWidget *create_modify (XFCE_palette *);
+GtkWidget *create_modify (void);
 
-void open_modify (GtkWidget * modify, int menu, int item);
+void open_modify (GtkWidget * modify, gint menu, gint item);
 
 #endif
