@@ -21,27 +21,19 @@
 
 #include <gtk/gtk.h>
 
-void modify_cancel_cb( GtkWidget *widget,
-                     gpointer   data );
+void modify_cancel_cb (GtkWidget * widget, gpointer data);
 
 gboolean
-modify_delete_event( GtkWidget *widget,
-                   GdkEvent  *event,
-                   gpointer   data );
-		   
-void modify_browse_command_cb( GtkWidget *widget,
-                               gpointer   data );
+modify_delete_event (GtkWidget * widget, GdkEvent * event, gpointer data);
 
-void modify_browse_icon_cb( GtkWidget *widget,
-                            gpointer   data );
+void modify_browse_command_cb (GtkWidget * widget, gpointer data);
 
-void modify_remove_cb( GtkWidget *widget,
-                            gpointer   data );
+void modify_browse_icon_cb (GtkWidget * widget, gpointer data);
 
-void modify_change_cb( GtkWidget *widget,
-                            gpointer   data );
+void modify_remove_cb (GtkWidget * widget, gpointer data);
 
-void modify_add_cb( GtkWidget *widget,
-                            gpointer   data );
+void modify_change_cb (GtkWidget * widget, gpointer data);
+
+void modify_add_cb (GtkWidget * widget, gpointer data);
 
 #endif
