@@ -37,6 +37,9 @@ GdkGC *DrawGC;
 static gboolean xgrabbed = FALSE;
 static gboolean pressed = FALSE;
 
+/* Added by Jason Litowitz */
+#include "popup.h"
+
 void
 move_internal_grab (Display * disp)
 {
@@ -62,9 +65,14 @@ CreateDrawGC (GdkWindow * w)
 {
   GdkGCValues gcv;
   GdkGCValuesMask gcm;
+  GdkColormap *cmap;
   GdkColor col;
 
-  col.red = col.green = col.blue = 0;
+  cmap = gdk_colormap_get_system();
+  col.red = col.green = col.blue = 0xFFFF;
+  if (!gdk_color_alloc(cmap, &col)) {
+    g_error("couldn't allocate colour");
+  }  
 
   gcm =
     GDK_GC_FUNCTION | GDK_GC_LINE_WIDTH | GDK_GC_FOREGROUND | GDK_GC_SUBWINDOW
@@ -77,6 +85,12 @@ CreateDrawGC (GdkWindow * w)
   DrawGC = gdk_gc_new_with_values (w, &gcv, gcm);
 }
 
+void
+FreeDrawGC (void)
+{
+  gdk_gc_destroy (DrawGC);
+}
+
 void
 MoveOutline (int x, int y, int width, int height)
 {
@@ -111,6 +125,7 @@ MoveOutline (int x, int y, int width, int height)
 static void
 move_pressed (GtkWidget * widget, GdkEventButton * event, gpointer * topwin)
 {
+
   CursorOffset *p;
   gint upositionx = 0;
   gint upositiony = 0;
@@ -118,6 +133,8 @@ move_pressed (GtkWidget * widget, GdkEventButton * event, gpointer * topwin)
   gint uheight = 0;
   gint xp, yp;
 
+  /* Added by Jason Litowitz */
+  hide_current_popup_menu();
   /* ignore double and triple click */
   if (event->type != GDK_BUTTON_PRESS)
     return;
@@ -160,6 +177,9 @@ move_released (GtkWidget * widget, GdkEventButton * event, gpointer * topwin)
   if (event->button != 1)
     return;
 
+  if (!pressed)
+    return;
+
   pressed = FALSE;
 
   p = gtk_object_get_user_data (GTK_OBJECT (widget));
