@@ -31,7 +31,6 @@
 #include <unistd.h>
 #include "my_intl.h"
 #include "constant.h"
-#include "xfcolor.h"
 #include "xfce_main.h"
 #include "xfce.h"
 #include "xfce_cb.h"
@@ -72,9 +71,11 @@ static GtkTargetEntry popup_target_table[] = {
 static guint n_popup_targets =
   sizeof (popup_target_table) / sizeof (popup_target_table[0]);
 
+/* Added by Jason Litowitz */
+static gint Current_Popup_Window = -1;
+
 GtkWidget *
-create_popup_item (GtkWidget * toplevel, XFCE_palette * pal, gint nbr_menu,
-		   gint nbr_item)
+create_popup_item (GtkWidget * toplevel, gint nbr_menu, gint nbr_item)
 {
   GtkWidget *hbox;
 
@@ -92,7 +93,6 @@ create_popup_item (GtkWidget * toplevel, XFCE_palette * pal, gint nbr_menu,
   gtk_button_set_relief ((GtkButton *) popup_menus[nbr_menu].
 			 popup_buttons[nbr_item].item_button,
 			 GTK_RELIEF_NONE);
-  /* gtk_widget_set_style(popup_menus[nbr_menu].popup_buttons[nbr_item].item_button, pal->cm[7]); */
   gtk_widget_show (popup_menus[nbr_menu].popup_buttons[nbr_item].item_button);
 
   popup_menus[nbr_menu].popup_buttons[nbr_item].item_tooltip =
@@ -110,7 +110,6 @@ create_popup_item (GtkWidget * toplevel, XFCE_palette * pal, gint nbr_menu,
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_widget_set_name (hbox, "hbox");
   gtk_object_set_data (GTK_OBJECT (toplevel), "hbox", hbox);
-  /* gtk_widget_set_style(hbox, pal->cm[7]); */
   gtk_widget_show (hbox);
   gtk_container_add (GTK_CONTAINER
 		     (popup_menus[nbr_menu].popup_buttons[nbr_item].
@@ -123,7 +122,6 @@ create_popup_item (GtkWidget * toplevel, XFCE_palette * pal, gint nbr_menu,
   gtk_object_set_data (GTK_OBJECT (toplevel), "frame",
 		       popup_menus[nbr_menu].popup_buttons[nbr_item].
 		       item_pixmap_frame);
-  /* gtk_widget_set_style(popup_menus[nbr_menu].popup_buttons[nbr_item].item_pixmap_frame, pal->cm[7]); */
   gtk_widget_show (popup_menus[nbr_menu].popup_buttons[nbr_item].
 		   item_pixmap_frame);
   gtk_box_pack_start (GTK_BOX (hbox),
@@ -145,7 +143,6 @@ create_popup_item (GtkWidget * toplevel, XFCE_palette * pal, gint nbr_menu,
   gtk_object_set_data (GTK_OBJECT (toplevel), "popup_pixmap",
 		       popup_menus[nbr_menu].popup_buttons[nbr_item].
 		       item_pixmap);
-  /* gtk_widget_set_style(popup_menus[nbr_menu].popup_buttons[nbr_item].item_pixmap, pal->cm[7]); */
   gtk_widget_show (popup_menus[nbr_menu].popup_buttons[nbr_item].item_pixmap);
   gtk_container_add (GTK_CONTAINER
 		     (popup_menus[nbr_menu].popup_buttons[nbr_item].
@@ -160,7 +157,6 @@ create_popup_item (GtkWidget * toplevel, XFCE_palette * pal, gint nbr_menu,
   gtk_object_set_data (GTK_OBJECT (toplevel), "popup_label",
 		       popup_menus[nbr_menu].popup_buttons[nbr_item].
 		       item_label);
-  /* gtk_widget_set_style(popup_menus[nbr_menu].popup_buttons[nbr_item].item_label, pal->cm[7]); */
   gtk_widget_show (popup_menus[nbr_menu].popup_buttons[nbr_item].item_label);
   gtk_box_pack_start (GTK_BOX (hbox),
 		      popup_menus[nbr_menu].popup_buttons[nbr_item].
@@ -182,7 +178,7 @@ create_popup_item (GtkWidget * toplevel, XFCE_palette * pal, gint nbr_menu,
 		      (popup_menus[nbr_menu].popup_buttons[nbr_item].
 		       item_button), "drag_data_received",
 		      GTK_SIGNAL_FUNC (popup_entry_drag_data_received),
-		      (gpointer) (nbr_menu * NBMAXITEMS + nbr_item));
+		      (gpointer)((long)(nbr_menu * NBMAXITEMS + nbr_item)));
 
   gtk_widget_set_events (popup_menus[nbr_menu].popup_buttons[nbr_item].
 			 item_button,
@@ -194,18 +190,18 @@ create_popup_item (GtkWidget * toplevel, XFCE_palette * pal, gint nbr_menu,
 		      (popup_menus[nbr_menu].popup_buttons[nbr_item].
 		       item_button), "button_press_event",
 		      GTK_SIGNAL_FUNC (popup_entry_modify_cb),
-		      (gpointer) (nbr_menu * NBMAXITEMS + nbr_item));
+		      (gpointer)((long) (nbr_menu * NBMAXITEMS + nbr_item)));
   gtk_signal_connect (GTK_OBJECT
 		      (popup_menus[nbr_menu].popup_buttons[nbr_item].
 		       item_button), "clicked",
 		      GTK_SIGNAL_FUNC (popup_entry_cb),
-		      (gpointer) (nbr_menu * NBMAXITEMS + nbr_item));
+		      (gpointer)((long) (nbr_menu * NBMAXITEMS + nbr_item)));
 
   return popup_menus[nbr_menu].popup_buttons[nbr_item].item_button;
 }
 
 GtkWidget *
-create_popup_menu (XFCE_palette * pal, gint nbr)
+create_popup_menu (gint nbr)
 {
   GtkWidget *popup_mainframe;
   GtkWidget *popup_vbox;
@@ -234,13 +230,11 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
   gtk_window_set_title (GTK_WINDOW (popup_menus[nbr].popup_toplevel),
 			"Popup Menu");
   gnome_sticky (popup_menus[nbr].popup_toplevel->window);
-  /* gtk_widget_set_style(popup_menus[nbr].popup_toplevel, pal->cm[7]); */
 
   popup_mainframe = gtk_frame_new (NULL);
   gtk_widget_set_name (popup_mainframe, "popup_mainframe");
   gtk_object_set_data (GTK_OBJECT (popup_menus[nbr].popup_toplevel),
 		       "popup_mainframe", popup_mainframe);
-  /* gtk_widget_set_style(popup_mainframe, pal->cm[7]); */
   gtk_widget_show (popup_mainframe);
   gtk_container_add (GTK_CONTAINER (popup_menus[nbr].popup_toplevel),
 		     popup_mainframe);
@@ -250,7 +244,6 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
   gtk_widget_set_name (popup_vbox, "popup_vbox");
   gtk_object_set_data (GTK_OBJECT (popup_menus[nbr].popup_toplevel),
 		       "popup_vbox", popup_vbox);
-  /* gtk_widget_set_style(popup_vbox, pal->cm[7]); */
   gtk_widget_show (popup_vbox);
   gtk_container_add (GTK_CONTAINER (popup_mainframe), popup_vbox);
 
@@ -262,7 +255,6 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
 		       popup_menus[nbr].popup_addicon_button);
   gtk_button_set_relief ((GtkButton *) popup_menus[nbr].popup_addicon_button,
 			 GTK_RELIEF_NONE);
-  /* gtk_widget_set_style(popup_menus[nbr].popup_addicon_button, pal->cm[7]); */
   gtk_widget_show (popup_menus[nbr].popup_addicon_button);
   gtk_box_pack_start (GTK_BOX (popup_vbox),
 		      popup_menus[nbr].popup_addicon_button, FALSE, TRUE, 0);
@@ -288,7 +280,6 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
   gtk_object_set_data (GTK_OBJECT (popup_menus[nbr].popup_toplevel),
 		       "popup_addicon_icon_frame",
 		       popup_menus[nbr].popup_addicon_icon_frame);
-  /* gtk_widget_set_style(popup_menus[nbr].popup_addicon_icon_frame, pal->cm[7]); */
   gtk_widget_show (popup_menus[nbr].popup_addicon_icon_frame);
   gtk_box_pack_start (GTK_BOX (popup_addicon_hbox),
 		      popup_menus[nbr].popup_addicon_icon_frame, FALSE, TRUE,
@@ -309,7 +300,6 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
   gtk_object_set_data (GTK_OBJECT (popup_menus[nbr].popup_toplevel),
 		       "popup_addicon_icon_pixmap",
 		       popup_addicon_icon_pixmap);
-  /* gtk_widget_set_style(popup_addicon_icon_pixmap, pal->cm[7]); */
   gtk_widget_show (popup_addicon_icon_pixmap);
   gtk_container_add (GTK_CONTAINER
 		     (popup_menus[nbr].popup_addicon_icon_frame),
@@ -319,7 +309,6 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
   gtk_widget_set_name (popup_addicon_icon_label, "popup_addicon_icon_label");
   gtk_object_set_data (GTK_OBJECT (popup_menus[nbr].popup_toplevel),
 		       "popup_addicon_icon_label", popup_addicon_icon_label);
-  /* gtk_widget_set_style(popup_addicon_icon_label, pal->cm[7]); */
   gtk_widget_show (popup_addicon_icon_label);
   gtk_box_pack_start (GTK_BOX (popup_addicon_hbox), popup_addicon_icon_label,
 		      TRUE, TRUE, 0);
@@ -334,7 +323,6 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
   gtk_object_set_data (GTK_OBJECT (popup_menus[nbr].popup_toplevel),
 		       "popup_addicon_separator",
 		       popup_menus[nbr].popup_addicon_separator);
-  /* gtk_widget_set_style(popup_menus[nbr].popup_addicon_separator, pal->cm[7]); */
   gtk_widget_show (popup_menus[nbr].popup_addicon_separator);
   gtk_box_pack_start (GTK_BOX (popup_vbox),
 		      popup_menus[nbr].popup_addicon_separator, FALSE, TRUE,
@@ -343,7 +331,7 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
   for (i = 0; i < NBMAXITEMS; i++)
     gtk_box_pack_start (GTK_BOX (popup_vbox),
 			create_popup_item (popup_menus[nbr].popup_toplevel,
-					   pal, nbr, i), FALSE, TRUE, 0);
+					   nbr, i), FALSE, TRUE, 0);
 
   popup_menus[nbr].popup_detach = gtk_button_new ();
   gtk_widget_set_name (popup_menus[nbr].popup_detach, "popup_tearoff_button");
@@ -351,7 +339,6 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
 		       "popup_tearoff_button", popup_menus[nbr].popup_detach);
   gtk_button_set_relief ((GtkButton *) popup_menus[nbr].popup_detach,
 			 GTK_RELIEF_NONE);
-  /* gtk_widget_set_style(popup_menus[nbr].popup_detach, pal->cm[7]); */
   gtk_widget_show (popup_menus[nbr].popup_detach);
   gtk_box_pack_start (GTK_BOX (popup_vbox), popup_menus[nbr].popup_detach,
 		      FALSE, TRUE, 0);
@@ -367,21 +354,21 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
   gtk_widget_set_name (popup_tearoff_hseparator, "popup_tearoff_hseparator");
   gtk_object_set_data (GTK_OBJECT (popup_menus[nbr].popup_toplevel),
 		       "popup_tearoff_hseparator", popup_tearoff_hseparator);
-  /* gtk_widget_set_style(popup_tearoff_hseparator, pal->cm[7]); */
   gtk_widget_show (popup_tearoff_hseparator);
   gtk_container_add (GTK_CONTAINER (popup_menus[nbr].popup_detach),
 		     popup_tearoff_hseparator);
 
   gtk_signal_connect (GTK_OBJECT (popup_menus[nbr].popup_toplevel),
 		      "delete_event", GTK_SIGNAL_FUNC (delete_popup_cb),
-		      (gpointer) nbr);
+		      (gpointer)((long) nbr));
 
   gtk_signal_connect (GTK_OBJECT (popup_menus[nbr].popup_detach), "clicked",
-		      GTK_SIGNAL_FUNC (detach_cb), (gpointer) nbr);
+		      GTK_SIGNAL_FUNC (detach_cb), 
+                      (gpointer)((long) nbr));
 
   gtk_signal_connect (GTK_OBJECT (popup_menus[nbr].popup_addicon_button),
 		      "clicked", GTK_SIGNAL_FUNC (popup_addicon_cb),
-		      (gpointer) nbr);
+		      (gpointer)((long) nbr));
 
   gtk_drag_dest_set (popup_menus[nbr].popup_addicon_button,
 		     GTK_DEST_DEFAULT_ALL,
@@ -391,7 +378,7 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
   gtk_signal_connect (GTK_OBJECT (popup_menus[nbr].popup_addicon_button),
 		      "drag_data_received",
 		      GTK_SIGNAL_FUNC (popup_addicon_drag_data_received),
-		      (gpointer) nbr);
+		      (gpointer)((long) nbr));
 
   set_icon (popup_menus[nbr].popup_toplevel, "Popup Menu", menu_icon);
 
@@ -401,13 +388,13 @@ create_popup_menu (XFCE_palette * pal, gint nbr)
 }
 
 void
-create_all_popup_menus (XFCE_palette * pal, GtkWidget * main)
+create_all_popup_menus (	GtkWidget * main)
 {
   gint i;
 
   for (i = 0; i < NBPOPUPS; i++)
     {
-      create_popup_menu (pal, i);
+      create_popup_menu (i);
       gtk_window_set_transient_for (GTK_WINDOW
 				    (popup_menus[i].popup_toplevel),
 				    GTK_WINDOW (main));
@@ -450,6 +437,8 @@ show_popup_menu (gint nbr, gint x, gint y, gboolean animation)
       gtk_widget_show (popup_menus[nbr].popup_addicon_separator);
     }
 
+  hide_current_popup_menu();
+
   if ((x > 0) && (y > 0))
     {
       px = x;
@@ -483,10 +472,16 @@ show_popup_menu (gint nbr, gint x, gint y, gboolean animation)
     }
 
   if (!popup_menus[nbr].detach)
-    gtk_widget_set_uposition (popup_menus[nbr].popup_toplevel, tempx, tempy);
+    {
+      Current_Popup_Window = nbr;
+      gtk_widget_set_uposition (popup_menus[nbr].popup_toplevel, tempx, tempy);
+    }
   else
-    gtk_widget_set_uposition (popup_menus[nbr].popup_toplevel,
-			      popup_menus[nbr].uposx, popup_menus[nbr].uposy);
+    {
+      Current_Popup_Window = -1;
+      gtk_widget_set_uposition (popup_menus[nbr].popup_toplevel,
+			        popup_menus[nbr].uposx, popup_menus[nbr].uposy);
+    }
 
   if ((!popup_menus[nbr].animatewin) && anim)
     {
@@ -573,6 +568,10 @@ hide_popup_menu (gint nbr, gboolean animation)
 				 popup_menus[nbr].popup_toplevel)->window,
 				&popup_menus[nbr].uposx,
 				&popup_menus[nbr].uposy);
+  /* Added by Jason Litowitz */
+  if (!popup_menus[nbr].detach)
+    Current_Popup_Window = -1;
+
   if ((!popup_menus[nbr].animatewin) && anim)
     {
       popup_menus[nbr].animatewin = gtk_window_new (GTK_WINDOW_POPUP);
@@ -591,7 +590,6 @@ hide_popup_menu (gint nbr, gboolean animation)
   gtk_widget_hide (popup_menus[nbr].popup_toplevel);
   gdk_window_withdraw ((popup_menus[nbr].popup_toplevel)->window);
 
-  my_flush_events ();
   gettimeofday (&old_tv, &tz);
 
   if (anim)
@@ -642,7 +640,7 @@ update_popup_entries (gint nbr)
 void
 update_popup_size (void)
 {
-  int i, j;
+  gint i, j;
 
   for (i = 0; i < NBPOPUPS; i++)
     {
@@ -865,8 +863,18 @@ get_popup_entry_icon (gint menu, gint entry)
   return popup_menus[menu].popup_buttons[entry].pixfile;
 }
 
-int
+gint
 get_popup_menu_entries (gint menu)
 {
   return popup_menus[menu].entries;
 }
+
+/* Added by Jason Litowitz */
+void
+hide_current_popup_menu ()
+{
+  if ((Current_Popup_Window != -1) && !(popup_menus[Current_Popup_Window].detach))
+    {
+      private_close_popup_button(Current_Popup_Window);
+    }
+}
