@@ -30,9 +30,10 @@
 #include <gtk/gtk.h>
 #include "popup.h"
 
-gint delete_popup_cb (GtkWidget * widget, GdkEvent * event, gpointer data);
+gboolean
+delete_popup_cb (GtkWidget * widget, GdkEvent * event, gpointer data);
 
-gint
+gboolean
 popup_entry_modify_cb (GtkWidget * widget,
 		       GdkEventButton * event, gpointer data);
 
@@ -57,4 +58,9 @@ popup_addicon_drag_data_received (GtkWidget * widget,
 				  gint y,
 				  GtkSelectionData * data,
 				  guint info, guint time, gpointer cbdata);
+
+/* Added by Jason Litowitz */
+void
+private_close_popup_button (gint menu);
+
 #endif
