@@ -29,6 +29,7 @@
 #include "screen.h"
 #include "my_string.h"
 #include "xfce.h"
+#include "xfwm.h"
 #include "xfce_main.h"
 #include "xfce-common.h"
 #include "configfile.h"
@@ -61,7 +62,8 @@ screen_ok_cb (GtkWidget * widget, gpointer data)
   s =
     cleanup ((char *)
 	     gtk_entry_get_text (GTK_ENTRY (screen_displayed_entry)));
-  set_gxfce_screen_label ((int) data, s);
+  set_gxfce_screen_label ((gint)((long) data), s);
+  apply_wm_desk_names (current_config.visible_screen);
   gtk_main_quit ();
   gtk_widget_hide (screen);
   writeconfig ();
