@@ -30,15 +30,11 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-void screen_cancel_cb( GtkWidget *widget,
-                     gpointer   data );
+void screen_cancel_cb (GtkWidget * widget, gpointer data);
 
 gboolean
-screen_delete_event( GtkWidget *widget,
-                   GdkEvent  *event,
-                   gpointer   data );
+screen_delete_event (GtkWidget * widget, GdkEvent * event, gpointer data);
 
-void screen_ok_cb( GtkWidget *widget,
-                     gpointer   data );
+void screen_ok_cb (GtkWidget * widget, gpointer data);
 
 #endif
