@@ -163,7 +163,7 @@ OpenICEConn (void)
 	gdk_input_add (IceConnectionNumber (SmcGetIceConnection (sm_conn)),
 		       GDK_INPUT_READ | GDK_INPUT_EXCEPTION,
 		       (GdkInputFunction) process_ice_messages,
-		       (gpointer)
+		       (gpointer) (long)
 		       IceConnectionNumber (SmcGetIceConnection (sm_conn)));
     }
 
