@@ -35,9 +35,14 @@
 #include "xpmext.h"
 #include "configfile.h"
 #include "xfwm.h"
+#include "popup.h"
 #include "gnome_protocol.h"
 #include "constant.h"
 
+#ifndef HAVE_SNPRINTF
+#include "snprintf.h"
+#endif
+
 #ifdef DMALLOC
 #  include "dmalloc.h"
 #endif
@@ -45,21 +50,24 @@
 void
 apply_pal_colortable (XFCE_palette * pal)
 {
-  gint i;
-
+  /*
   for (i = 0; i < NB_XFCE_COLORS; i++)
     {
       gtk_widget_set_style (color_buttons.setup_color_button_frame[i],
 			    pal->cm[i]);
       gtk_widget_set_style (color_buttons.setup_color_button[i], pal->cm[i]);
     }
+   */
   if ((pal->fnt) && strlen (pal->fnt))
     gtk_entry_set_text (GTK_ENTRY (setup_options.setup_font_xfce_entry),
 			pal->fnt);
   else
     gtk_entry_set_text (GTK_ENTRY (setup_options.setup_font_xfce_entry),
 			DEFAULTFONT);
+  gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (setup_options.setup_palette_engine_combo)->entry), 
+                      temp_pal->engine);
   gtk_entry_set_position (GTK_ENTRY (setup_options.setup_font_xfce_entry), 0);
+  apply_temp_gtkrc_file (pal, setup);
 }
 
 GtkWidget *
@@ -68,15 +76,18 @@ create_setup_colortable (GtkWidget * toplevel, XFCE_palette * pal)
   gint i;
 
   GtkWidget *setup_table;
+  char temp_name[16];
 
   setup_table = gtk_table_new (2, 4, FALSE);
   gtk_widget_set_name (setup_table, "setup_table");
   gtk_object_set_data (GTK_OBJECT (toplevel), "setup_table", setup_table);
   gtk_widget_show (setup_table);
   gtk_container_border_width (GTK_CONTAINER (setup_table), 5);
+  
 
   for (i = 0; i < NB_XFCE_COLORS; i++)
     {
+      snprintf (temp_name, 15, "temp_color%i", i);
       color_buttons.setup_color_button_frame[i] = gtk_frame_new (NULL);
       gtk_widget_set_name (color_buttons.setup_color_button_frame[i],
 			   "setup_color_button_frame");
@@ -88,8 +99,8 @@ create_setup_colortable (GtkWidget * toplevel, XFCE_palette * pal)
       gtk_frame_set_shadow_type (GTK_FRAME
 				 (color_buttons.setup_color_button_frame[i]),
 				 GTK_SHADOW_IN);
-      gtk_widget_set_style (color_buttons.setup_color_button_frame[i],
-			    pal->cm[i]);
+      /* gtk_widget_set_style (color_buttons.setup_color_button_frame[i],
+			    pal->cm[i]); */
       gtk_widget_show (color_buttons.setup_color_button_frame[i]);
       gtk_table_attach (GTK_TABLE (setup_table),
 			color_buttons.setup_color_button_frame[i], (i % 4),
@@ -98,11 +109,10 @@ create_setup_colortable (GtkWidget * toplevel, XFCE_palette * pal)
 			(GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
       color_buttons.setup_color_button[i] = gtk_button_new ();
-      gtk_widget_set_name (color_buttons.setup_color_button[i],
-			   "setup_color_button");
-      gtk_object_set_data (GTK_OBJECT (toplevel), "setup_color_button",
+      gtk_widget_set_name (color_buttons.setup_color_button[i], temp_name);
+      gtk_object_set_data (GTK_OBJECT (toplevel), temp_name,
 			   color_buttons.setup_color_button[i]);
-      gtk_widget_set_style (color_buttons.setup_color_button[i], pal->cm[i]);
+      /* gtk_widget_set_style (color_buttons.setup_color_button[i], pal->cm[i]); */
       gtk_widget_set_usize (color_buttons.setup_color_button[i], 0, 16);
       gtk_widget_show (color_buttons.setup_color_button[i]);
       gtk_container_add (GTK_CONTAINER
@@ -111,7 +121,7 @@ create_setup_colortable (GtkWidget * toplevel, XFCE_palette * pal)
 
       gtk_signal_connect (GTK_OBJECT (color_buttons.setup_color_button[i]),
 			  "clicked", GTK_SIGNAL_FUNC (color_button_cb),
-			  (gpointer) i);
+			  (gpointer)((long) i));
 
     }
   return setup_table;
@@ -129,6 +139,10 @@ create_setup (XFCE_palette * pal)
   GtkWidget *setup_upframe;
   GtkWidget *setup_loadframe;
   GtkWidget *setup_hbuttonbox;
+  GtkWidget *setup_engine_frame;
+  GtkWidget *setup_xcolors_frame;
+  GtkWidget *setup_engine_hbox;
+  GtkWidget *setup_engine_label;
   GtkWidget *setup_vbox3;
   GtkWidget *setup_tooltipsdelay_frame;
   GtkWidget *setup_tooltipsdelay_hbox;
@@ -179,11 +193,18 @@ create_setup (XFCE_palette * pal)
   GtkWidget *scrolled_window2;
   GtkWidget *scrolled_window3;
   GtkWidget *scrolled_window4;
+  GList *list_engines = NULL;
 
   GtkAccelGroup *accel_group;
 
   temp_pal = newpal ();
   copypal (temp_pal, pal);
+  /* Initialization of well known engines */
+  list_engines = g_list_append(list_engines, "");
+  list_engines = g_list_append(list_engines, "gtk");
+  list_engines = g_list_append(list_engines, "xfce");
+  list_engines = g_list_append(list_engines, "notif");
+  list_engines = g_list_append(list_engines, "redmond95");
 
   setup = gtk_window_new (GTK_WINDOW_DIALOG);
   gtk_widget_set_name (setup, "setup");
@@ -254,6 +275,64 @@ create_setup (XFCE_palette * pal)
   gtk_container_add (GTK_CONTAINER (setup_upframe),
 		     create_setup_colortable (setup, temp_pal));
 
+  setup_engine_frame = gtk_frame_new (NULL);
+  gtk_widget_set_name (setup_engine_frame, "setup_engine_frame");
+  gtk_object_set_data (GTK_OBJECT (setup), "setup_engine_frame",
+		       setup_engine_frame);
+  gtk_widget_show (setup_engine_frame);
+  gtk_container_border_width (GTK_CONTAINER (setup_engine_frame), 5);
+  gtk_box_pack_start (GTK_BOX (setup_vbox2), setup_engine_frame, FALSE, TRUE, 0);
+
+  setup_engine_hbox = gtk_hbox_new (FALSE, 0);
+  gtk_widget_set_name (setup_engine_hbox, "setup_engine_hbox");
+  gtk_object_set_data (GTK_OBJECT (setup), "setup_engine_hbox",
+		       setup_engine_hbox);
+  gtk_widget_show (setup_engine_hbox);
+  gtk_container_border_width (GTK_CONTAINER (setup_engine_hbox), 5);
+  gtk_container_add (GTK_CONTAINER (setup_engine_frame),
+		     setup_engine_hbox);
+
+  setup_engine_label =
+    gtk_label_new (_("Theme engine : "));
+  gtk_widget_set_name (setup_engine_label, "setup_engine_label");
+  gtk_object_set_data (GTK_OBJECT (setup), "setup_engine_label",
+		       setup_engine_label);
+  gtk_widget_show (setup_engine_label);
+  gtk_box_pack_start (GTK_BOX (setup_engine_hbox), setup_engine_label,
+		      FALSE, FALSE, 0);
+  gtk_label_set_justify (GTK_LABEL (setup_engine_label), GTK_JUSTIFY_RIGHT);
+
+  setup_options.setup_palette_engine_combo = gtk_combo_new ();
+  gtk_combo_set_popdown_strings (GTK_COMBO (setup_options.setup_palette_engine_combo), list_engines);
+  gtk_widget_set_name (setup_options.setup_palette_engine_combo, "setup_palette_engine_combo");
+  gtk_object_set_data (GTK_OBJECT (setup), "setup_palette_engine_combo",
+		       setup_options.setup_palette_engine_combo);
+  gtk_widget_show (setup_options.setup_palette_engine_combo);
+  gtk_editable_select_region (GTK_EDITABLE (GTK_COMBO (setup_options.setup_palette_engine_combo)->entry), 0,
+			      -1);
+  gtk_box_pack_start (GTK_BOX (setup_engine_hbox), setup_options.setup_palette_engine_combo, FALSE, FALSE, 0);
+  g_list_free (list_engines);
+
+  setup_xcolors_frame = gtk_frame_new (NULL);
+  gtk_widget_set_name (setup_xcolors_frame, "setup_xcolors_frame");
+  gtk_object_set_data (GTK_OBJECT (setup), "setup_xcolors_frame",
+		       setup_xcolors_frame);
+  gtk_widget_show (setup_xcolors_frame);
+  gtk_container_border_width (GTK_CONTAINER (setup_xcolors_frame), 5);
+  gtk_box_pack_start (GTK_BOX (setup_vbox2), setup_xcolors_frame, FALSE, TRUE, 0);
+
+  setup_options.setup_apply_xcolors_checkbutton =
+    gtk_check_button_new_with_label (_("Apply colors to all applications"));
+  gtk_widget_set_name (setup_options.setup_apply_xcolors_checkbutton,
+		       "setup_apply_xcolors_checkbutton");
+  gtk_object_set_data (GTK_OBJECT (setup), "setup_apply_xcolors_checkbutton",
+		       setup_options.setup_apply_xcolors_checkbutton);
+  gtk_widget_show (setup_options.setup_apply_xcolors_checkbutton);
+  gtk_container_add (GTK_CONTAINER (setup_xcolors_frame),
+		     setup_options.setup_apply_xcolors_checkbutton);
+  gtk_container_border_width (GTK_CONTAINER
+			      (setup_options.setup_apply_xcolors_checkbutton), 2);
+
   setup_loadframe = gtk_frame_new (NULL);
   gtk_widget_set_name (setup_loadframe, "setup_loadframe");
   gtk_object_set_data (GTK_OBJECT (setup), "setup_loadframe",
@@ -370,6 +449,19 @@ create_setup (XFCE_palette * pal)
   gtk_container_border_width (GTK_CONTAINER
 			      (setup_options.setup_tearoff_checkbutton), 2);
 
+  setup_options.setup_show_diagnostic_checkbutton =
+    gtk_check_button_new_with_label (_("Show subprocess diagnostic dialog"));
+  gtk_widget_set_name (setup_options.setup_show_diagnostic_checkbutton,
+		       "setup_show_diagnostic_checkbutton");
+  gtk_object_set_data (GTK_OBJECT (setup), "setup_show_diagnostic_checkbutton",
+		       setup_options.setup_show_diagnostic_checkbutton);
+  gtk_widget_show (setup_options.setup_show_diagnostic_checkbutton);
+  gtk_box_pack_start (GTK_BOX (setup_vbox3),
+		      setup_options.setup_show_diagnostic_checkbutton, FALSE, TRUE,
+		      0);
+  gtk_container_border_width (GTK_CONTAINER
+			      (setup_options.setup_show_diagnostic_checkbutton), 2);
+
   setup_clock_frame = gtk_frame_new (_("Clock"));
   gtk_widget_set_name (setup_clock_frame, "setup_clock_frame");
   gtk_object_set_data (GTK_OBJECT (setup), "setup_clock_frame",
@@ -490,7 +582,7 @@ create_setup (XFCE_palette * pal)
 			 GTK_JUSTIFY_RIGHT);
 
   setup_options.setup_numscreens_spinbutton_adj =
-    gtk_adjustment_new (4, 2, 10, 2, 2, 1);
+    gtk_adjustment_new (4, 0, 10, 2, 2, 1);
   setup_options.setup_numscreens_spinbutton =
     gtk_spin_button_new (GTK_ADJUSTMENT
 			 (setup_options.setup_numscreens_spinbutton_adj), 1,
@@ -1277,7 +1369,8 @@ create_setup (XFCE_palette * pal)
   gtk_container_border_width (GTK_CONTAINER (setup_options.setup_ok_button),
 			      5);
   GTK_WIDGET_SET_FLAGS (setup_options.setup_ok_button, GTK_CAN_DEFAULT);
-
+  gtk_widget_grab_default (setup_options.setup_ok_button);
+  
   setup_options.setup_apply_button = gtk_button_new_with_label (_("Apply"));
   gtk_widget_set_name (setup_options.setup_apply_button,
 		       "setup_apply_button");
@@ -1341,9 +1434,6 @@ create_setup (XFCE_palette * pal)
   gtk_signal_connect (GTK_OBJECT (setup), "delete_event",
 		      GTK_SIGNAL_FUNC (setup_delete_event), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (setup), "destroy",
-		      GTK_SIGNAL_FUNC (setup_cancel_cb), NULL);
-
   gtk_signal_connect (GTK_OBJECT (setup_options.setup_font_title_button),
 		      "clicked", GTK_SIGNAL_FUNC (xfwm_titlefont_cb), NULL);
 
@@ -1375,14 +1465,21 @@ create_setup (XFCE_palette * pal)
 void
 show_setup (XFCE_palette * pal)
 {
+  hide_current_popup_menu();
   copypal (temp_pal, pal);
-  apply_pal_colortable (temp_pal);
+  apply_pal_colortable (temp_pal);                                               
   gtk_window_set_modal (GTK_WINDOW (setup), TRUE);
   prev_panel_icon_size = current_config.select_icon_size;
   prev_popup_icon_size = current_config.popup_icon_size;
   prev_visible_screen = current_config.visible_screen;
   prev_visible_popup = current_config.visible_popup;
+  prev_apply_xcolors = current_config.apply_xcolors;
   pal_changed = FALSE;
+  gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (setup_options.setup_palette_engine_combo)->entry), 
+                      temp_pal->engine);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+				(setup_options.setup_apply_xcolors_checkbutton),
+				(current_config.apply_xcolors != 0));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 				(setup_options.setup_repaint_checkbutton),
 				(current_config.colorize_root != 0));
@@ -1400,6 +1497,9 @@ show_setup (XFCE_palette * pal)
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 				(setup_options.setup_tearoff_checkbutton),
 				(current_config.detach_menu != 0));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+				(setup_options.setup_show_diagnostic_checkbutton),
+				(current_config.show_diagnostic != 0));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 				(setup_options.setup_panelicons_large),
 				(current_config.select_icon_size == 2));
@@ -1538,6 +1638,9 @@ void
 get_setup_values (void)
 {
   char *s1, *s2, *s3;
+  current_config.apply_xcolors =
+    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
+				  (setup_options.setup_apply_xcolors_checkbutton));
   current_config.colorize_root =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
 				  (setup_options.setup_repaint_checkbutton));
@@ -1547,6 +1650,9 @@ get_setup_values (void)
   current_config.detach_menu =
     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
 				  (setup_options.setup_tearoff_checkbutton));
+  current_config.show_diagnostic =
+    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
+				  (setup_options.setup_show_diagnostic_checkbutton));
   current_config.select_icon_size =
     2 *
     (gtk_toggle_button_get_active
