@@ -34,10 +34,13 @@ typedef struct
   GtkWidget *setup_palette_load_button;
   GtkWidget *setup_palette_save_button;
   GtkWidget *setup_palette_default_button;
+  GtkWidget *setup_palette_engine_combo;
   GtkWidget *setup_repaint_checkbutton;
   GtkWidget *setup_gradient_checkbutton;
   GtkWidget *setup_tearoff_checkbutton;
   GtkWidget *setup_digital_clock_checkbutton;
+  GtkWidget *setup_apply_xcolors_checkbutton;
+  GtkWidget *setup_show_diagnostic_checkbutton;
   GtkWidget *setup_hrs_mode_checkbutton;
   GtkObject *setup_tooltipsdelay_spinbutton_adj;
   GtkWidget *setup_tooltipsdelay_spinbutton;
@@ -87,10 +90,11 @@ XFCE_palette *temp_pal;
 color_button color_buttons;
 setup_option setup_options;
 
-int prev_panel_icon_size;
-int prev_popup_icon_size;
-int prev_visible_screen;
-int prev_visible_popup;
+gshort prev_panel_icon_size;
+gshort prev_popup_icon_size;
+gshort prev_visible_screen;
+gshort prev_visible_popup;
+gshort prev_apply_xcolors;
 gboolean pal_changed;
 
 void apply_pal_colortable (XFCE_palette * pal);
