@@ -52,8 +52,7 @@
 void
 color_button_cb (GtkWidget * widget, gpointer data)
 {
-  open_colorselect (temp_pal, (int) data);
-  makepalstyle (temp_pal, (int) data);
+  open_colorselect (temp_pal, (gint)((long) data));
   apply_pal_colortable (temp_pal);
   pal_changed = TRUE;
 }
@@ -61,22 +60,34 @@ color_button_cb (GtkWidget * widget, gpointer data)
 void
 setup_ok_cb (GtkWidget * widget, gpointer data)
 {
+  gchar *engine;
   cursor_wait (setup);
+  get_setup_values ();
+  engine = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (setup_options.setup_palette_engine_combo)->entry));
+  if (strcmp (engine, temp_pal->engine))
+    {
+      set_engine (temp_pal, engine);
+      pal_changed = TRUE;
+    }
   if (pal_changed)
     {
       copyvaluepal (pal, temp_pal);
       savepal (pal);
-      create_gtkrc_file (pal);
-      applypal (pal, gxfce);
+      create_gtkrc_file (pal, NULL);
+      /* applypal (pal, gxfce); */
       applypal_to_all ();
+      apply_xpalette (pal, current_config.apply_xcolors);
+    }
+  else if (prev_apply_xcolors != current_config.apply_xcolors)
+    {
+      apply_xpalette (pal, current_config.apply_xcolors);
     }
-  get_setup_values ();
   update_delay_tooltips (current_config.tooltipsdelay);
   update_gxfce_clock ();
   if (prev_visible_screen != current_config.visible_screen)
     {
       update_gxfce_screen_buttons (current_config.visible_screen);
-      gnome_set_desk_count (current_config.visible_screen);
+      gnome_set_desk_count (current_config.visible_screen ? current_config.visible_screen : 1);
     }
   if (current_config.colorize_root)
     ApplyRootColor (pal, (current_config.gradient_root != 0),
@@ -106,22 +117,34 @@ setup_ok_cb (GtkWidget * widget, gpointer data)
 void
 setup_apply_cb (GtkWidget * widget, gpointer data)
 {
+  gchar *engine;
   cursor_wait (setup);
+  get_setup_values ();
+  engine = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (setup_options.setup_palette_engine_combo)->entry));
+  if (strcmp (engine, temp_pal->engine))
+    {
+      set_engine (temp_pal, engine);
+      pal_changed = TRUE;
+    }
   if (pal_changed)
     {
       copyvaluepal (pal, temp_pal);
       savepal (pal);
-      create_gtkrc_file (pal);
-      applypal (pal, gxfce);
+      create_gtkrc_file (pal, NULL);
       applypal_to_all ();
+      apply_xpalette (pal, current_config.apply_xcolors);
+    }
+  else if (prev_apply_xcolors != current_config.apply_xcolors)
+    {
+      apply_xpalette (pal, current_config.apply_xcolors);
+      prev_apply_xcolors = current_config.apply_xcolors;
     }
-  get_setup_values ();
   update_delay_tooltips (current_config.tooltipsdelay);
   update_gxfce_clock ();
   if (prev_visible_screen != current_config.visible_screen)
     {
       update_gxfce_screen_buttons (current_config.visible_screen);
-      gnome_set_desk_count (current_config.visible_screen);
+      gnome_set_desk_count (current_config.visible_screen ? current_config.visible_screen : 1);
     }
   if (current_config.colorize_root)
     ApplyRootColor (pal, (current_config.gradient_root != 0),
@@ -168,10 +191,7 @@ setup_delete_event (GtkWidget * widget, GdkEvent * event, gpointer data)
 void
 setup_default_cb (GtkWidget * widget, gpointer data)
 {
-  int i;
   defpal (temp_pal);
-  for (i = 0; i < NB_XFCE_COLORS; i++)
-    makepalstyle (temp_pal, i);
   apply_pal_colortable (temp_pal);
   pal_changed = TRUE;
 }
@@ -180,13 +200,10 @@ void
 setup_loadpal_cb (GtkWidget * widget, gpointer data)
 {
   char *t;
-  int i;
 
   t = open_fileselect (build_path (XFCE_PAL));
   if (t)
     loadnamepal (temp_pal, t);
-  for (i = 0; i < NB_XFCE_COLORS; i++)
-    makepalstyle (temp_pal, i);
   apply_pal_colortable (temp_pal);
   pal_changed = TRUE;
 }
