@@ -52,13 +52,15 @@ create_startup ()
   GtkWidget *startup_logo_pixmap;
   GtkWidget *startup_wait_label;
 
-  startup = gtk_window_new (GTK_WINDOW_POPUP);
+  startup = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_widget_set_name (startup, "startup");
   gtk_object_set_data (GTK_OBJECT (startup), "startup", startup);
   gtk_widget_set_usize (startup, 280, 160);
   gtk_window_set_title (GTK_WINDOW (startup), _("Startup"));
   gtk_window_position (GTK_WINDOW (startup), GTK_WIN_POS_CENTER);
   gtk_window_set_policy (GTK_WINDOW (startup), FALSE, FALSE, FALSE);
+  gtk_widget_realize (startup);
+  gdk_window_set_decorations (startup->window, 0);
 
   startup_mainframe = gtk_frame_new (NULL);
   gtk_widget_set_name (startup_mainframe, "startup_mainframe");
