@@ -65,7 +65,14 @@ char *screen_names[] =
   N_("Eleven"), N_("Twelve"), N_("Thirteen"), N_("Fourteen"), N_("Fifteen"),
   N_("Sixteen"), N_("Seventeen"), N_("Eighteen"), N_("Nineteen"), N_("Twenty")
 };
-int screen_colors[] = { 2, 5, 4, 6 };
+
+gint screen_colors[] = { 2, 5, 4, 6 };
+
+char *screen_class[] = { "gxfce_color2", 
+                         "gxfce_color5", 
+                         "gxfce_color4", 
+                         "gxfce_color6"
+};
 
 enum
 {
@@ -129,7 +136,7 @@ update_gxfce_clock (void)
 }
 
 void
-update_gxfce_coord (GtkWidget * toplevel, int *x, int *y)
+update_gxfce_coord (GtkWidget * toplevel, gint *x, gint *y)
 {
   GtkRequisition requisition;
 
@@ -148,59 +155,89 @@ update_gxfce_coord (GtkWidget * toplevel, int *x, int *y)
 void
 update_gxfce_size (void)
 {
-  int i;
+  gint i;
+  gint size    = current_config.select_icon_size;
 
   for (i = 0; i < NBPOPUPS; i++)
     gtk_widget_set_usize (popup_buttons.popup_button[i], PANEL_ICON_SIZE + 4,
-			  16);
+			  TOPHEIGHT);
 
   for (i = 0; i < NBSELECTS; i++)
-    gtk_widget_set_usize (select_buttons.select_button[i], PANEL_ICON_SIZE,
-			  PANEL_ICON_SIZE);
+    {
+      gtk_widget_set_usize (select_buttons.select_button[i], PANEL_ICON_SIZE,
+			    PANEL_ICON_SIZE);
+      gtk_container_border_width (GTK_CONTAINER
+			        (select_buttons.select_button[i]), ((size == 0) ? 0 : 2));
+    }
 
-  gtk_widget_set_usize (gxfce_move_left_pixmap, PANEL_ICON_SIZE - 16 + 4, 16);
+  gtk_widget_set_usize (gxfce_move_left_pixmap, PANEL_ICON_SIZE - 16 + 4, TOPHEIGHT);
   gtk_widget_set_usize (gxfce_move_right_pixmap, PANEL_ICON_SIZE - 16 + 4,
-			16);
+			TOPHEIGHT);
 
   gtk_widget_set_usize (gxfce_clock_event, PANEL_ICON_SIZE, PANEL_ICON_SIZE);
+  change_gxfce_screen_buttons_width (SCREEN_BUTTON_WIDTH / ((size == 0) ? 2 : 1));
+  /* 
+    Reorganize the widgets when smallest size is selected
+   */
+  reorganize_table ((GtkTable *) (screen_buttons.desktops_table), 
+                    screen_buttons.screen_frame, 
+                    NBSCREENS, 
+                    (size == 0) ? 1 : 2);
+  reorganize_table ((GtkTable *) (gxfce_leftbuttons_table), 
+                    gxfce_leftbuttons, 
+                    2, 
+                    (size == 0) ? 1 : 2);
+  reorganize_table ((GtkTable *) (gxfce_rightbuttons_table), 
+                    gxfce_rightbuttons, 
+                    2, 
+                    (size == 0) ? 1 : 2);
+  gtk_container_border_width (GTK_CONTAINER (gxfce_clock_event), 
+                              ((size == 0) ? 0 : 5));
 
   setup_icon ();
 }
 
 GtkWidget *
-create_gxfce_popup_button (GtkWidget * toplevel, XFCE_palette * pal, gint nbr)
+create_gxfce_popup_button (GtkWidget * toplevel, gint nbr)
 {
   popup_buttons.popup_button[nbr] = gtk_toggle_button_new ();
-  gtk_widget_set_name (popup_buttons.popup_button[nbr], "gxfce_popup_panel");
+#ifndef OLD_STYLE
+  gtk_button_set_relief ((GtkButton *) popup_buttons.popup_button[nbr],
+			 GTK_RELIEF_NONE);
+  gtk_widget_set_name (popup_buttons.popup_button[nbr], "gxfce_color7");
+#else
+  gtk_widget_set_name (popup_buttons.popup_button[nbr], "gxfce_color1");
+#endif			 
+
   gtk_object_set_data (GTK_OBJECT (toplevel), "gxfce_popup_panel",
 		       popup_buttons.popup_button[nbr]);
   gtk_widget_show (popup_buttons.popup_button[nbr]);
   gtk_widget_set_usize (popup_buttons.popup_button[nbr], PANEL_ICON_SIZE + 4,
-			16);
-  gtk_widget_set_style (popup_buttons.popup_button[nbr], pal->cm[1]);
+			TOPHEIGHT);
 
   popup_buttons.popup_pixmap[nbr] =
     MyCreateFromPixmapData (popup_buttons.popup_button[nbr], minbutup);
   if (popup_buttons.popup_pixmap[nbr] == NULL)
     g_error (_("Couldn't create pixmap"));
   gtk_widget_set_name (popup_buttons.popup_pixmap[nbr],
-		       "gxfce_popup_button_pixmap");
+		       "gxfce_color1");
   gtk_object_set_data (GTK_OBJECT (toplevel), "gxfce_popup_button_pixmap",
 		       popup_buttons.popup_pixmap[nbr]);
   gtk_widget_show (popup_buttons.popup_pixmap[nbr]);
   gtk_container_add (GTK_CONTAINER (popup_buttons.popup_button[nbr]),
 		     popup_buttons.popup_pixmap[nbr]);
-  gtk_widget_set_style (popup_buttons.popup_pixmap[nbr], pal->cm[1]);
   gtk_signal_connect (GTK_OBJECT (popup_buttons.popup_button[nbr]), "clicked",
-		      GTK_SIGNAL_FUNC (popup_cb), (gpointer) nbr);
+		      GTK_SIGNAL_FUNC (popup_cb), (gpointer)((long) nbr));
 
   return popup_buttons.popup_button[nbr];
 }
 
 GtkWidget *
-create_gxfce_select_button (GtkWidget * toplevel, XFCE_palette * pal,
+create_gxfce_select_button (GtkWidget * toplevel,
 			    gint nbr)
 {
+  gint size = current_config.select_icon_size;
+
   select_buttons.select_button[nbr] = gtk_button_new ();
   gtk_widget_set_name (select_buttons.select_button[nbr],
 		       "gxfce_select_button");
@@ -212,8 +249,8 @@ create_gxfce_select_button (GtkWidget * toplevel, XFCE_palette * pal,
   gtk_widget_set_usize (select_buttons.select_button[nbr], PANEL_ICON_SIZE,
 			PANEL_ICON_SIZE);
   gtk_container_border_width (GTK_CONTAINER
-			      (select_buttons.select_button[nbr]), 2);
-  /* gtk_widget_set_style(select_buttons.select_button[nbr], pal->cm[7]); */
+			      (select_buttons.select_button[nbr]), ((size == 0) ? 1 : 2));
+
   select_buttons.select_tooltips[nbr] =
     my_tooltips_new (current_config.tooltipsdelay);
   gtk_tooltips_set_tip (select_buttons.select_tooltips[nbr],
@@ -230,7 +267,7 @@ create_gxfce_select_button (GtkWidget * toplevel, XFCE_palette * pal,
   gtk_signal_connect (GTK_OBJECT (select_buttons.select_button[nbr]),
 		      "drag_data_received",
 		      GTK_SIGNAL_FUNC (select_drag_data_received),
-		      (gpointer) nbr);
+		      (gpointer)((long) nbr));
 
   gtk_widget_set_events (select_buttons.select_button[nbr],
 			 gtk_widget_get_events (select_buttons.select_button
@@ -238,9 +275,11 @@ create_gxfce_select_button (GtkWidget * toplevel, XFCE_palette * pal,
 
   gtk_signal_connect (GTK_OBJECT (select_buttons.select_button[nbr]),
 		      "button_press_event",
-		      GTK_SIGNAL_FUNC (select_modify_cb), (gpointer) nbr);
+		      GTK_SIGNAL_FUNC (select_modify_cb), 
+                      (gpointer)((long) nbr));
   gtk_signal_connect (GTK_OBJECT (select_buttons.select_button[nbr]),
-		      "clicked", GTK_SIGNAL_FUNC (select_cb), (gpointer) nbr);
+		      "clicked", GTK_SIGNAL_FUNC (select_cb), 
+                      (gpointer)((long) nbr));
 
   select_buttons.select_pixmap[nbr] =
     MyCreateFromPixmapData (select_buttons.select_button[nbr], empty);
@@ -275,13 +314,13 @@ create_gxfce_popup_select_group (GtkWidget * toplevel, GtkWidget * popup,
 }
 
 char *
-get_gxfce_screen_label (int i)
+get_gxfce_screen_label (gint i)
 {
   return (char *) GTK_LABEL (screen_buttons.screen_label[i])->label;
 }
 
 void
-set_gxfce_screen_label (int i, char *label)
+set_gxfce_screen_label (gint i, char *label)
 {
   if (label && strlen (label))
     gtk_label_set_text (GTK_LABEL (screen_buttons.screen_label[i]), label);
@@ -290,20 +329,20 @@ set_gxfce_screen_label (int i, char *label)
 			_(screen_names[i]));
 }
 
-int
-get_screen_color (int idx)
+gint
+get_screen_color (gint idx)
 {
   return screen_colors[((idx >= 0) ? idx : 0) % 4];
 }
 
 GtkWidget *
-create_gxfce_screen_buttons (GtkWidget * toplevel, XFCE_palette * pal)
+create_gxfce_screen_buttons (GtkWidget * toplevel)
 {
   GSList *desktops_table_group = NULL;
   GtkWidget *desktops_table;
   gint i;
 
-  desktops_table = gtk_table_new (2, ((NBSCREENS + 1) / 2), FALSE);
+  desktops_table = gtk_table_new (2, NBSCREENS, FALSE);
 
   for (i = 0; i < NBSCREENS; i++)
     {
@@ -318,15 +357,15 @@ create_gxfce_screen_buttons (GtkWidget * toplevel, XFCE_palette * pal)
 				  (screen_buttons.screen_frame[i]), 2);
       screen_buttons.screen_button[i] =
 	gtk_radio_button_new (desktops_table_group);
+      gtk_widget_set_usize (screen_buttons.screen_button[i], SCREEN_BUTTON_WIDTH, 0);
       desktops_table_group =
 	gtk_radio_button_group (GTK_RADIO_BUTTON
 				(screen_buttons.screen_button[i]));
-      gtk_widget_set_name (screen_buttons.screen_button[i], screen_names[i]);
+      gtk_widget_set_name (screen_buttons.screen_button[i], screen_class[i % 4]);
       gtk_object_set_data (GTK_OBJECT (toplevel), screen_names[i],
 			   screen_buttons.screen_button[i]);
       gtk_button_set_relief ((GtkButton *) screen_buttons.screen_button[i],
 			     GTK_RELIEF_HALF);
-      gtk_widget_set_usize (screen_buttons.screen_button[i], 0, 0);
       gtk_widget_show (screen_buttons.screen_button[i]);
       gtk_container_add (GTK_CONTAINER (screen_buttons.screen_frame[i]),
 			 screen_buttons.screen_button[i]);
@@ -340,7 +379,7 @@ create_gxfce_screen_buttons (GtkWidget * toplevel, XFCE_palette * pal)
 			screen_buttons.screen_frame[i], (i / 2), (i / 2) + 1,
 			(i % 2), (i % 2) + 1,
 			(GtkAttachOptions) GTK_EXPAND | GTK_FILL | GTK_SHRINK,
-			(GtkAttachOptions) GTK_EXPAND | GTK_FILL | GTK_SHRINK,
+			(GtkAttachOptions) GTK_EXPAND | GTK_SHRINK,
 			0, 0);
       gtk_container_border_width (GTK_CONTAINER
 				  (screen_buttons.screen_button[i]), 0);
@@ -349,33 +388,60 @@ create_gxfce_screen_buttons (GtkWidget * toplevel, XFCE_palette * pal)
 				    (i == 0));
       gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON
 				  (screen_buttons.screen_button[i]), FALSE);
-      /* gtk_widget_set_style(screen_buttons.screen_frame[i], pal->cm[7]); */
-      gtk_widget_set_style (screen_buttons.screen_button[i],
-			    pal->cm[get_screen_color (i)]);
-      gtk_widget_set_style (screen_buttons.screen_label[i],
-			    pal->cm[get_screen_color (i)]);
+      gtk_widget_set_name (screen_buttons.screen_button[i], screen_class[i % 4]);
+
       gtk_widget_set_events (screen_buttons.screen_button[i],
 			     gtk_widget_get_events
 			     (screen_buttons.screen_button[i]) |
 			     GDK_BUTTON3_MASK);
       gtk_signal_connect (GTK_OBJECT (screen_buttons.screen_button[i]),
 			  "button_press_event",
-			  GTK_SIGNAL_FUNC (screen_modify_cb), (gpointer) i);
+			  GTK_SIGNAL_FUNC (screen_modify_cb), 
+                          (gpointer)((long) i));
       gtk_signal_connect (GTK_OBJECT (screen_buttons.screen_button[i]),
 			  "clicked", GTK_SIGNAL_FUNC (screen_cb),
-			  (gpointer) i);
+			  (gpointer)((long) i));
     }
   return desktops_table;
 }
 
+void reorganize_table (GtkTable *tbl, GtkWidget **w, guint nitems, guint rows)
+{
+  GtkTableChild *child;
+  GList *tmp;
+  guint i;
+  
+  if ((rows < 1) || (rows > 2))
+    return;
+
+  for (i = 0; i < nitems; i++)
+    {
+      g_return_if_fail (GTK_IS_WIDGET (w[i]));
+      child = NULL;
+      for (tmp = tbl->children; tmp != NULL; tmp = tmp->next) 
+        {
+          child = (GtkTableChild *)tmp->data;
+          g_return_if_fail (GTK_IS_WIDGET (child->widget));
+          if (GTK_WIDGET (child->widget) == GTK_WIDGET (w[i]))
+              break;
+        }
+      g_return_if_fail (child != NULL);
+      child->left_attach   = (i / rows);
+      child->right_attach  = (i / rows) + 1;
+      child->top_attach    = (i % rows);
+      child->bottom_attach = (i % rows) + 1;
+    }
+  gtk_widget_queue_resize(GTK_WIDGET(tbl));
+}
+
 void
 update_gxfce_screen_buttons (gint visible)
 {
   gint i, true_visible;
 
   true_visible = ((visible + 1) / 2) * 2;
-  if (true_visible < 2)
-    true_visible = 2;
+  if (true_visible < 0)
+    true_visible = 0;
   if (true_visible > 10)
     true_visible = 10;
   for (i = 0; i < true_visible; i++)
@@ -386,11 +452,20 @@ update_gxfce_screen_buttons (gint visible)
     {
       gtk_widget_hide (screen_buttons.screen_frame[i]);
     }
-  gtk_widget_set_usize (screen_buttons.gxfce_central_frame,
-			80 + 40 * true_visible, 0);
   update_config_screen_visible (true_visible);
 }
 
+void
+change_gxfce_screen_buttons_width (guint width)
+{
+  gint i;
+
+  for (i = 0; i < NBSCREENS; i++)
+    {
+      gtk_widget_set_usize (screen_buttons.screen_button[i], width, 0);
+    }
+}
+
 void
 update_gxfce_popup_buttons (gint visible)
 {
@@ -408,7 +483,7 @@ update_gxfce_popup_buttons (gint visible)
 }
 
 GtkWidget *
-create_gxfce (XFCE_palette * pal)
+create_gxfce (XFCE_palette *pal)
 {
   GtkWidget *gxfce;
   GtkWidget *gxfce_mainframe;
@@ -424,12 +499,9 @@ create_gxfce (XFCE_palette * pal)
   GtkTooltips *gxfce_clock_tooltip;
   GtkWidget *gxfce_central_vbox;
   GtkWidget *gxfce_central_hbox;
-  GtkWidget *gxfce_central_vbox_left;
-  GtkWidget *desktops_table;
   GtkWidget *gxfce_info;
   GtkWidget *gxfce_info_pixmap;
   GtkTooltips *gxfce_info_tooltip;
-  GtkWidget *gxfce_central_vbox_right;
   GtkWidget *gxfce_setup;
   GtkWidget *gxfce_setup_pixmap;
   GtkTooltips *gxfce_setup_tooltip;
@@ -443,8 +515,8 @@ create_gxfce (XFCE_palette * pal)
   GtkWidget *gxfce_iconify_button;
   GtkWidget *gxfce_iconify_pixmap;
 
-  int i;
-  int nbselects = NBSELECTS;
+  gint i;
+  gint nbselects = NBSELECTS;
 
   gxfce = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_policy (GTK_WINDOW (gxfce), FALSE, FALSE, TRUE);
@@ -453,7 +525,6 @@ create_gxfce (XFCE_palette * pal)
   gtk_window_set_title (GTK_WINDOW (gxfce), "XFce Main Panel");
   gtk_widget_realize (gxfce);
   gdk_window_set_decorations (gxfce->window, 0);
-  /* gtk_widget_set_style(gxfce, pal->cm[7]);  */
 
   gxfce_mainframe = gtk_frame_new (NULL);
   gtk_widget_set_name (gxfce_mainframe, "gxfce_mainframe");
@@ -462,7 +533,6 @@ create_gxfce (XFCE_palette * pal)
   gtk_widget_show (gxfce_mainframe);
   gtk_container_add (GTK_CONTAINER (gxfce), gxfce_mainframe);
   gtk_frame_set_shadow_type (GTK_FRAME (gxfce_mainframe), GTK_SHADOW_OUT);
-  /* gtk_widget_set_style(gxfce_mainframe, pal->cm[7]); */
 
   gxfce_hbox1 = gtk_hbox_new (FALSE, 0);
   gtk_widget_set_name (gxfce_hbox1, "gxfce_hbox1");
@@ -470,7 +540,11 @@ create_gxfce (XFCE_palette * pal)
   gtk_widget_show (gxfce_hbox1);
   gtk_container_add (GTK_CONTAINER (gxfce_mainframe), gxfce_hbox1);
   gtk_widget_set_usize (gxfce_hbox1, 0, 0);
+#ifndef OLD_STYLE
+  gtk_container_border_width (GTK_CONTAINER (gxfce_hbox1), 0);
+#else
   gtk_container_border_width (GTK_CONTAINER (gxfce_hbox1), 2);
+#endif
 
   gxfce_hbox2 = gtk_hbox_new (FALSE, 0);
   gtk_widget_set_name (gxfce_hbox2, "gxfce_hbox2");
@@ -492,58 +566,69 @@ create_gxfce (XFCE_palette * pal)
   gtk_widget_set_usize (gxfce_hbox_moveleft, 0, 0);
 
   gxfce_close_button = gtk_button_new ();
-  gtk_widget_set_name (gxfce_close_button, "gxfce_close_button");
+#ifndef OLD_STYLE
+  gtk_button_set_relief ((GtkButton *) gxfce_close_button,
+			 GTK_RELIEF_NONE);
+  gtk_widget_set_name (gxfce_close_button, "gxfce_color7");
+#else
+  gtk_widget_set_name (gxfce_close_button, "gxfce_color1");
+#endif
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_close_button",
 		       gxfce_close_button);
   gtk_widget_show (gxfce_close_button);
   gtk_box_pack_start (GTK_BOX (gxfce_hbox_moveleft), gxfce_close_button, TRUE,
 		      TRUE, 0);
-  gtk_widget_set_usize (gxfce_close_button, 16, 16);
-  gtk_widget_set_style (gxfce_close_button, pal->cm[1]);
+  gtk_widget_set_usize (gxfce_close_button, 16, TOPHEIGHT);
 
   gxfce_close_pixmap = MyCreateFromPixmapData (gxfce_close_button, closepix);
   if (gxfce_close_pixmap == NULL)
     g_error (_("Couldn't create pixmap"));
-  gtk_widget_set_name (gxfce_close_pixmap, "gxfce_close_pixmap");
+  gtk_widget_set_name (gxfce_close_pixmap, "gxfce_color1");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_close_pixmap",
 		       gxfce_close_pixmap);
   gtk_widget_show (gxfce_close_pixmap);
   gtk_container_add (GTK_CONTAINER (gxfce_close_button), gxfce_close_pixmap);
-  gtk_widget_set_style (gxfce_close_button, pal->cm[1]);
 
   gxfce_move_frame_left = gtk_frame_new (NULL);
-  gtk_widget_set_name (gxfce_move_frame_left, "gxfce_move_frame_left");
+#ifndef OLD_STYLE
+  gtk_frame_set_shadow_type (GTK_FRAME (gxfce_move_frame_left), 
+                             GTK_SHADOW_NONE);
+  gtk_widget_set_name (gxfce_move_frame_left, "gxfce_color7");
+#else
+  gtk_frame_set_shadow_type (GTK_FRAME (gxfce_move_frame_left),
+			     GTK_SHADOW_OUT);
+  gtk_widget_set_name (gxfce_move_frame_left, "gxfce_color1");
+#endif
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_move_frame_left",
 		       gxfce_move_frame_left);
   gtk_widget_show (gxfce_move_frame_left);
   gtk_box_pack_start (GTK_BOX (gxfce_hbox_moveleft), gxfce_move_frame_left,
 		      TRUE, TRUE, 0);
-  gtk_widget_set_usize (gxfce_move_frame_left, 0, 16);
-  gtk_frame_set_shadow_type (GTK_FRAME (gxfce_move_frame_left),
-			     GTK_SHADOW_OUT);
-  gtk_widget_set_style (gxfce_move_frame_left, pal->cm[1]);
+  gtk_widget_set_usize (gxfce_move_frame_left, 0, TOPHEIGHT);
 
   gxfce_move_event_left = gtk_event_box_new ();
-  gtk_widget_set_name (gxfce_move_event_left, "gxfce_move_event_left");
+#ifndef OLD_STYLE
+  gtk_widget_set_name (gxfce_move_event_left, "gxfce_color7");
+#else
+  gtk_widget_set_name (gxfce_move_event_left, "gxfce_color1");
+#endif
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_move_event_left",
 		       gxfce_move_event_left);
   gtk_widget_show (gxfce_move_event_left);
   gtk_container_add (GTK_CONTAINER (gxfce_move_frame_left),
 		     gxfce_move_event_left);
-  gtk_widget_set_style (gxfce_move_event_left, pal->cm[1]);
 
   gxfce_move_left_pixmap =
     MyCreateFromPixmapData (gxfce_move_event_left, handle);
   if (gxfce_move_left_pixmap == NULL)
     g_error (_("Couldn't create pixmap"));
-  gtk_widget_set_name (gxfce_move_left_pixmap, "gxfce_move_left_pixmap");
+  gtk_widget_set_name (gxfce_move_left_pixmap, "gxfce_color1");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_move_left_pixmap",
 		       gxfce_move_left_pixmap);
   gtk_widget_show (gxfce_move_left_pixmap);
   gtk_container_add (GTK_CONTAINER (gxfce_move_event_left),
 		     gxfce_move_left_pixmap);
-  gtk_widget_set_usize (gxfce_move_left_pixmap, PANEL_ICON_SIZE - 16 + 4, 16);
-  gtk_widget_set_style (gxfce_move_left_pixmap, pal->cm[1]);
+  gtk_widget_set_usize (gxfce_move_left_pixmap, PANEL_ICON_SIZE - 16 + 4, TOPHEIGHT);
 
   gxfce_clock_event = gtk_event_box_new ();
   gtk_widget_set_name (gxfce_clock_event, "gxfce_clock_event");
@@ -551,7 +636,6 @@ create_gxfce (XFCE_palette * pal)
 		       gxfce_clock_event);
   gtk_container_border_width (GTK_CONTAINER (gxfce_clock_event), 5);
   gtk_widget_show (gxfce_clock_event);
-  /* gtk_widget_set_style(gxfce_clock_event, pal->cm[7]); */
 
   gxfce_clock_frame = gtk_frame_new (NULL);
   gtk_widget_set_name (gxfce_clock_frame, "gxfce_clock_frame");
@@ -562,7 +646,7 @@ create_gxfce (XFCE_palette * pal)
 			     GTK_SHADOW_ETCHED_IN);
   gtk_container_border_width (GTK_CONTAINER (gxfce_clock_frame), 0);
   gtk_widget_set_usize (gxfce_clock_frame, PANEL_ICON_SIZE, PANEL_ICON_SIZE);
-  /* gtk_widget_set_style(gxfce_clock_frame, pal->cm[7]); */
+
   gtk_widget_show (gxfce_clock_frame);
   gxfce_clock_tooltip = my_tooltips_new (current_config.tooltipsdelay);
   gtk_tooltips_set_tip (gxfce_clock_tooltip, gxfce_clock_event, "",
@@ -575,7 +659,7 @@ create_gxfce (XFCE_palette * pal)
 
   gxfce_clock = my_gtk_clock_new ();
   gtk_container_add (GTK_CONTAINER (gxfce_clock_frame), gxfce_clock);
-  gtk_widget_set_style (gxfce_clock, pal->cm[2]);
+  gtk_widget_set_name (gxfce_clock, "gxfce_color2");
   my_gtk_clock_set_relief (MY_GTK_CLOCK (gxfce_clock), FALSE);
   my_gtk_clock_show_secs (MY_GTK_CLOCK (gxfce_clock), FALSE);
   my_gtk_clock_show_ampm (MY_GTK_CLOCK (gxfce_clock), FALSE);
@@ -596,9 +680,9 @@ create_gxfce (XFCE_palette * pal)
 			  popup_buttons.popup_vbox[i] =
 			  create_gxfce_popup_select_group (gxfce,
 							   create_gxfce_popup_button
-							   (gxfce, pal, i),
+							   (gxfce, i),
 							   create_gxfce_select_button
-							   (gxfce, pal,
+							   (gxfce,
 							    ((i == 6) ?
 							     NBPOPUPS : i))),
 			  TRUE, TRUE, 0);
@@ -613,7 +697,6 @@ create_gxfce (XFCE_palette * pal)
   gtk_widget_show (gxfce_central_vbox);
   gtk_box_pack_start (GTK_BOX (gxfce_hbox1), gxfce_central_vbox, TRUE, TRUE,
 		      0);
-  /* gtk_widget_set_style(gxfce_central_vbox, pal->cm[7]); */
 
   screen_buttons.gxfce_central_frame = gtk_frame_new (NULL);
   gtk_widget_set_name (screen_buttons.gxfce_central_frame,
@@ -624,10 +707,13 @@ create_gxfce (XFCE_palette * pal)
   gtk_box_pack_start (GTK_BOX (gxfce_central_vbox),
 		      screen_buttons.gxfce_central_frame, TRUE, TRUE, 0);
   gtk_widget_set_usize (screen_buttons.gxfce_central_frame, 0, 0);
+#ifndef OLD_STYLE
+  gtk_frame_set_shadow_type (GTK_FRAME (screen_buttons.gxfce_central_frame),
+			     GTK_SHADOW_ETCHED_IN);
+#else
   gtk_frame_set_shadow_type (GTK_FRAME (screen_buttons.gxfce_central_frame),
 			     GTK_SHADOW_OUT);
-  /* gtk_widget_set_style(screen_buttons.gxfce_central_frame, pal->cm[7]); */
-
+#endif
   gxfce_central_hbox = gtk_hbox_new (FALSE, 0);
   gtk_widget_set_name (gxfce_central_hbox, "gxfce_central_hbox");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_central_hbox",
@@ -636,16 +722,15 @@ create_gxfce (XFCE_palette * pal)
   gtk_container_add (GTK_CONTAINER (screen_buttons.gxfce_central_frame),
 		     gxfce_central_hbox);
 
-  gxfce_central_vbox_left = gtk_vbox_new (TRUE, 0);
-  gtk_widget_set_name (gxfce_central_vbox_left, "gxfce_central_vbox_left");
-  gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_central_vbox_left",
-		       gxfce_central_vbox_left);
-  gtk_widget_show (gxfce_central_vbox_left);
-  gtk_box_pack_start (GTK_BOX (gxfce_central_hbox), gxfce_central_vbox_left,
+  gxfce_leftbuttons_table = gtk_table_new (2, 2, FALSE);
+  gtk_widget_set_name (gxfce_leftbuttons_table, "gxfce_leftbuttons_table");
+  gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_leftbuttons_table",
+		       gxfce_leftbuttons_table);
+  gtk_widget_show (gxfce_leftbuttons_table);
+  gtk_box_pack_start (GTK_BOX (gxfce_central_hbox), gxfce_leftbuttons_table,
 		      FALSE, TRUE, 0);
 
-  select_buttons.select_button[NBSELECTS] =
-    select_buttons.select_button[NBSELECTS] = gtk_button_new ();
+  gxfce_leftbuttons[0] = select_buttons.select_button[NBSELECTS] = gtk_button_new ();
   gtk_widget_set_name (select_buttons.select_button[NBSELECTS],
 		       "gxfce_select_button");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_select_button",
@@ -655,12 +740,13 @@ create_gxfce (XFCE_palette * pal)
 			 GTK_RELIEF_NONE);
   gtk_widget_show (select_buttons.select_button[NBSELECTS]);
   gtk_widget_set_usize (select_buttons.select_button[NBSELECTS], 35, 28);
-  gtk_box_pack_start (GTK_BOX (gxfce_central_vbox_left),
-		      select_buttons.select_button[NBSELECTS], FALSE, TRUE,
-		      0);
+  gtk_table_attach (GTK_TABLE (gxfce_leftbuttons_table),
+		    select_buttons.select_button[NBSELECTS], 0, 1, 0, 1,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL | GTK_SHRINK,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_SHRINK,
+		     0, 0);
   gtk_container_border_width (GTK_CONTAINER
 			      (select_buttons.select_button[NBSELECTS]), 2);
-  /* gtk_widget_set_style(select_buttons.select_button[NBSELECTS], pal->cm[7]); */
   select_buttons.select_tooltips[NBSELECTS] =
     my_tooltips_new (current_config.tooltipsdelay);
   gtk_tooltips_force_window (select_buttons.select_tooltips[NBSELECTS]);
@@ -682,18 +768,19 @@ create_gxfce (XFCE_palette * pal)
   gtk_widget_show (select_buttons.select_pixmap[NBSELECTS]);
   gtk_container_add (GTK_CONTAINER (select_buttons.select_button[NBSELECTS]),
 		     select_buttons.select_pixmap[NBSELECTS]);
-  /* gtk_widget_set_style(select_buttons.select_pixmap[NBSELECTS], pal->cm[7]); */
 
-  gxfce_info = gtk_button_new ();
+  gxfce_leftbuttons[1] = gxfce_info = gtk_button_new ();
   gtk_widget_set_name (gxfce_info, "gxfce_info");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_info", gxfce_info);
   gtk_button_set_relief ((GtkButton *) gxfce_info, GTK_RELIEF_NONE);
   gtk_widget_set_usize (gxfce_info, 35, 28);
   gtk_widget_show (gxfce_info);
-  gtk_box_pack_start (GTK_BOX (gxfce_central_vbox_left), gxfce_info, FALSE,
-		      TRUE, 0);
+  gtk_table_attach (GTK_TABLE (gxfce_leftbuttons_table),
+		    gxfce_info, 0, 1, 1, 2,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL | GTK_SHRINK,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_SHRINK,
+		    0, 0);
   gtk_container_border_width (GTK_CONTAINER (gxfce_info), 2);
-  /* gtk_widget_set_style(gxfce_info, pal->cm[7]); */
 
   gxfce_info_tooltip = my_tooltips_new (current_config.tooltipsdelay);
   gtk_tooltips_set_tip (gxfce_info_tooltip, gxfce_info, _("About..."),
@@ -708,33 +795,34 @@ create_gxfce (XFCE_palette * pal)
 		       gxfce_info_pixmap);
   gtk_widget_show (gxfce_info_pixmap);
   gtk_container_add (GTK_CONTAINER (gxfce_info), gxfce_info_pixmap);
-  /* gtk_widget_set_style(gxfce_info_pixmap, pal->cm[7]); */
 
-  desktops_table = create_gxfce_screen_buttons (gxfce, pal);
-  gtk_widget_set_name (desktops_table, "desktops_table");
-  gtk_object_set_data (GTK_OBJECT (gxfce), "desktops_table", desktops_table);
-  gtk_widget_show (desktops_table);
-  gtk_box_pack_start (GTK_BOX (gxfce_central_hbox), desktops_table, TRUE,
+  screen_buttons.desktops_table = create_gxfce_screen_buttons (gxfce);
+  gtk_widget_set_name (screen_buttons.desktops_table, "desktops_table");
+  gtk_object_set_data (GTK_OBJECT (gxfce), "desktops_table", screen_buttons.desktops_table);
+  gtk_widget_show (screen_buttons.desktops_table);
+  gtk_box_pack_start (GTK_BOX (gxfce_central_hbox), screen_buttons.desktops_table, TRUE,
 		      TRUE, 0);
 
-  gxfce_central_vbox_right = gtk_vbox_new (TRUE, 0);
-  gtk_widget_set_name (gxfce_central_vbox_right, "gxfce_central_vbox_right");
-  gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_central_vbox_right",
-		       gxfce_central_vbox_right);
-  gtk_widget_show (gxfce_central_vbox_right);
-  gtk_box_pack_start (GTK_BOX (gxfce_central_hbox), gxfce_central_vbox_right,
+  gxfce_rightbuttons_table = gtk_table_new (2, 2, FALSE);
+  gtk_widget_set_name (gxfce_rightbuttons_table, "gxfce_rightbuttons_table");
+  gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_rightbuttons_table",
+		       gxfce_rightbuttons_table);
+  gtk_widget_show (gxfce_rightbuttons_table);
+  gtk_box_pack_start (GTK_BOX (gxfce_central_hbox), gxfce_rightbuttons_table,
 		      FALSE, TRUE, 0);
 
-  gxfce_setup = gtk_button_new ();
+  gxfce_rightbuttons[0] = gxfce_setup = gtk_button_new ();
   gtk_widget_set_name (gxfce_setup, "gxfce_setup");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_setup", gxfce_setup);
   gtk_button_set_relief ((GtkButton *) gxfce_setup, GTK_RELIEF_NONE);
   gtk_widget_set_usize (gxfce_setup, 35, 28);
   gtk_widget_show (gxfce_setup);
-  gtk_box_pack_start (GTK_BOX (gxfce_central_vbox_right), gxfce_setup, FALSE,
-		      TRUE, 0);
+  gtk_table_attach (GTK_TABLE (gxfce_rightbuttons_table),
+		    gxfce_setup, 0, 1, 0, 1,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL | GTK_SHRINK,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_SHRINK,
+		     0, 0);
   gtk_container_border_width (GTK_CONTAINER (gxfce_setup), 2);
-  /* gtk_widget_set_style(gxfce_setup, pal->cm[7]); */
 
   gxfce_setup_tooltip = my_tooltips_new (current_config.tooltipsdelay);
   gtk_tooltips_set_tip (gxfce_setup_tooltip, gxfce_setup, _("Setup..."),
@@ -749,17 +837,18 @@ create_gxfce (XFCE_palette * pal)
 		       gxfce_setup_pixmap);
   gtk_widget_show (gxfce_setup_pixmap);
   gtk_container_add (GTK_CONTAINER (gxfce_setup), gxfce_setup_pixmap);
-  /* gtk_widget_set_style(gxfce_setup_pixmap, pal->cm[7]); */
 
-  gxfce_quit = gtk_button_new ();
+  gxfce_rightbuttons[1] = gxfce_quit = gtk_button_new ();
   gtk_widget_set_name (gxfce_quit, "gxfce_quit");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_quit", gxfce_quit);
   gtk_button_set_relief ((GtkButton *) gxfce_quit, GTK_RELIEF_NONE);
   gtk_widget_show (gxfce_quit);
-  gtk_box_pack_start (GTK_BOX (gxfce_central_vbox_right), gxfce_quit, FALSE,
-		      FALSE, 0);
+  gtk_table_attach (GTK_TABLE (gxfce_rightbuttons_table),
+		    gxfce_quit, 0, 1, 1, 2,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL | GTK_SHRINK,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_SHRINK,
+		     0, 0);
   gtk_container_border_width (GTK_CONTAINER (gxfce_quit), 2);
-  /* gtk_widget_set_style(gxfce_quit, pal->cm[7]); */
 
   gxfce_quit_tooltip = my_tooltips_new (current_config.tooltipsdelay);
   gtk_tooltips_set_tip (gxfce_quit_tooltip, gxfce_quit, _("Whoooops !"),
@@ -788,9 +877,9 @@ create_gxfce (XFCE_palette * pal)
 			  popup_buttons.popup_vbox[i] =
 			  create_gxfce_popup_select_group (gxfce,
 							   create_gxfce_popup_button
-							   (gxfce, pal, i),
+							   (gxfce, i),
 							   create_gxfce_select_button
-							   (gxfce, pal, i)),
+							   (gxfce, i)),
 			  TRUE, TRUE, 0);
     }
 
@@ -802,66 +891,77 @@ create_gxfce (XFCE_palette * pal)
   gtk_widget_set_usize (gxfce_hbox_moveright, 0, 0);
 
   gxfce_move_frame_right = gtk_frame_new (NULL);
-  gtk_widget_set_name (gxfce_move_frame_right, "gxfce_move_frame_right");
+#ifndef OLD_STYLE
+  gtk_frame_set_shadow_type (GTK_FRAME (gxfce_move_frame_right), 
+                             GTK_SHADOW_NONE);
+  gtk_widget_set_name (gxfce_move_frame_right, "gxfce_color7");
+#else
+  gtk_frame_set_shadow_type (GTK_FRAME (gxfce_move_frame_right),
+			     GTK_SHADOW_OUT);
+  gtk_widget_set_name (gxfce_move_frame_right, "gxfce_color1");
+#endif
+
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_move_frame_right",
 		       gxfce_move_frame_right);
   gtk_widget_show (gxfce_move_frame_right);
   gtk_box_pack_start (GTK_BOX (gxfce_hbox_moveright), gxfce_move_frame_right,
 		      TRUE, TRUE, 0);
-  gtk_widget_set_usize (gxfce_move_frame_right, 0, 16);
-  gtk_frame_set_shadow_type (GTK_FRAME (gxfce_move_frame_right),
-			     GTK_SHADOW_OUT);
-  gtk_widget_set_style (gxfce_move_frame_right, pal->cm[1]);
-
+  gtk_widget_set_usize (gxfce_move_frame_right, 0, TOPHEIGHT);
   gxfce_move_event_right = gtk_event_box_new ();
-  gtk_widget_set_name (gxfce_move_event_right, "gxfce_move_event_right");
+#ifndef OLD_STYLE
+  gtk_widget_set_name (gxfce_move_event_right, "gxfce_color7");
+#else
+  gtk_widget_set_name (gxfce_move_event_right, "gxfce_color1");
+#endif
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_move_event_right",
 		       gxfce_move_event_right);
   gtk_widget_show (gxfce_move_event_right);
   gtk_container_add (GTK_CONTAINER (gxfce_move_frame_right),
 		     gxfce_move_event_right);
-  gtk_widget_set_style (gxfce_move_event_right, pal->cm[1]);
 
   gxfce_move_right_pixmap =
     MyCreateFromPixmapData (gxfce_move_event_right, handle);
   if (gxfce_move_right_pixmap == NULL)
     g_error (_("Couldn't create pixmap"));
-  gtk_widget_set_name (gxfce_move_right_pixmap, "gxfce_move_right_pixmap");
+  gtk_widget_set_name (gxfce_move_right_pixmap, "gxfce_color1");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_move_right_pixmap",
 		       gxfce_move_right_pixmap);
   gtk_widget_show (gxfce_move_right_pixmap);
   gtk_container_add (GTK_CONTAINER (gxfce_move_event_right),
 		     gxfce_move_right_pixmap);
   gtk_widget_set_usize (gxfce_move_right_pixmap, PANEL_ICON_SIZE - 16 + 4,
-			16);
-  gtk_widget_set_style (gxfce_move_right_pixmap, pal->cm[1]);
+			TOPHEIGHT);
 
   gxfce_iconify_button = gtk_button_new ();
-  gtk_widget_set_name (gxfce_iconify_button, "gxfce_iconify_button");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_iconify_button",
 		       gxfce_iconify_button);
+#ifndef OLD_STYLE
+  gtk_button_set_relief ((GtkButton *) gxfce_iconify_button,
+			 GTK_RELIEF_NONE);
+  gtk_widget_set_name (gxfce_iconify_button, "gxfce_color7");
+#else
+  gtk_widget_set_name (gxfce_iconify_button, "gxfce_color1");
+#endif
   gtk_widget_show (gxfce_iconify_button);
   gtk_box_pack_start (GTK_BOX (gxfce_hbox_moveright), gxfce_iconify_button,
 		      TRUE, TRUE, 0);
-  gtk_widget_set_usize (gxfce_iconify_button, 16, 16);
-  gtk_widget_set_style (gxfce_iconify_button, pal->cm[1]);
+  gtk_widget_set_usize (gxfce_iconify_button, 16, TOPHEIGHT);
 
   gxfce_iconify_pixmap =
     MyCreateFromPixmapData (gxfce_iconify_button, iconify);
   if (gxfce_iconify_pixmap == NULL)
     g_error (_("Couldn't create pixmap"));
-  gtk_widget_set_name (gxfce_iconify_pixmap, "gxfce_iconify_pixmap");
+  gtk_widget_set_name (gxfce_iconify_pixmap, "gxfce_color1");
   gtk_object_set_data (GTK_OBJECT (gxfce), "gxfce_iconify_pixmap",
 		       gxfce_iconify_pixmap);
   gtk_widget_show (gxfce_iconify_pixmap);
   gtk_container_add (GTK_CONTAINER (gxfce_iconify_button),
 		     gxfce_iconify_pixmap);
-  gtk_widget_set_style (gxfce_iconify_pixmap, pal->cm[1]);
   gtk_box_pack_start (GTK_BOX (gxfce_hbox3),
 		      create_gxfce_popup_select_group (gxfce,
 						       gxfce_hbox_moveright,
 						       create_gxfce_select_button
-						       (gxfce, pal, 6)), TRUE,
+						       (gxfce, 6)), TRUE,
 		      TRUE, 0);
   /* Signal handling */
 
@@ -871,10 +971,6 @@ create_gxfce (XFCE_palette * pal)
   gtk_signal_connect (GTK_OBJECT (gxfce), "delete_event",
 		      GTK_SIGNAL_FUNC (delete_event), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (gxfce), "destroy",
-		      GTK_SIGNAL_FUNC (destroy_cb), NULL);
-
-
   gtk_signal_connect (GTK_OBJECT (gxfce_quit), "clicked",
 		      GTK_SIGNAL_FUNC (quit_cb), GTK_OBJECT (gxfce));
 
@@ -890,11 +986,11 @@ create_gxfce (XFCE_palette * pal)
   gtk_signal_connect (GTK_OBJECT (select_buttons.select_button[NBSELECTS]),
 		      "button_press_event",
 		      GTK_SIGNAL_FUNC (select_modify_cb),
-		      (gpointer) nbselects);
+		      (gpointer)((long) nbselects));
 
   gtk_signal_connect (GTK_OBJECT (select_buttons.select_button[NBSELECTS]),
 		      "clicked", GTK_SIGNAL_FUNC (select_cb),
-		      (gpointer) nbselects);
+		      (gpointer)((long) nbselects));
 
   gtk_signal_connect (GTK_OBJECT (gxfce_clock_event), "button_press_event",
 		      GTK_SIGNAL_FUNC (gxfce_clock_show_popup_cb),
