@@ -27,23 +27,21 @@
 
 #define end_XFCE(x) exit(x)
 
-  GtkWidget *gxfce;
-  GtkWidget *setup;
-  GtkWidget *fileselect;
-  GtkWidget *colorselect;
-  GtkWidget *modify;
-  GtkWidget *action;
-  GtkWidget *screen;
-  GtkWidget *info_scr;
-  GtkWidget *startup;
-  GtkWidget *fontselectiondialog;
+GtkWidget *gxfce;
+GtkWidget *setup;
+GtkWidget *fileselect;
+GtkWidget *colorselect;
+GtkWidget *modify;
+GtkWidget *action;
+GtkWidget *screen;
+GtkWidget *info_scr;
+GtkWidget *startup;
+GtkWidget *fontselectiondialog;
 
-  XFCE_palette *pal;
+XFCE_palette *pal;
 
-void 
-reap (int sig);
+void reap (int sig);
 
-int
-main (int argc, char *argv[]);
+int main (int argc, char *argv[]);
 
 #endif
