@@ -30,6 +30,7 @@
 #include <gtk/gtk.h>
 #include "my_intl.h"
 #include "xfwm.h"
+#include "xfce.h"
 #include "my_string.h"
 #include "fileutil.h"
 #include "configfile.h"
@@ -43,6 +44,10 @@
 #include "my_tooltips.h"
 #include "gnome_protocol.h"
 
+#ifndef HAVE_SNPRINTF
+#  include "snprintf.h"
+#endif
+
 #ifdef DMALLOC
 #  include "dmalloc.h"
 #endif
@@ -193,7 +198,7 @@ init_watchpipe (void)
     input_id = gdk_input_add (fd[1],
 			      GDK_INPUT_READ | GDK_INPUT_EXCEPTION,
 			      (GdkInputFunction) process_xfwm_messages,
-			      (gpointer) fd[1]);
+			      (gpointer) ((long)fd[1]));
 #endif
 }
 
@@ -235,7 +240,7 @@ apply_wm_colors (const XFCE_palette * p)
       howbright = brightness_pal (p, 2);
       howdark = brightness_pal (p, 7);
       color_to_hex (t, p, 2);
-      sprintf (u, MENUCOLOR_CMD, (howdark < darklim) ? "white" : "black", s,
+      sprintf (u, MENUCOLOR_CMD, (howdark < fadeblack) ? "white" : "black", s,
 	       (howbright < fadeblack) ? "white" : "black", t);
       sendinfo (fd, u, 0);
 
@@ -254,8 +259,9 @@ apply_wm_colors (const XFCE_palette * p)
 	sprintf (u, TITLESTYLE_CMD, INACTIVE, SOLID, t, "");
       sendinfo (fd, u, 0);
 
+      howbright = brightness_pal (p, 0);
       color_to_hex (t, p, 0);
-      sprintf (u, CURSORCOLOR_CMD, t, "white");
+      sprintf (u, CURSORCOLOR_CMD, t, (howbright < fadeblack) ? "white" : "black");
       sendinfo (fd, u, 0);
 
       sendinfo (fd, REFRESH_CMD, 0);
@@ -272,21 +278,21 @@ apply_wm_fonts (void)
   char *s;
   if (current_config.wm == XFWM)
     {
-      s = (char *) malloc (sizeof (char) * (MAXSTRLEN + 1));
+      s = (char *) malloc (sizeof (char) * 256);
       if ((current_config.fonts[0]) && strlen (current_config.fonts[0]))
-	sprintf (s, WINDOWFONT_CMD, current_config.fonts[0]);
+	snprintf (s, 255, WINDOWFONT_CMD, current_config.fonts[0]);
       else
-	sprintf (s, WINDOWFONT_CMD, XFWM_TITLEFONT);
+	snprintf (s, 255, WINDOWFONT_CMD, XFWM_TITLEFONT);
       sendinfo (fd, s, 0);
       if ((current_config.fonts[1]) && strlen (current_config.fonts[1]))
-	sprintf (s, MENUFONT_CMD, current_config.fonts[1]);
+	snprintf (s, 255, MENUFONT_CMD, current_config.fonts[1]);
       else
-	sprintf (s, MENUFONT_CMD, XFWM_MENUFONT);
+	snprintf (s, 255, MENUFONT_CMD, XFWM_MENUFONT);
       sendinfo (fd, s, 0);
       if ((current_config.fonts[2]) && strlen (current_config.fonts[2]))
-	sprintf (s, ICONFONT_CMD, current_config.fonts[2]);
+	snprintf (s, 255, ICONFONT_CMD, current_config.fonts[2]);
       else
-	sprintf (s, ICONFONT_CMD, XFWM_ICONFONT);
+	snprintf (s, 255, ICONFONT_CMD, XFWM_ICONFONT);
       sendinfo (fd, s, 0);
       free (s);
     }
@@ -299,7 +305,7 @@ apply_wm_iconpos (void)
   if (current_config.wm == XFWM)
     {
       s = (char *) malloc (sizeof (char) * 256);
-      sprintf (s, ICONPOS_CMD, current_config.iconpos);
+      snprintf (s, 255, ICONPOS_CMD, current_config.iconpos);
       sendinfo (fd, s, 0);
       /*
          sprintf(s , ARRANGEICONS_CMD, 0, NBSCREENS - 1);
@@ -335,7 +341,7 @@ apply_wm_snapsize (void)
   char command[256];
   if (current_config.wm == XFWM)
     {
-      sprintf (command, SNAPSIZE_CMD, current_config.snapsize);
+      snprintf (command, 255, SNAPSIZE_CMD, current_config.snapsize);
       sendinfo (fd, command, 0);
     }
 }
@@ -377,3 +383,25 @@ startup_wm_modules (void)
       free (command);
     }
 }
+
+void
+apply_wm_desk_names (int ndesks)
+{
+  char *command;
+  int i;
+
+  if (current_config.wm == XFWM)
+    {
+      command = (char *) malloc (sizeof (char) * 256);
+      snprintf (command, 255, DESTROYMENU_CMD, DESKMENU);
+      sendinfo (fd, command, 0);
+      for (i = 0; i < ndesks; i++)
+        {
+          snprintf (command, 255, ADDTOMENUDESK_CMD, DESKMENU, 
+                    _("Workspace"), i + 1, get_gxfce_screen_label (i), i);
+          sendinfo (fd, command, 0);
+        }
+      free (command);
+    }
+}
+
