@@ -68,7 +68,9 @@
 #define GRADIENT	    "Gradient"
 #define SOLID		    "Solid"
 #define SNAPSIZE_CMD	    "SnapSize %i"
-
+#define DESTROYMENU_CMD     "DestroyMenu \"%s\""
+#define ADDTOMENUDESK_CMD   "AddToMenu \"%s\" \"%s %u (%s)\" WindowsDesk 0 %u"
+#define DESKMENU	    "__builtin_sendtodesk_menu__"
 
 void assume_event (unsigned long type, unsigned long *body);
 
@@ -99,4 +101,6 @@ void apply_wm_snapsize (void);
 
 void startup_wm_modules (void);
 
+void apply_wm_desk_names (int);
+
 #endif
