@@ -42,6 +42,8 @@ typedef struct
   int fore_green;
   int fore_blue;
   char *font;
+  int calendar_opt;
+  int holy_days;
 }
 config;
 
