@@ -446,23 +446,6 @@ gnome_handle_win_state (XClientMessageEvent * event, Window id, long mask)
 	}
     }
 
-  /* iconify or deiconify */
-  if ((new_members & WIN_STATE_HIDDEN) || (new_members & WIN_STATE_MINIMIZED))
-    {
-      if (!(xfwm_window->flags & ICONIFIED))
-	{
-	  SendInfo (fd, "Iconify", xfwm_window->id);
-	}
-    }
-  else if ((change_mask & WIN_STATE_HIDDEN)
-	   || (change_mask & WIN_STATE_MINIMIZED))
-    {
-      if (xfwm_window->flags & ICONIFIED)
-	{
-	  SendInfo (fd, "Iconify", xfwm_window->id);
-	}
-    }
-
   if (event)
     gnome_get_prop_workspace (xfwm_window->id);
 }
@@ -481,8 +464,8 @@ gnome_get_prop_state (Window id)
 			  (unsigned char **) &data) == Success && data)
     {
       flags = *data;
-      XFree (data);
       gnome_handle_win_state (NULL, id, flags);
+      XFree (data);
     }
 
 }
