@@ -17,23 +17,23 @@
  * $Id: Gnome.h,v 1.9 1999/04/12 03:59:59 rafal Exp $
  */
 
-#define WIN_HINTS_SKIP_FOCUS      (1<<0) /*"alt-tab" skips this win*/
-#define WIN_HINTS_SKIP_WINLIST    (1<<1) /*do not show in window list*/
-#define WIN_HINTS_SKIP_TASKBAR    (1<<2) /*do not show on taskbar*/
-#define WIN_HINTS_GROUP_TRANSIENT (1<<3) /*Reserved - definition is unclear*/
-#define WIN_HINTS_FOCUS_ON_CLICK  (1<<4) /*app only accepts focus if clicked*/
-#define WIN_HINTS_DO_NOT_COVER    (1<<5) /*attempt to not cover this window */
+#define WIN_HINTS_SKIP_FOCUS      (1<<0)	/*"alt-tab" skips this win */
+#define WIN_HINTS_SKIP_WINLIST    (1<<1)	/*do not show in window list */
+#define WIN_HINTS_SKIP_TASKBAR    (1<<2)	/*do not show on taskbar */
+#define WIN_HINTS_GROUP_TRANSIENT (1<<3)	/*Reserved - definition is unclear */
+#define WIN_HINTS_FOCUS_ON_CLICK  (1<<4)	/*app only accepts focus if clicked */
+#define WIN_HINTS_DO_NOT_COVER    (1<<5)	/*attempt to not cover this window */
 
-#define WIN_STATE_STICKY          (1<<0) /*everyone knows sticky*/
-#define WIN_STATE_MINIMIZED       (1<<1) /*Reserved - definition is unclear*/
-#define WIN_STATE_MAXIMIZED_VERT  (1<<2) /*window in maximized V state*/
-#define WIN_STATE_MAXIMIZED_HORIZ (1<<3) /*window in maximized H state*/
-#define WIN_STATE_HIDDEN          (1<<4) /*not on taskbar but window visible*/
-#define WIN_STATE_SHADED          (1<<5) /*shaded (MacOS / Afterstep style)*/
-#define WIN_STATE_HID_WORKSPACE   (1<<6) /*not on current desktop*/
-#define WIN_STATE_HID_TRANSIENT   (1<<7) /*owner of transient is hidden*/
-#define WIN_STATE_FIXED_POSITION  (1<<8) /*window is fixed in position even*/
-#define WIN_STATE_ARRANGE_IGNORE  (1<<9) /*ignore for auto arranging*/
+#define WIN_STATE_STICKY          (1<<0)	/*everyone knows sticky */
+#define WIN_STATE_MINIMIZED       (1<<1)	/*Reserved - definition is unclear */
+#define WIN_STATE_MAXIMIZED_VERT  (1<<2)	/*window in maximized V state */
+#define WIN_STATE_MAXIMIZED_HORIZ (1<<3)	/*window in maximized H state */
+#define WIN_STATE_HIDDEN          (1<<4)	/*not on taskbar but window visible */
+#define WIN_STATE_SHADED          (1<<5)	/*shaded (MacOS / Afterstep style) */
+#define WIN_STATE_HID_WORKSPACE   (1<<6)	/*not on current desktop */
+#define WIN_STATE_HID_TRANSIENT   (1<<7)	/*owner of transient is hidden */
+#define WIN_STATE_FIXED_POSITION  (1<<8)	/*window is fixed in position even */
+#define WIN_STATE_ARRANGE_IGNORE  (1<<9)	/*ignore for auto arranging */
 
 /*
 #define WIN_LAYER_DESKTOP    0
@@ -48,13 +48,14 @@
 /* flags for the window layer */
 typedef enum
 {
-  WIN_LAYER_DESKTOP     = 0,
-  WIN_LAYER_BELOW       = 2,
-  WIN_LAYER_NORMAL      = 4,
-  WIN_LAYER_ONTOP       = 6,
-  WIN_LAYER_DOCK        = 8,
-  WIN_LAYER_ABOVE_DOCK  = 10
-} GnomeWinLayer;
+  WIN_LAYER_DESKTOP = 0,
+  WIN_LAYER_BELOW = 2,
+  WIN_LAYER_NORMAL = 4,
+  WIN_LAYER_ONTOP = 6,
+  WIN_LAYER_DOCK = 8,
+  WIN_LAYER_ABOVE_DOCK = 10
+}
+GnomeWinLayer;
 
 typedef enum
 {
@@ -103,31 +104,34 @@ typedef enum
   WIN_APP_STATE_PERCENT090_2,
   WIN_APP_STATE_PERCENT100_1,
   WIN_APP_STATE_PERCENT100_2
-} GnomeWinAppState;
+}
+GnomeWinAppState;
 
 typedef struct node
 {
-    long id;
-    long flags;
-    int workspace;
-    struct node *previous;
-    struct node *next;
-}list_item;
+  long id;
+  long flags;
+  int workspace;
+  struct node *previous;
+  struct node *next;
+}
+list_item;
 
 typedef struct
 {
-    list_item *first, *last;
-}s_list;
+  list_item *first, *last;
+}
+s_list;
 
-int s_list_remove_by_data (s_list *list, long id);
-list_item * s_list_find_by_data (s_list *list, long id);
+int s_list_remove_by_data (s_list * list, long id);
+list_item *s_list_find_by_data (s_list * list, long id);
 
 static void gnome_compliance_init ();
 static void gnome_get_prop_workspace (Window id);
 
 static int list_configure (unsigned long *body);
 static int list_add_window (unsigned long *body);
-static int list_window_name  (unsigned long *body);
+static int list_window_name (unsigned long *body);
 static int list_icon_name (unsigned long *body);
 static int list_destroy_window (unsigned long *body);
 static int list_end ();
