@@ -27,33 +27,35 @@
 #include "xfmouse.h"
 #include "xfmouse_cb.h"
 
-void ok_cb( GtkWidget *widget, gpointer   data )
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
+void
+ok_cb (GtkWidget * widget, gpointer data)
 {
-   apply_mouse_values(&mouseval);
-   savecfg (&mouseval);
-   gtk_main_quit ();
-   exit (0);
+  apply_mouse_values (&mouseval);
+  savecfg (&mouseval);
+  gtk_main_quit ();
+  exit (0);
 }
 
-void apply_cb( GtkWidget *widget, gpointer   data )
+void
+apply_cb (GtkWidget * widget, gpointer data)
 {
-   apply_mouse_values(&mouseval);
+  apply_mouse_values (&mouseval);
 }
 
-void cancel_cb( GtkWidget *widget, gpointer   data )
+void
+cancel_cb (GtkWidget * widget, gpointer data)
 {
-   gtk_main_quit ();
-   exit (0);
+  gtk_main_quit ();
+  exit (0);
 }
 
-gboolean delete_event( GtkWidget *widget,
-                   GdkEvent  *event,
-                   gpointer   data )
+gboolean
+delete_event (GtkWidget * widget, GdkEvent * event, gpointer data)
 {
-  cancel_cb (widget,data);
+  cancel_cb (widget, data);
   return (TRUE);
 }
-
-
-
-
