@@ -26,11 +26,15 @@
 #  include <config.h>
 #endif
 
+#ifdef HAVE_GDK_IMLIB
+#include <fcntl.h>
+#include <gdk_imlib.h>
+#endif
+
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
-#include <fcntl.h>
 #include "my_intl.h"
 #include "xfsound.h"
 #include "xfsound_cb.h"
@@ -87,8 +91,8 @@ T_messages messages[KNOWN_MESSAGES + KNOWN_BUILTIN] = {
   {0, N_("Unknown")}
 };
 
-static int private_menu_selected = -1;
-static int prev = -1;
+static gint private_menu_selected = -1;
+static gint prev = -1;
 
 void
 display_error (char *s)
@@ -202,7 +206,7 @@ value_table (long id)
 }
 
 void
-audio_play (short code)
+audio_play (short code, short backgnd)
 {
   char *command;
 
@@ -220,7 +224,8 @@ audio_play (short code)
 	  strcpy (command, sndcfg.playcmd);
 	  strcat (command, " ");
 	  strcat (command, sndcfg.datafiles[code]);
-	  strcat (command, " &");
+          /* If backgnd is set, run command in background */
+          if (backgnd) strcat (command, " &");
 	  system (command);
 	  free (command);
 	}
@@ -230,14 +235,23 @@ audio_play (short code)
 void
 done (int n)
 {
-  audio_play (BUILTIN_SHUTDOWN);
+  /* Cancel all signals handling to prevent the sound to be played twice ! */
+  signal (SIGPIPE, SIG_IGN);
+  signal (SIGINT,  SIG_IGN);
+  signal (SIGKILL, SIG_IGN);
+  signal (SIGTERM, SIG_IGN);
+  signal (SIGQUIT, SIG_IGN);
+  signal (SIGSTOP, SIG_IGN);
+  signal (SIGHUP,  SIG_IGN);
+
+  audio_play (BUILTIN_SHUTDOWN, 0);
   exit (n);
 }
 
 void
 DeadPipe (int nonsense)
 {
-  done (0);
+  done (nonsense);
 }
 
 void
@@ -261,21 +275,29 @@ Loop (int *fd)
       loadcfg (&sndcfg);
 
       if (code >= 0 && code < MAX_MESSAGES)
-	audio_play (code);
+	audio_play (code, 1);
       else if (code >= MAX_MESSAGES)
-	audio_play (BUILTIN_UNKNOWN);
+	audio_play (BUILTIN_UNKNOWN, 1);
     }
 }
 
 void
 startmodule (int argc, char *argv[])
 {
+  /* Intercept interupt signals to play "logout" sound */
   signal (SIGPIPE, DeadPipe);
+  signal (SIGINT,  DeadPipe);
+  signal (SIGKILL, DeadPipe);
+  signal (SIGTERM, DeadPipe);
+  signal (SIGQUIT, DeadPipe);
+  signal (SIGSTOP, DeadPipe);
+  signal (SIGHUP,  DeadPipe);
 
+  /* Initiate pipe */
   fd[0] = atoi (argv[1]);
   fd[1] = atoi (argv[2]);
 
-  audio_play (BUILTIN_STARTUP);
+  audio_play (BUILTIN_STARTUP, 0);
   sendinfo (fd, "Nop", 0);
   Loop (fd);
 }
@@ -314,7 +336,7 @@ update_all_data (void)
 }
 
 GtkWidget *
-create_xfsound (XFCE_palette * pal)
+create_xfsound ()
 {
   GtkWidget *xfsound_mainframe;
   GtkWidget *vbox1;
@@ -531,6 +553,8 @@ create_xfsound (XFCE_palette * pal)
   gtk_widget_show (ok_button);
   gtk_container_add (GTK_CONTAINER (hbuttonbox2), ok_button);
   GTK_WIDGET_SET_FLAGS (ok_button, GTK_CAN_DEFAULT);
+  gtk_widget_grab_default (ok_button);
+  
   accel_group = gtk_accel_group_new ();
   gtk_window_add_accel_group (GTK_WINDOW (xfsound), accel_group);
   gtk_widget_add_accelerator (ok_button, "clicked", accel_group,
@@ -575,8 +599,6 @@ create_xfsound (XFCE_palette * pal)
 		      GTK_SIGNAL_FUNC (testfile_cb), NULL);
   gtk_signal_connect (GTK_OBJECT (xfsound), "delete_event",
 		      GTK_SIGNAL_FUNC (delete_event), NULL);
-  gtk_signal_connect (GTK_OBJECT (xfsound), "destroy",
-		      GTK_SIGNAL_FUNC (cancel_cb), NULL);
 
   return xfsound;
 }
@@ -584,7 +606,7 @@ create_xfsound (XFCE_palette * pal)
 void
 private_update_menuentry_cb (GtkWidget * widget, gpointer data)
 {
-  private_menu_selected = (int) data;
+  private_menu_selected = (gint)((long)data);
   update_all_data ();
 }
 
@@ -600,7 +622,7 @@ list_addto_choice (char *name)
       gtk_menu_append (GTK_MENU (list_event_optionmenu_menu), menuitem);
       gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 			  GTK_SIGNAL_FUNC (private_update_menuentry_cb),
-			  (gpointer) position++);
+			  (gpointer)((long)position++));
       gtk_widget_show (menuitem);
       gtk_widget_realize (menuitem);
     }
@@ -633,8 +655,6 @@ init_choice_str (void)
 int
 main (int argc, char *argv[])
 {
-  XFCE_palette *pal;
-
   signal_setup ();
 
   homedir = (char *) malloc ((MAXSTRLEN + 1) * sizeof (char));
@@ -642,20 +662,11 @@ main (int argc, char *argv[])
   allocXFSound (&sndcfg);
   loadcfg (&sndcfg);
 
-  gtk_set_locale ();
-  bindtextdomain (PACKAGE, XFCE_LOCALE_DIR);
-  textdomain (PACKAGE);
-  gtk_init (&argc, &argv);
-
-  fcntl (ConnectionNumber (GDK_DISPLAY ()), F_SETFD, 1);
-
   if ((argc != 6) && (argc != 7))
     {
-      pal = newpal ();
-      defpal (pal);
-      loadpal (pal);
-      applypal (pal, NULL);
-      xfsound = create_xfsound (pal);
+      xfce_init (&argc, &argv);
+
+      xfsound = create_xfsound ();
       init_choice_str ();
       list_set_choice_selected (0);
       gtk_entry_set_text (GTK_ENTRY (command_entry), sndcfg.playcmd);
@@ -665,10 +676,10 @@ main (int argc, char *argv[])
 				    (sndcfg.playsnd != 0));
       gtk_widget_show (xfsound);
       set_icon (xfsound, "XFSound", xfsound_icon_xpm);
-      reg_xfce_app (xfsound, pal);
       gtk_main ();
+      xfce_end ((gpointer) NULL, 0);
     }
   else
     startmodule (argc, argv);
-  return 0;
+  return (0);
 }
