@@ -131,7 +131,7 @@ testfile_cb (GtkWidget * widget, gpointer data)
 
   i = list_get_choice_selected ();
   get_all_data (i);
-  audio_play (i);
+  audio_play (i, 0);
 }
 
 gboolean
