@@ -4,6 +4,9 @@
  * Copyright (C) 1999 Rasca, Berlin
  * EMail: thron@gmx.de
  *
+ * Olivier Fourdan (fourdan@xfce.org)
+ * Heavily modified as part of the Xfce project (http://www.xfce.org)
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -21,6 +24,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <limits.h>
 #include <glib.h>
 #include <dirent.h>
@@ -74,7 +78,7 @@ free_app_list (void)
 static void
 on_cancel (GtkWidget * btn, gpointer * data)
 {
-  if ((int) data == DLG_RC_CANCEL)
+  if ((int)((long) data) == DLG_RC_CANCEL)
     {
       gtk_widget_destroy (dl.top);
     }
@@ -111,11 +115,11 @@ on_ok (GtkWidget * ok, gpointer data)
 	list = g_list_append (list, g_strdup (temp));
       dl.in_terminal = GTK_TOGGLE_BUTTON (dl.check)->active;
       gtk_widget_destroy (dl.top);
-      dl.result = (int) data;
+      dl.result = (int)((long) data);
       gtk_main_quit ();
     }
   else
-    on_cancel (ok, DLG_RC_CANCEL);
+    on_cancel (ok, (gpointer) ((long) DLG_RC_CANCEL));
 }
 
 
@@ -145,7 +149,7 @@ dlg_open_with (char *xap, char *defval, char *file)
   gtk_window_position (GTK_WINDOW (dl.top), GTK_WIN_POS_CENTER);
   gtk_window_set_title (GTK_WINDOW (dl.top), title);
   gtk_signal_connect (GTK_OBJECT (dl.top), "destroy",
-		      GTK_SIGNAL_FUNC (on_cancel), (void *) DLG_RC_DESTROY);
+		      GTK_SIGNAL_FUNC (on_cancel), (gpointer)((long) DLG_RC_DESTROY));
   gtk_window_set_modal (GTK_WINDOW (dl.top), TRUE);
   gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dl.top)->vbox),
 				  5);
@@ -159,9 +163,9 @@ dlg_open_with (char *xap, char *defval, char *file)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dl.top)->action_area),
 		      cancel, TRUE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (ok), "clicked",
-		      GTK_SIGNAL_FUNC (on_ok), (void *) DLG_RC_OK);
+		      GTK_SIGNAL_FUNC (on_ok), (gpointer)((long) DLG_RC_OK));
   gtk_signal_connect (GTK_OBJECT (cancel), "clicked",
-		      GTK_SIGNAL_FUNC (on_cancel), (void *) DLG_RC_CANCEL);
+		      GTK_SIGNAL_FUNC (on_cancel), (gpointer)((long) DLG_RC_CANCEL));
   gtk_widget_grab_default (ok);
 
   box = gtk_hbox_new (FALSE, 5);
