@@ -4,6 +4,9 @@
  * Copyright (C) 1999 Rasca, Berlin
  * EMail: thron@gmx.de
  *
+ * Olivier Fourdan (fourdan@xfce.org)
+ * Heavily modified as part of the Xfce project (http://www.xfce.org)
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -78,9 +81,9 @@ label_new (char *text, GtkJustification j_type)
 static void
 on_cancel (GtkWidget * btn, gpointer * data)
 {
-  if ((int) data != DLG_RC_DESTROY)
+  if ((int)((long) data) != DLG_RC_DESTROY)
     {
-      dl.result = (int) data;
+      dl.result = (int)((long) data);
       gtk_widget_destroy (dl.top);
     }
   gtk_main_quit ();
@@ -115,7 +118,7 @@ on_ok (GtkWidget * ok, gpointer * data)
     }
   gtk_widget_destroy (dl.top);
 
-  dl.result = (int) data;
+  dl.result = (int)((long) data);
   gtk_main_quit ();
 }
 
@@ -124,7 +127,7 @@ on_ok (GtkWidget * ok, gpointer * data)
 static void
 cb_perm (GtkWidget * toggle, void *data)
 {
-  int bit = (int) data;
+  int bit = (int)((long) data);
   if (GTK_TOGGLE_BUTTON (toggle)->active)
     dl.prop->mode |= (mode_t) bit;
   else
@@ -138,7 +141,7 @@ on_key_press (GtkWidget * w, GdkEventKey * event, void *data)
 {
   if (event->keyval == GDK_Escape)
     {
-      on_cancel ((GtkWidget *) data, (void *) DLG_RC_CANCEL);
+      on_cancel ((GtkWidget *) data, (gpointer) ((long) DLG_RC_CANCEL));
       return (TRUE);
     }
   return (FALSE);
@@ -173,7 +176,7 @@ dlg_prop (char *path, fprop * prop, int flags)
   dl.top = gtk_dialog_new ();
   gtk_window_set_title (GTK_WINDOW (dl.top), _("Properties"));
   gtk_signal_connect (GTK_OBJECT (dl.top), "destroy",
-		      GTK_SIGNAL_FUNC (on_cancel), (void *) DLG_RC_DESTROY);
+		      GTK_SIGNAL_FUNC (on_cancel), (gpointer)((long) DLG_RC_DESTROY));
   gtk_window_set_modal (GTK_WINDOW (dl.top), TRUE);
 
   notebook = gtk_notebook_new ();
@@ -193,9 +196,9 @@ dlg_prop (char *path, fprop * prop, int flags)
 		      cancel, TRUE, FALSE, 0);
 
   gtk_signal_connect (GTK_OBJECT (ok), "clicked",
-		      GTK_SIGNAL_FUNC (on_ok), (void *) DLG_RC_OK);
+		      GTK_SIGNAL_FUNC (on_ok), (gpointer)((long) DLG_RC_OK));
   gtk_signal_connect (GTK_OBJECT (cancel), "clicked",
-		      GTK_SIGNAL_FUNC (on_cancel), (void *) DLG_RC_CANCEL);
+		      GTK_SIGNAL_FUNC (on_cancel), (gpointer)((long) DLG_RC_CANCEL));
   gtk_widget_grab_default (ok);
 
   if (flags & IS_MULTI)
@@ -207,9 +210,9 @@ dlg_prop (char *path, fprop * prop, int flags)
       gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dl.top)->action_area),
 			  all, TRUE, FALSE, 0);
       gtk_signal_connect (GTK_OBJECT (skip), "clicked",
-			  GTK_SIGNAL_FUNC (on_cancel), (void *) DLG_RC_SKIP);
+			  GTK_SIGNAL_FUNC (on_cancel), (gpointer)((long) DLG_RC_SKIP));
       gtk_signal_connect (GTK_OBJECT (all), "clicked",
-			  GTK_SIGNAL_FUNC (on_ok), (void *) DLG_RC_ALL);
+			  GTK_SIGNAL_FUNC (on_ok), (gpointer)((long) DLG_RC_ALL));
       GTK_WIDGET_SET_FLAGS (skip, GTK_CAN_DEFAULT);
       GTK_WIDGET_SET_FLAGS (all, GTK_CAN_DEFAULT);
     }
@@ -308,22 +311,22 @@ dlg_prop (char *path, fprop * prop, int flags)
       if (prop->mode & S_IRUSR)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[1]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[1]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_IRUSR);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_IRUSR));
       perm[2] = gtk_check_button_new_with_label (_("Write"));
       if (prop->mode & S_IWUSR)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[2]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[2]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_IWUSR);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_IWUSR));
       perm[3] = gtk_check_button_new_with_label (_("Execute"));
       if (prop->mode & S_IXUSR)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[3]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[3]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_IXUSR);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_IXUSR));
       perm[4] = gtk_check_button_new_with_label (_("Set UID"));
       if (prop->mode & S_ISUID)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[4]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[4]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_ISUID);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_ISUID));
 
       gtk_table_attach (GTK_TABLE (table), perm[0], 0, 1, 0, 1, 0, 0, X_PAD,
 			0);
@@ -341,22 +344,22 @@ dlg_prop (char *path, fprop * prop, int flags)
       if (prop->mode & S_IRGRP)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[6]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[6]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_IRGRP);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_IRGRP));
       perm[7] = gtk_check_button_new_with_label (_("Write"));
       if (prop->mode & S_IWGRP)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[7]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[7]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_IWGRP);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_IWGRP));
       perm[8] = gtk_check_button_new_with_label (_("Execute"));
       if (prop->mode & S_IXGRP)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[8]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[8]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_IXGRP);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_IXGRP));
       perm[9] = gtk_check_button_new_with_label (_("Set GID"));
       if (prop->mode & S_ISGID)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[9]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[9]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_ISGID);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_ISGID));
       gtk_table_attach (GTK_TABLE (table), perm[5], 0, 1, 1, 2, 0, 0, X_PAD,
 			0);
       gtk_table_attach (GTK_TABLE (table), perm[6], 1, 2, 1, 2, 0, 0, X_PAD,
@@ -373,22 +376,22 @@ dlg_prop (char *path, fprop * prop, int flags)
       if (prop->mode & S_IROTH)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[11]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[11]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_IROTH);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_IROTH));
       perm[12] = gtk_check_button_new_with_label (_("Write"));
       if (prop->mode & S_IWOTH)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[12]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[12]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_IWOTH);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_IWOTH));
       perm[13] = gtk_check_button_new_with_label (_("Execute"));
       if (prop->mode & S_IXOTH)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[13]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[13]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_IXOTH);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_IXOTH));
       perm[14] = gtk_check_button_new_with_label (_("Sticky"));
       if (prop->mode & S_ISVTX)
 	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (perm[14]), 1);
       gtk_signal_connect (GTK_OBJECT (perm[14]), "clicked",
-			  GTK_SIGNAL_FUNC (cb_perm), (void *) S_ISVTX);
+			  GTK_SIGNAL_FUNC (cb_perm), (gpointer)((long) S_ISVTX));
       gtk_table_attach (GTK_TABLE (table), perm[10], 0, 1, 2, 3, 0, 0, X_PAD,
 			0);
       gtk_table_attach (GTK_TABLE (table), perm[11], 1, 2, 2, 3, 0, 0, X_PAD,
@@ -445,7 +448,7 @@ dlg_prop (char *path, fprop * prop, int flags)
   gtk_table_attach (GTK_TABLE (table), owner[3], 1, 2, 1, 2, 0, 0, X_PAD, 0);
 
   gtk_signal_connect (GTK_OBJECT (dl.top), "key_press_event",
-		      GTK_SIGNAL_FUNC (on_key_press), (void *) cancel);
+		      GTK_SIGNAL_FUNC (on_key_press), (gpointer) cancel);
   gtk_widget_show_all (dl.top);
   gtk_main ();
 
