@@ -4,6 +4,9 @@
  * Copyright (C) 1998 Rasca, Berlin
  * EMail: thron@gmx.de
  *
+ * Olivier Fourdan (fourdan@xfce.org)
+ * Heavily modified as part of the Xfce project (http://www.xfce.org)
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -19,14 +22,16 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <fcntl.h>
 #include <signal.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <sys/wait.h>
 #include <limits.h>
 #include <errno.h>
 #include "io.h"
@@ -122,6 +127,7 @@ int
 io_system (char *cmd)
 {
   int pid, status;
+  int nulldev;
 
   if (cmd == NULL)
     return (1);
@@ -136,6 +142,16 @@ io_system (char *cmd)
       argv[1] = "-c";
       argv[2] = cmd;
       argv[3] = NULL;
+
+      /* The following is to avoid X locking when executing 
+         terminal based application that requires user input */
+      if ((nulldev = open ("/dev/null", O_RDWR)))
+        {
+          close (0); dup (nulldev);
+          close (1); dup (nulldev);
+          close (2); dup (nulldev);
+        }
+
       if (execve ("/bin/sh", argv, environ) == -1)
 	perror ("/bin/sh");
       _exit (127);
