@@ -4,6 +4,9 @@
  * Copyright (C) 1999 Rasca, Berlin
  * EMail: thron@gmx.de
  *
+ * Olivier Fourdan (fourdan@xfce.org)
+ * Heavily modified as part of the Xfce project (http://www.xfce.org)
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -70,21 +73,12 @@ main (int argc, char *argv[])
   struct stat st;
   wgeo_t geo = { -1, -1, 380, 480 };
 
-  signal_setup ();
+  xfce_init (&argc, &argv);
 
   sprintf (rc, "%s/%s/%s", path, BASE_DIR, "xtree.rc");
 
   strcpy (path, getenv ("HOME"));
 
-  gui_init (&argc, &argv, rc);
-
-#ifdef HAVE_GDK_IMLIB
-  gdk_imlib_init ();
-/* Get gdk to use imlib's visual and colormap */
-  gtk_widget_push_visual (gdk_imlib_get_visual ());
-  gtk_widget_push_colormap (gdk_imlib_get_colormap ());
-#endif
-
   while ((c = getopt (argc, argv, "vg:i:")) != EOF)
     {
       switch (c)
@@ -186,5 +180,6 @@ main (int argc, char *argv[])
     }
   fcntl (ConnectionNumber (GDK_DISPLAY ()), F_SETFD, 1);
   gui_main (path, base, trash, reg, &geo, flags);
-  return 0;
+  xfce_end ((gpointer) NULL, 0);
+  return (0);
 }
