@@ -4,6 +4,9 @@
  * Copyright (C) 1999 Rasca, Berlin
  * EMail: thron@gmx.de
  *
+ * Olivier Fourdan (fourdan@xfce.org)
+ * Heavily modified as part of the Xfce project (http://www.xfce.org)
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -171,18 +174,6 @@ static GtkWidget *new_top (char *p, char *x, char *trash, GList * reg,
 			   int width, int height, int flags);
 int move_dir (char *source, char *label, char *target, int trash);
 
-/*
- * gtk init function, must be called first
- */
-void
-gui_init (int *argc, char ***argv, char *rc)
-{
-  gtk_set_locale ();
-  bindtextdomain (PACKAGE, XFCE_LOCALE_DIR);
-  textdomain (PACKAGE);
-  gtk_init (argc, argv);
-}
-
 /*
  */
 #define FATAL 1
@@ -412,7 +403,7 @@ node_unselect_by_type (GtkCTree * ctree, GtkCTreeNode * node, void *data)
   entry *en;
 
   en = gtk_ctree_node_get_row_data (ctree, node);
-  if (en->type & (int) data)
+  if (en->type & (int)((long) data))
     {
       gtk_ctree_unselect (ctree, node);
     }
@@ -432,7 +423,7 @@ cb_select (GtkWidget * item, GtkCTree * ctree)
   gtk_ctree_select_recursive (ctree, node);
   gtk_ctree_unselect (ctree, node);
   gtk_ctree_pre_recursive (ctree, node, node_unselect_by_type,
-			   (void *) FT_DIR_UP);
+			   (gpointer)((long) FT_DIR_UP));
 }
 
 /*
@@ -1619,9 +1610,9 @@ on_double_click (GtkWidget * ctree, GdkEventButton * event, void *menu)
 	{
 	  node = gtk_ctree_node_nth (GTK_CTREE (ctree), row);
 	  en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node);
-	  if (EN_IS_DIR (en) && (event->state & GDK_MOD1_MASK))
+	  if (EN_IS_DIR (en) && (event->state & (GDK_MOD1_MASK | GDK_CONTROL_MASK)))
 	    {
-	      /* Alt button is pressed it's the same as _go_to()..
+	      /* Alt or Ctrl button is pressed, it's the same as _go_to()..
 	       */
 	      go_to (GTK_CTREE (ctree),
 		     GTK_CTREE_NODE (GTK_CLIST (ctree)->row_list),
@@ -2331,8 +2322,6 @@ cb_register (GtkWidget * item, GtkWidget * ctree)
 
 /*
  */
-static XFCE_palette *global_pal;
-
 void
 on_destroy (GtkWidget * top, cfg * win)
 {
@@ -2433,6 +2422,27 @@ update_timer (GtkCTree * ctree)
   return (TRUE);
 }
 
+static void
+cb_term (GtkWidget * item, GtkWidget * ctree)  
+{
+  GtkCTreeNode *node;
+  char path[PATH_MAX + 1];
+  entry *en;
+
+
+  count_selection (GTK_CTREE (ctree), &node);
+  en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node);
+
+  if (!(en->type & FT_DIR))
+       {
+               node = GTK_CTREE_ROW (node)->parent;
+               en = gtk_ctree_node_get_row_data (GTK_CTREE (ctree), node);
+       }
+      
+  sprintf (path,"xfterm \"%s\" &", en->path);
+  io_system (path); 
+}
+
 /*
  */
 static void
@@ -2445,6 +2455,7 @@ cb_exec (GtkWidget * top, gpointer data)
 XErrorHandler
 ErrorHandler (Display * dpy, XErrorEvent * event)
 {
+  char buf[64];
   if ((event->error_code == BadWindow) ||
       (event->error_code == BadDrawable) ||
       (event->request_code == X_GetGeometry) ||
@@ -2456,7 +2467,11 @@ ErrorHandler (Display * dpy, XErrorEvent * event)
       (event->request_code == X_InstallColormap))
     return (0);
 
+  XGetErrorText (dpy, event->error_code, buf, 63);
   fprintf (stderr, "xftree: Fatal XLib internal error\n");
+  fprintf (stderr, "%s\n", buf);
+  fprintf (stderr, "Request %d, Error %d\n", 
+                    event->request_code, event->error_code);
   exit (1);
   return (0);
 }
@@ -2755,6 +2770,12 @@ create_menu (GtkWidget * top, GtkWidget * ctree, cfg * win)
   gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 		      GTK_SIGNAL_FUNC (cb_new_window), (gpointer) ctree);
 
+  menuitem = gtk_menu_item_new_with_label (_("Open in terminal"));
+  gtk_menu_append (GTK_MENU (menu), menuitem);
+  gtk_widget_show (menuitem);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+                     GTK_SIGNAL_FUNC (cb_term), (gpointer) ctree);
+
   menuitem = gtk_menu_item_new_with_label (_("New Folder ..."));
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
@@ -2770,7 +2791,7 @@ create_menu (GtkWidget * top, GtkWidget * ctree, cfg * win)
   menuitem = gtk_menu_item_new ();
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
-
+  
   menuitem = gtk_menu_item_new_with_label (_("Run program ..."));
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
@@ -2913,129 +2934,130 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width,
   int i;
 
   menu_entry dir_mlist[] = {
-    {N_("Open in new"), (void *) cb_new_window, 0},
+    {N_("Open in new"), (gpointer) cb_new_window, 0},
+    {N_("Open in terminal"), (gpointer) cb_term, 0, GDK_k, GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("New Folder ..."), (void *) cb_new_subdir, 0, GDK_n, GDK_MOD1_MASK},
-    {N_("New file ..."), (void *) cb_new_file, 0, GDK_k, GDK_MOD1_MASK},
+    {N_("New Folder ..."), (gpointer) cb_new_subdir, 0, GDK_n, GDK_MOD1_MASK},
+    {N_("New file ..."), (gpointer) cb_new_file, 0, GDK_k, GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("Rename ..."), (void *) cb_rename, 0, GDK_r, GDK_MOD1_MASK},
-    {N_("Delete ..."), (void *) cb_delete, 0, GDK_x, GDK_CONTROL_MASK},
+    {N_("Rename ..."), (gpointer) cb_rename, 0, GDK_r, GDK_MOD1_MASK},
+    {N_("Delete ..."), (gpointer) cb_delete, 0, GDK_x, GDK_CONTROL_MASK},
     {NULL, NULL, 0},
-    {N_("Go to ..."), (void *) cb_go_to, 0},
-    {N_("Go to marked"), (void *) cb_go_to, 0, GDK_g, GDK_MOD1_MASK},
-    {N_("Go up"), (void *) cb_go_up, 0, GDK_u, GDK_MOD1_MASK},
-    {N_("Go home"), (void *) cb_go_home, 0, GDK_h, GDK_MOD1_MASK},
+    {N_("Go to ..."), (gpointer) cb_go_to, 0},
+    {N_("Go to marked"), (gpointer) cb_go_to, 0, GDK_g, GDK_MOD1_MASK},
+    {N_("Go up"), (gpointer) cb_go_up, 0, GDK_u, GDK_MOD1_MASK},
+    {N_("Go home"), (gpointer) cb_go_home, 0, GDK_h, GDK_MOD1_MASK},
     {NULL, NULL, 0},
 
-    {N_("Unselect"), (void *) cb_unselect, 0, GDK_a,
+    {N_("Unselect"), (gpointer) cb_unselect, 0, GDK_a,
      GDK_SHIFT_MASK | GDK_MOD1_MASK},
-    {N_("Select all"), (void *) cb_select, 0, GDK_a, GDK_MOD1_MASK},
-    {N_("Unselect all"), (void *) cb_unselect, 0},
-    {N_("Find ..."), (void *) cb_find, 0, GDK_f, GDK_MOD1_MASK},
+    {N_("Select all"), (gpointer) cb_select, 0, GDK_a, GDK_MOD1_MASK},
+    {N_("Unselect all"), (gpointer) cb_unselect, 0},
+    {N_("Find ..."), (gpointer) cb_find, 0, GDK_f, GDK_MOD1_MASK},
 
-    {N_("Toggle Dotfiles"), (void *) on_dotfiles, 0, GDK_D,
+    {N_("Toggle Dotfiles"), (gpointer) on_dotfiles, 0, GDK_D,
      GDK_SHIFT_MASK | GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("Properties ..."), (void *) cb_props, 0, GDK_i, GDK_MOD1_MASK},
+    {N_("Properties ..."), (gpointer) cb_props, 0, GDK_i, GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("Empty Trash"), (void *) cb_empty_trash, 0, GDK_e, GDK_MOD1_MASK},
-    {N_("Open Trash"), (void *) cb_open_trash, WINCFG, GDK_t, GDK_MOD1_MASK},
-    {N_("About ..."), (void *) cb_about, 0, GDK_a, GDK_CONTROL_MASK},
+    {N_("Empty Trash"), (gpointer) cb_empty_trash, 0, GDK_e, GDK_MOD1_MASK},
+    {N_("Open Trash"), (gpointer) cb_open_trash, WINCFG, GDK_t, GDK_MOD1_MASK},
+    {N_("About ..."), (gpointer) cb_about, 0, GDK_a, GDK_CONTROL_MASK},
     {NULL, NULL, 0},
-    {N_("Run program ..."), (void *) cb_exec, WINCFG},
-    {N_("Close window"), (void *) cb_destroy, TOPWIN, GDK_w, GDK_MOD1_MASK},
-    {N_("Quit"), (void *) gtk_main_quit, 0, GDK_q, GDK_MOD1_MASK},
+    {N_("Run program ..."), (gpointer) cb_exec, WINCFG},
+    {N_("Close window"), (gpointer) cb_destroy, TOPWIN, GDK_w, GDK_MOD1_MASK},
+    {N_("Quit"), (gpointer) gtk_main_quit, 0, GDK_q, GDK_MOD1_MASK},
   };
 #define LAST_DIR_MENU_ENTRY (sizeof(dir_mlist)/sizeof(menu_entry))
 
   menu_entry file_mlist[] = {
-    {N_("New window"), (void *) cb_new_window, 0},
+    {N_("New window"), (gpointer) cb_new_window, 0},
     {NULL, NULL, 0},
-    {N_("Open with ..."), (void *) cb_open_with, 0, GDK_o, GDK_MOD1_MASK},
+    {N_("Open with ..."), (gpointer) cb_open_with, 0, GDK_o, GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("Rename ..."), (void *) cb_rename, 0, GDK_r, GDK_MOD1_MASK},
-    {N_("Delete ..."), (void *) cb_delete, 0, GDK_x, GDK_CONTROL_MASK},
-    {N_("Duplicate"), (void *) cb_duplicate, 0, GDK_d, GDK_MOD1_MASK},
+    {N_("Rename ..."), (gpointer) cb_rename, 0, GDK_r, GDK_MOD1_MASK},
+    {N_("Delete ..."), (gpointer) cb_delete, 0, GDK_x, GDK_CONTROL_MASK},
+    {N_("Duplicate"), (gpointer) cb_duplicate, 0, GDK_d, GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("Go to ..."), (void *) cb_go_to, 0},
-    {N_("Go up"), (void *) cb_go_up, 0, GDK_u, GDK_MOD1_MASK},
-    {N_("Go home"), (void *) cb_go_home, 0, GDK_h, GDK_MOD1_MASK},
+    {N_("Go to ..."), (gpointer) cb_go_to, 0},
+    {N_("Go up"), (gpointer) cb_go_up, 0, GDK_u, GDK_MOD1_MASK},
+    {N_("Go home"), (gpointer) cb_go_home, 0, GDK_h, GDK_MOD1_MASK},
     {NULL, NULL, 0},
 
-    {N_("Unselect"), (void *) cb_unselect, 0, GDK_a,
+    {N_("Unselect"), (gpointer) cb_unselect, 0, GDK_a,
      GDK_SHIFT_MASK | GDK_MOD1_MASK},
-    {N_("Select all"), (void *) cb_select, 0, GDK_a, GDK_MOD1_MASK},
-    {N_("Unselect all"), (void *) cb_unselect, 0},
+    {N_("Select all"), (gpointer) cb_select, 0, GDK_a, GDK_MOD1_MASK},
+    {N_("Unselect all"), (gpointer) cb_unselect, 0},
     {NULL, NULL, 0},
-    {N_("Properties ..."), (void *) cb_props, 0, GDK_i, GDK_MOD1_MASK},
-    {N_("Register ..."), (void *) cb_register, 0, GDK_j, GDK_MOD1_MASK},
+    {N_("Properties ..."), (gpointer) cb_props, 0, GDK_i, GDK_MOD1_MASK},
+    {N_("Register ..."), (gpointer) cb_register, 0, GDK_j, GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("Empty Trash"), (void *) cb_empty_trash, 0, GDK_e, GDK_MOD1_MASK},
-    {N_("Open Trash"), (void *) cb_open_trash, WINCFG, GDK_t, GDK_MOD1_MASK},
-    {N_("About ..."), (void *) cb_about, 0, GDK_a, GDK_CONTROL_MASK},
+    {N_("Empty Trash"), (gpointer) cb_empty_trash, 0, GDK_e, GDK_MOD1_MASK},
+    {N_("Open Trash"), (gpointer) cb_open_trash, WINCFG, GDK_t, GDK_MOD1_MASK},
+    {N_("About ..."), (gpointer) cb_about, 0, GDK_a, GDK_CONTROL_MASK},
     {NULL, NULL, 0},
-    {N_("Run program ..."), (void *) cb_exec, WINCFG},
-    {N_("Close window"), (void *) cb_destroy, TOPWIN, GDK_w, GDK_MOD1_MASK},
-    {N_("Quit"), (void *) gtk_main_quit, 0, GDK_q, GDK_MOD1_MASK},
+    {N_("Run program ..."), (gpointer) cb_exec, WINCFG},
+    {N_("Close window"), (gpointer) cb_destroy, TOPWIN, GDK_w, GDK_MOD1_MASK},
+    {N_("Quit"), (gpointer) gtk_main_quit, 0, GDK_q, GDK_MOD1_MASK},
   };
 #define LAST_FILE_MENU_ENTRY (sizeof(file_mlist)/sizeof(menu_entry))
 
   menu_entry mixed_mlist[] = {
-    {N_("New windows"), (void *) cb_new_window, 0},
+    {N_("New windows"), (gpointer) cb_new_window, 0},
     {NULL, NULL, 0},
-    {N_("Delete ..."), (void *) cb_delete, 0, GDK_x, GDK_CONTROL_MASK},
+    {N_("Delete ..."), (gpointer) cb_delete, 0, GDK_x, GDK_CONTROL_MASK},
     {NULL, NULL, 0},
-    {N_("Go to ..."), (void *) cb_go_to, 0},
-    {N_("Go up"), (void *) cb_go_up, 0, GDK_u, GDK_MOD1_MASK},
-    {N_("Go home"), (void *) cb_go_home, 0, GDK_h, GDK_MOD1_MASK},
+    {N_("Go to ..."), (gpointer) cb_go_to, 0},
+    {N_("Go up"), (gpointer) cb_go_up, 0, GDK_u, GDK_MOD1_MASK},
+    {N_("Go home"), (gpointer) cb_go_home, 0, GDK_h, GDK_MOD1_MASK},
     {NULL, NULL, 0},
 
-    {N_("Unselect"), (void *) cb_unselect, 0, GDK_a,
+    {N_("Unselect"), (gpointer) cb_unselect, 0, GDK_a,
      GDK_SHIFT_MASK | GDK_MOD1_MASK},
-    {N_("Select all"), (void *) cb_select, 0, GDK_a, GDK_MOD1_MASK},
-    {N_("Unselect all"), (void *) cb_unselect, 0},
-    {N_("Find ..."), (void *) cb_find, 0, GDK_f, GDK_MOD1_MASK},
+    {N_("Select all"), (gpointer) cb_select, 0, GDK_a, GDK_MOD1_MASK},
+    {N_("Unselect all"), (gpointer) cb_unselect, 0},
+    {N_("Find ..."), (gpointer) cb_find, 0, GDK_f, GDK_MOD1_MASK},
 
-    {N_("Toggle Dotfiles"), (void *) on_dotfiles, 0, GDK_D,
+    {N_("Toggle Dotfiles"), (gpointer) on_dotfiles, 0, GDK_D,
      GDK_SHIFT_MASK | GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("Empty Trash"), (void *) cb_empty_trash, 0},
-    {N_("Open Trash"), (void *) cb_open_trash, WINCFG},
+    {N_("Empty Trash"), (gpointer) cb_empty_trash, 0},
+    {N_("Open Trash"), (gpointer) cb_open_trash, WINCFG},
     {NULL, NULL, 0},
-    {N_("Empty Trash"), (void *) cb_empty_trash, 0, GDK_e, GDK_MOD1_MASK},
-    {N_("Open Trash"), (void *) cb_open_trash, WINCFG, GDK_t, GDK_MOD1_MASK},
-    {N_("About ..."), (void *) cb_about, 0, GDK_a, GDK_CONTROL_MASK},
+    {N_("Empty Trash"), (gpointer) cb_empty_trash, 0, GDK_e, GDK_MOD1_MASK},
+    {N_("Open Trash"), (gpointer) cb_open_trash, WINCFG, GDK_t, GDK_MOD1_MASK},
+    {N_("About ..."), (gpointer) cb_about, 0, GDK_a, GDK_CONTROL_MASK},
     {NULL, NULL, 0},
-    {N_("Run program ..."), (void *) cb_exec, WINCFG},
-    {N_("Close window"), (void *) cb_destroy, TOPWIN, GDK_w, GDK_MOD1_MASK},
-    {N_("Quit"), (void *) gtk_main_quit, 0, GDK_q, GDK_MOD1_MASK},
+    {N_("Run program ..."), (gpointer) cb_exec, WINCFG},
+    {N_("Close window"), (gpointer) cb_destroy, TOPWIN, GDK_w, GDK_MOD1_MASK},
+    {N_("Quit"), (gpointer) gtk_main_quit, 0, GDK_q, GDK_MOD1_MASK},
   };
 #define LAST_MIXED_MENU_ENTRY (sizeof(mixed_mlist)/sizeof(menu_entry))
 
   menu_entry none_mlist[] = {
-    {N_("New window"), (void *) cb_new_window, 0},
+    {N_("New window"), (gpointer) cb_new_window, 0},
     {NULL, NULL, 0},
-    {N_("New Folder ..."), (void *) cb_new_subdir, 0},
-    {N_("New file ..."), (void *) cb_new_file, 0, GDK_k, GDK_MOD1_MASK},
+    {N_("New Folder ..."), (gpointer) cb_new_subdir, 0},
+    {N_("New file ..."), (gpointer) cb_new_file, 0, GDK_k, GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("Go to ..."), (void *) cb_go_to, 0},
-    {N_("Go up"), (void *) cb_go_up, 0, GDK_u, GDK_MOD1_MASK},
-    {N_("Go home"), (void *) cb_go_home, 0},
+    {N_("Go to ..."), (gpointer) cb_go_to, 0},
+    {N_("Go up"), (gpointer) cb_go_up, 0, GDK_u, GDK_MOD1_MASK},
+    {N_("Go home"), (gpointer) cb_go_home, 0},
     {NULL, NULL, 0},
-    {N_("Select all"), (void *) cb_select, 0, GDK_a, GDK_MOD1_MASK},
-    {N_("Unselect all"), (void *) cb_unselect, 0},
+    {N_("Select all"), (gpointer) cb_select, 0, GDK_a, GDK_MOD1_MASK},
+    {N_("Unselect all"), (gpointer) cb_unselect, 0},
 
-    {N_("Toggle Dotfiles"), (void *) on_dotfiles, 0, GDK_D,
+    {N_("Toggle Dotfiles"), (gpointer) on_dotfiles, 0, GDK_D,
      GDK_SHIFT_MASK | GDK_MOD1_MASK},
     {NULL, NULL, 0},
-    {N_("Find ..."), (void *) cb_find, 0, GDK_f, GDK_MOD1_MASK},
-    {N_("Empty Trash"), (void *) cb_empty_trash, 0, GDK_e, GDK_MOD1_MASK},
-    {N_("Open Trash"), (void *) cb_open_trash, WINCFG, GDK_t, GDK_MOD1_MASK},
-    {N_("About ..."), (void *) cb_about, 0, GDK_a, GDK_CONTROL_MASK},
+    {N_("Find ..."), (gpointer) cb_find, 0, GDK_f, GDK_MOD1_MASK},
+    {N_("Empty Trash"), (gpointer) cb_empty_trash, 0, GDK_e, GDK_MOD1_MASK},
+    {N_("Open Trash"), (gpointer) cb_open_trash, WINCFG, GDK_t, GDK_MOD1_MASK},
+    {N_("About ..."), (gpointer) cb_about, 0, GDK_a, GDK_CONTROL_MASK},
     {NULL, NULL, 0},
-    {N_("Run program ..."), (void *) cb_exec, WINCFG},
-    {N_("Close window"), (void *) cb_destroy, TOPWIN, GDK_w, GDK_MOD1_MASK},
-    {N_("Quit"), (void *) gtk_main_quit, 0, GDK_q, GDK_MOD1_MASK},
+    {N_("Run program ..."), (gpointer) cb_exec, WINCFG},
+    {N_("Close window"), (gpointer) cb_destroy, TOPWIN, GDK_w, GDK_MOD1_MASK},
+    {N_("Quit"), (gpointer) gtk_main_quit, 0, GDK_q, GDK_MOD1_MASK},
   };
 #define LAST_NONE_MENU_ENTRY (sizeof(none_mlist)/sizeof(menu_entry))
 
@@ -3054,9 +3076,9 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width,
   label[COL_DATE] = "";
   top = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_signal_connect (GTK_OBJECT (top), "destroy",
-		      GTK_SIGNAL_FUNC (on_destroy), (void *) win);
+		      GTK_SIGNAL_FUNC (on_destroy), (gpointer) win);
   gtk_signal_connect (GTK_OBJECT (top), "delete_event",
-		      GTK_SIGNAL_FUNC (on_delete), (void *) win);
+		      GTK_SIGNAL_FUNC (on_delete), (gpointer) win);
   top_register (top);
 
   vbox = gtk_vbox_new (FALSE, 0);
@@ -3098,7 +3120,7 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width,
 			      GDK_CONTROL_MASK | GDK_MOD1_MASK,
 			      GTK_ACCEL_VISIBLE);
 
-  win->compare = (void *) GTK_CLIST (ctree)->compare;
+  win->compare = (gpointer) GTK_CLIST (ctree)->compare;
   win->trash = g_strdup (trash);
   win->xap = g_strdup (xap);
   win->reg = reg;
@@ -3140,7 +3162,7 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width,
 	  else
 	    gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
 				GTK_SIGNAL_FUNC (dir_mlist[i].func),
-				(void *) ctree);
+				(gpointer) ctree);
 	}
       if (dir_mlist[i].key)
 	{
@@ -3174,7 +3196,7 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width,
 	  else
 	    gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
 				GTK_SIGNAL_FUNC (file_mlist[i].func),
-				(void *) ctree);
+				(gpointer) ctree);
 	}
       if (file_mlist[i].key)
 	{
@@ -3208,7 +3230,7 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width,
 	  else
 	    gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
 				GTK_SIGNAL_FUNC (mixed_mlist[i].func),
-				(void *) ctree);
+				(gpointer) ctree);
 	}
       if (mixed_mlist[i].key)
 	{
@@ -3243,7 +3265,7 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width,
 	  else
 	    gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
 				GTK_SIGNAL_FUNC (none_mlist[i].func),
-				(void *) ctree);
+				(gpointer) ctree);
 	}
       if (none_mlist[i].key)
 	{
@@ -3312,11 +3334,12 @@ new_top (char *path, char *xap, char *trash, GList * reg, int width,
   toolbar = create_toolbar (top, ctree, win);
   gtk_container_add (GTK_CONTAINER (handlebox2), toolbar);
   gtk_widget_show (toolbar);
-
   icon_name = strrchr (path, '/');
   if ((icon_name) && (!(*(++icon_name))))
     icon_name = NULL;
+
   set_icon (top, (icon_name ? icon_name : "/"), xftree_icon_xpm);
+
   return (top);
 }
 
@@ -3330,48 +3353,39 @@ gui_main (char *path, char *xap_path, char *trash, char *reg_file,
   GList *reg;
   GtkWidget *top, *new_win;
 
-  XFCE_palette *pal;
-
-  pal = newpal ();
-  defpal (pal);
-  loadpal (pal);
-  applypal (pal, NULL);
-
-  global_pal = pal;
-
-  top = gtk_window_new (GTK_WINDOW_DIALOG);
+  top = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_widget_realize (top);
-  reg = reg_build_list (reg_file);
 
-  gPIX_page = MyCreateGdkPixmapFromData (page_xpm, top, &gPIM_page);
+  gPIX_page = MyCreateGdkPixmapFromData (page_xpm, top, &gPIM_page, FALSE);
   gPIX_page_lnk =
-    MyCreateGdkPixmapFromData (page_lnk_xpm, top, &gPIM_page_lnk);
-  gPIX_dir_pd = MyCreateGdkPixmapFromData (dir_pd_xpm, top, &gPIM_dir_pd);
+    MyCreateGdkPixmapFromData (page_lnk_xpm, top, &gPIM_page_lnk, FALSE);
+  gPIX_dir_pd = MyCreateGdkPixmapFromData (dir_pd_xpm, top, &gPIM_dir_pd, FALSE);
   gPIX_dir_open =
-    MyCreateGdkPixmapFromData (dir_open_xpm, top, &gPIM_dir_open);
+    MyCreateGdkPixmapFromData (dir_open_xpm, top, &gPIM_dir_open, FALSE);
   gPIX_dir_open_lnk =
-    MyCreateGdkPixmapFromData (dir_open_lnk_xpm, top, &gPIM_dir_open_lnk);
+    MyCreateGdkPixmapFromData (dir_open_lnk_xpm, top, &gPIM_dir_open_lnk, FALSE);
   gPIX_dir_close =
-    MyCreateGdkPixmapFromData (dir_close_xpm, top, &gPIM_dir_close);
+    MyCreateGdkPixmapFromData (dir_close_xpm, top, &gPIM_dir_close, FALSE);
   gPIX_dir_close_lnk =
-    MyCreateGdkPixmapFromData (dir_close_lnk_xpm, top, &gPIM_dir_close_lnk);
-  gPIX_dir_up = MyCreateGdkPixmapFromData (dir_up_xpm, top, &gPIM_dir_up);
-  gPIX_exe = MyCreateGdkPixmapFromData (exe_xpm, top, &gPIM_exe);
-  gPIX_exe_lnk = MyCreateGdkPixmapFromData (exe_lnk_xpm, top, &gPIM_exe_lnk);
+    MyCreateGdkPixmapFromData (dir_close_lnk_xpm, top, &gPIM_dir_close_lnk, FALSE);
+  gPIX_dir_up = MyCreateGdkPixmapFromData (dir_up_xpm, top, &gPIM_dir_up, FALSE);
+  gPIX_exe = MyCreateGdkPixmapFromData (exe_xpm, top, &gPIM_exe, FALSE);
+  gPIX_exe_lnk = MyCreateGdkPixmapFromData (exe_lnk_xpm, top, &gPIM_exe_lnk, FALSE);
   gPIX_char_dev =
-    MyCreateGdkPixmapFromData (char_dev_xpm, top, &gPIM_char_dev);
+    MyCreateGdkPixmapFromData (char_dev_xpm, top, &gPIM_char_dev, FALSE);
   gPIX_block_dev =
-    MyCreateGdkPixmapFromData (block_dev_xpm, top, &gPIM_block_dev);
-  gPIX_fifo = MyCreateGdkPixmapFromData (fifo_xpm, top, &gPIM_fifo);
-  gPIX_socket = MyCreateGdkPixmapFromData (socket_xpm, top, &gPIM_socket);
+    MyCreateGdkPixmapFromData (block_dev_xpm, top, &gPIM_block_dev, FALSE);
+  gPIX_fifo = MyCreateGdkPixmapFromData (fifo_xpm, top, &gPIM_fifo, FALSE);
+  gPIX_socket = MyCreateGdkPixmapFromData (socket_xpm, top, &gPIM_socket, FALSE);
   gPIX_stale_lnk =
-    MyCreateGdkPixmapFromData (stale_lnk_xpm, top, &gPIM_stale_lnk);
+    MyCreateGdkPixmapFromData (stale_lnk_xpm, top, &gPIM_stale_lnk, FALSE);
 
   if (!io_is_directory (path))
     {
       dlg_error (path, strerror (errno));
       return;
     }
+  reg = reg_build_list (reg_file);
   new_win =
     new_top (path, xap_path, trash, reg, geo->width, geo->height, flags);
   if (geo->x > -1 && geo->y > -1)
@@ -3379,7 +3393,7 @@ gui_main (char *path, char *xap_path, char *trash, char *reg_file,
       gtk_widget_set_uposition (new_win, geo->x, geo->y);
     }
 
-  reg_xfce_app (new_win, pal);
-  gtk_widget_destroy (top);
   gtk_main ();
+  gtk_widget_destroy (top);
+  exit (0);
 }
