@@ -4,6 +4,9 @@
  * Copyright (C) 1999 Rasca, Berlin
  * EMail: thron@gmx.de
  *
+ * Olivier Fourdan (fourdan@xfce.org)
+ * Heavily modified as part of the Xfce project (http://www.xfce.org)
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -31,6 +34,5 @@ typedef struct
 }
 wgeo_t;
 
-void gui_init (int *argc, char ***argv, char *rc);
 void gui_main (char *path, char *xap, char *trash, char *reg, wgeo_t *, int);
 #endif
