@@ -256,6 +256,7 @@ AddWindow (Window w)
       if ((status == True) && (rm_value.size != 0))
 	{
 	  Desk = atoi (rm_value.addr);
+          Desk = ((Desk > 0) ? Desk - 1 : 0);
 	  tflag |= STARTSONDESK_FLAG;
 	}
       XrmDestroyDatabase (db);
@@ -263,14 +264,8 @@ AddWindow (Window w)
       XFreeStringList (client_argv);
     }
 
-  if (!PlaceWindow (tmp_win, tflag, Desk))
-    {
-      free ((char *) tmp_win);
-      return (NULL);
-    }
-
-  /* Load Session Management saved values */
-  MatchWinToSM (tmp_win);
+  /* Clear recapture flag */
+  tmp_win->flags &= ~RECAPTURE;
 
   /* If restarting, retrieve parameters saved as Atoms */
   if ((XGetWindowProperty (dpy, tmp_win->w, _XA_XFWM_FLAGS, 0L, 1L, True,
@@ -280,7 +275,7 @@ AddWindow (Window w)
       if (prop != NULL)
 	{
 	  tmp_win->flags |=
-	    (*(unsigned long *) prop) & (STICKY | ICON_MOVED | SHADED);
+	    (*(unsigned long *) prop) & (STICKY | ICON_MOVED | SHADED | RECAPTURE);
 	  XFree (prop);
 	}
     }
@@ -307,6 +302,17 @@ AddWindow (Window w)
 	}
     }
 
+  if (!PlaceWindow (tmp_win, tflag, Desk))
+    {
+      free ((char *) tmp_win);
+      return (NULL);
+    }
+  /* Once placement is computed, set recapture to false */
+  tmp_win->flags &= ~RECAPTURE;
+  
+  /* Load Session Management saved values */
+  MatchWinToSM (tmp_win);
+
   /*
    * Make sure the client window still exists.  We don't want to leave an
    * orphan frame window if it doesn't.  Since we now have the server
@@ -407,7 +413,7 @@ AddWindow (Window w)
 
   valuemask |= CWCursor | CWEventMask;
   attributes.cursor = Scr.XfwmCursors[DEFAULT];
-  attributes.event_mask = (SubstructureRedirectMask |
+  attributes.event_mask = (SubstructureRedirectMask | 
 			   ButtonPressMask | ButtonReleaseMask |
 			   EnterWindowMask | LeaveWindowMask | 
                            ExposureMask);
@@ -618,10 +624,10 @@ AddWindow (Window w)
   if (!(XGetWindowAttributes (dpy, tmp_win->w, &(tmp_win->attr))))
     tmp_win->attr.colormap = Scr.XfwmRoot.attr.colormap;
   InstallWindowColormaps (colormap_win);
-
+  /*
   if (tmp_win->flags & SHADED)
     XUnmapWindow (dpy, tmp_win->Parent);
-
+   */
   return (tmp_win);
 }
 
@@ -870,7 +876,7 @@ LookInList (name_list * list, char *name, XClassHint * class,
 	      if (nptr->value != NULL)
 		*value = nptr->value;
 	      if (nptr->off_flags & STARTSONDESK_FLAG)
-		*Desk = nptr->Desk;
+          	*Desk = ((nptr->Desk > 0) ? nptr->Desk - 1 : 0);
 	      if (nptr->off_flags & BW_FLAG)
 		*border_width = nptr->border_width;
 	      if (nptr->off_flags & FORE_COLOR_FLAG)
@@ -889,7 +895,7 @@ LookInList (name_list * list, char *name, XClassHint * class,
 	      if (nptr->value != NULL)
 		*value = nptr->value;
 	      if (nptr->off_flags & STARTSONDESK_FLAG)
-		*Desk = nptr->Desk;
+          	*Desk = ((nptr->Desk > 0) ? nptr->Desk - 1 : 0);
 	      if (nptr->off_flags & FORE_COLOR_FLAG)
 		*forecolor = nptr->ForeColor;
 	      if (nptr->off_flags & BACK_COLOR_FLAG)
@@ -908,7 +914,7 @@ LookInList (name_list * list, char *name, XClassHint * class,
 	  if (nptr->value != NULL)
 	    *value = nptr->value;
 	  if (nptr->off_flags & STARTSONDESK_FLAG)
-	    *Desk = nptr->Desk;
+            *Desk = ((nptr->Desk > 0) ? nptr->Desk - 1 : 0);
 	  if (nptr->off_flags & FORE_COLOR_FLAG)
 	    *forecolor = nptr->ForeColor;
 	  if (nptr->off_flags & BACK_COLOR_FLAG)
