@@ -842,6 +842,7 @@ SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h,
   int xwidth, ywidth, left, right, horig;
   int cx, cy, i;
   unsigned long winmask;
+  int center_x, center_y;
 
   horig = h;
 
@@ -859,14 +860,16 @@ SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h,
       tmp_win->orig_wd = w;
       tmp_win->orig_ht = horig;
     }
-  if (x >= Scr.MyDisplayWidth - 16)
-    x = Scr.MyDisplayWidth - 16;
-  if (y >= Scr.MyDisplayHeight - 16)
-    y = Scr.MyDisplayHeight - 16;
-  if (x <= 16 - w)
-    x = 16 - w;
-  if (y <= 16 - h)
-    y = 16 - h;
+  center_x = x + (w / 2);
+  center_y = y + (h / 2);
+  if (x >= MyDisplayMaxX(center_x, center_y) - 16)
+    x = MyDisplayMaxX(center_x, center_y) - 16;
+  if (y >= MyDisplayMaxY(center_x, center_y) - 16)
+    y = MyDisplayMaxY(center_x, center_y) - 16;
+  if (x <= MyDisplayX(center_x, center_y) + 16 - w)
+    x = MyDisplayX(center_x, center_y) + 16 - w;
+  if (y <= MyDisplayY(center_x, center_y) + 16 - h)
+    y = MyDisplayY(center_x, center_y) + 16 - h;
 
   if ((w != tmp_win->frame_width) || (h != tmp_win->frame_height))
     Resized = True;
@@ -1054,7 +1057,11 @@ SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h,
   cy = tmp_win->title_height + tmp_win->boundary_width - tmp_win->bw;
 
   XResizeWindow (dpy, tmp_win->w, tmp_win->attr.width, tmp_win->attr.height);
-  XMoveResizeWindow (dpy, tmp_win->Parent, cx, cy,
+  if (tmp_win->flags & SHADED)
+    XMoveResizeWindow (dpy, tmp_win->Parent, cx, cy - tmp_win->attr.height - tmp_win->title_height - tmp_win->boundary_width,
+		     tmp_win->attr.width, tmp_win->attr.height);
+  else
+    XMoveResizeWindow (dpy, tmp_win->Parent, cx, cy,
 		     tmp_win->attr.width, tmp_win->attr.height);
   /* 
    * fix up frame and assign size/location values in tmp_win
