@@ -11,6 +11,7 @@
 #include "my_intl.h"
 
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <sys/time.h>
 
 #include <stdio.h>
@@ -18,6 +19,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
+#include <fcntl.h>
 #include <errno.h>
 
 #include "xfwm.h"
@@ -85,6 +87,34 @@ Animate (int o_x, int o_y, int o_w, int o_h,
     }
 }
 
+void
+ShowMeMouse (XEvent * eventp, Window junk, XfwmWindow * tmp_win,
+	       unsigned long context, char *action, int *Module)
+{
+  XGCValues gcv;
+  int xl, yt;
+  int i;
+
+  XQueryPointer (dpy, Scr.Root, &JunkRoot, &JunkChild, &xl, &yt,
+		 &JunkX, &JunkY, &JunkMask);
+  
+  gcv.line_width = 5;
+
+  XChangeGC (dpy, Scr.DrawGC, GCLineWidth, &gcv);
+
+  XSync (dpy, 0);
+  MyXGrabServer (dpy);
+
+  for (i = 10; i < 120; i+=10)
+    {
+      XDrawArc(dpy, Scr.Root, Scr.DrawGC, xl - (i / 2), yt- (i / 2), i, i, 0, 360 * 64);
+      XSync (dpy, 0);
+      my_sleep (1);
+      XDrawArc(dpy, Scr.Root, Scr.DrawGC, xl - (i / 2), yt- (i / 2), i, i, 0, 360 * 64);
+    }
+  MyXUngrabServer (dpy);
+}
+
 /***********************************************************************
  *
  *  Procedure:
@@ -213,8 +243,6 @@ DeferExecution (XEvent * eventp, Window * w, XfwmWindow ** tmp_win,
 void
 FocusOn (XfwmWindow * t, int DeIconifyOnly)
 {
-  int dx, dy;
-  int cx, cy;
   int x, y;
 
   if (t == (XfwmWindow *) 0)
@@ -222,23 +250,12 @@ FocusOn (XfwmWindow * t, int DeIconifyOnly)
 
   if (t->Desk != Scr.CurrentDesk)
     {
-      changeDesks (0, t->Desk, 1, 1, 1);
+      if ((t->Desk >=0) && (t->Desk < Scr.ndesks))
+        changeDesks (0, t->Desk, 1, 1, 1);
+      else
+        sendWindowsDesk (Scr.CurrentDesk, t);
     }
 
-  if (t->flags & ICONIFIED)
-    {
-      cx = t->icon_xl_loc + t->icon_w_width / 2;
-      cy = t->icon_y_loc + t->icon_p_height + ICON_HEIGHT / 2;
-    }
-  else
-    {
-      cx = t->frame_x + t->frame_width / 2;
-      cy = t->frame_y + t->frame_height / 2;
-    }
-
-  dx = cx / Scr.MyDisplayWidth * Scr.MyDisplayWidth;
-  dy = cy / Scr.MyDisplayHeight * Scr.MyDisplayHeight;
-
   if (t->flags & ICONIFIED)
     {
       x = t->icon_xl_loc + t->icon_w_width / 2;
@@ -271,8 +288,6 @@ FocusOn (XfwmWindow * t, int DeIconifyOnly)
 void
 WarpOn (XfwmWindow * t, int warp_x, int x_unit, int warp_y, int y_unit)
 {
-  int dx, dy;
-  int cx, cy;
   int x, y;
 
   if (t == (XfwmWindow *) 0 || (t->flags & ICONIFIED && t->icon_w == None))
@@ -280,25 +295,12 @@ WarpOn (XfwmWindow * t, int warp_x, int x_unit, int warp_y, int y_unit)
 
   if (t->Desk != Scr.CurrentDesk)
     {
-      changeDesks (0, t->Desk, 1, 1, 1);
+      if ((t->Desk >=0) && (t->Desk < Scr.ndesks))
+        changeDesks (0, t->Desk, 1, 1, 1);
+      else
+        sendWindowsDesk (Scr.CurrentDesk, t);
     }
 
-  if (t->flags & ICONIFIED)
-    {
-      cx = t->icon_xl_loc + t->icon_w_width / 2;
-      cy = t->icon_y_loc + t->icon_p_height + ICON_HEIGHT / 2;
-    }
-  else
-    {
-      cx = t->frame_x + t->frame_width / 2;
-      cy =
-	t->frame_y +
-	((t->flags & SHADED) ? t->shade_height : t->frame_height) / 2;
-    }
-
-  dx = cx / Scr.MyDisplayWidth * Scr.MyDisplayWidth;
-  dy = cy / Scr.MyDisplayHeight * Scr.MyDisplayHeight;
-
   if (t->flags & ICONIFIED)
     {
       x = t->icon_xl_loc + t->icon_w_width / 2 + 2;
@@ -306,11 +308,11 @@ WarpOn (XfwmWindow * t, int warp_x, int x_unit, int warp_y, int y_unit)
     }
   else
     {
-      if (x_unit != Scr.MyDisplayWidth)
+      if (x_unit != MyDisplayWidth (warp_x, warp_y))
 	x = t->frame_x + 2 + warp_x;
       else
 	x = t->frame_x + 2 + (t->frame_width - 4) * warp_x / 100;
-      if (y_unit != Scr.MyDisplayHeight)
+      if (y_unit != MyDisplayHeight (warp_x, warp_y))
 	y = t->frame_y + 2 + warp_y;
       else
 	y =
@@ -320,7 +322,10 @@ WarpOn (XfwmWindow * t, int warp_x, int x_unit, int warp_y, int y_unit)
     }
   if (warp_x >= 0 && warp_y >= 0)
     {
-      XWarpPointer (dpy, None, Scr.Root, 0, 0, 0, 0, x, y);
+       XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                     0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+                     my_min(MyDisplayMaxX(x,y) - 1, x),
+                     my_min(MyDisplayMaxY(x,y) - 1, y));
     }
   RaiseWindow (t);
 
@@ -373,28 +378,14 @@ Shade (XfwmWindow * tmp_win)
   tmp_win->shade_y = tmp_win->frame_y;
   tmp_win->shade_width = tmp_win->frame_width;
   tmp_win->shade_height = tmp_win->title_height + 2 * tmp_win->boundary_width;
-  XUnmapWindow (dpy, tmp_win->Parent);
+  /* XUnmapWindow (dpy, tmp_win->Parent); */
+  
   SetupFrame (tmp_win, tmp_win->frame_x, tmp_win->frame_y,
 	      tmp_win->frame_width, tmp_win->frame_height, TRUE, TRUE);
+  SetTitleBar (tmp_win, (Scr.Hilite == tmp_win), True);
+  SetBorder (tmp_win, Scr.Hilite == tmp_win, True, True, None);
   Broadcast (XFCE_M_SHADE, 3, tmp_win->w, tmp_win->frame,
 	     (unsigned long) tmp_win, 0, 0, 0, 0);
-  if ((tmp_win == Scr.Focus) && (tmp_win->Desk == Scr.CurrentDesk))
-    {
-      if ((tmp_win->next) && !((tmp_win->next)->flags & SHADED)
-	  && !((tmp_win->next) == &Scr.XfwmRoot))
-	{
-	  RaiseWindow (tmp_win->next);
-	  SetFocus (tmp_win->next->w, tmp_win->next, 1);
-	}
-      else if ((tmp_win->prev) && !((tmp_win->prev)->flags & SHADED)
-	       && !((tmp_win->prev) == &Scr.XfwmRoot))
-	{
-	  RaiseWindow (tmp_win->prev);
-	  SetFocus (tmp_win->prev->w, tmp_win->prev, 1);
-	}
-      else
-	SetFocus (Scr.NoFocusWin, NULL, 1);
-    }
 }
 
 void
@@ -420,8 +411,10 @@ Unshade (XfwmWindow * tmp_win)
   tmp_win->frame_height = 0;	/* force redrawing frame */
   SetupFrame (tmp_win, tmp_win->frame_x, tmp_win->frame_y,
 	      tmp_win->frame_width, tmp, TRUE, TRUE);
+  /*
   XMapWindow (dpy, tmp_win->w);
   XMapWindow (dpy, tmp_win->Parent);
+   */
   if (tmp_win->Desk == Scr.CurrentDesk)
     {
       SetBorder (tmp_win, True, True, True, None);
@@ -429,6 +422,8 @@ Unshade (XfwmWindow * tmp_win)
       FocusOn (tmp_win, 1);
       KeepOnTop ();
     }
+  SetTitleBar (tmp_win, (Scr.Hilite == tmp_win), True);
+  SetBorder (tmp_win, Scr.Hilite == tmp_win, True, True, None);
   Broadcast (XFCE_M_UNSHADE, 3, tmp_win->w, tmp_win->frame,
 	     (unsigned long) tmp_win, 0, 0, 0, 0);
 }
@@ -473,6 +468,8 @@ Maximize (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 {
   int new_width, new_height, new_x, new_y;
   int val1, val2, val1_unit, val2_unit, n;
+  int center_x;
+  int center_y;
 
   if (DeferExecution (eventp, &w, &tmp_win, &context, SELECT, ButtonRelease))
     return;
@@ -480,13 +477,16 @@ Maximize (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   if (tmp_win == NULL)
     return;
 
-  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit);
+  center_x = tmp_win->frame_x + (tmp_win->frame_width / 2);
+  center_y = tmp_win->frame_y + (tmp_win->frame_height / 2);
+
+  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit, center_x, center_y);
   if (n != 2)
     {
       val1 = 100;
       val2 = 100;
-      val1_unit = Scr.MyDisplayWidth;
-      val2_unit = Scr.MyDisplayHeight;
+      val1_unit = MyDisplayWidth(center_x, center_y);
+      val2_unit = MyDisplayHeight(center_x, center_y);
     }
 
   if (tmp_win->flags & MAXIMIZED)
@@ -520,6 +520,11 @@ Maximize (XEvent * eventp, Window w, XfwmWindow * tmp_win,
     }
   else
     {
+      
+      /* Transient windows can't be maximized separately */
+      if (tmp_win->flags & TRANSIENT)
+        return;
+
       new_width = tmp_win->frame_width;
       new_height = tmp_win->frame_height;
       new_x = tmp_win->frame_x;
@@ -527,19 +532,19 @@ Maximize (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       if (val1 > 0)
 	{
 	  new_width = val1 * val1_unit / 100;
-	  new_x = 0;
+	  new_x = MyDisplayX (center_x, center_y);
 	}
       if (val2 > 0)
 	{
 	  new_height = val2 * val2_unit / 100;
-	  new_y = 0;
+	  new_y = MyDisplayY (center_x, center_y);
 	}
       if ((val1 == 0) && (val2 == 0))
 	{
-	  new_x = 0;
-	  new_y = 0;
-	  new_height = Scr.MyDisplayHeight;
-	  new_width = Scr.MyDisplayWidth;
+	  new_x      = MyDisplayX (center_x, center_y);
+	  new_y      = MyDisplayY (center_x, center_y);
+	  new_height = MyDisplayHeight(center_x, center_y);
+	  new_width  = MyDisplayWidth(center_x, center_y);
 	}
       tmp_win->flags |= MAXIMIZED;
       if (!(tmp_win->flags & ICONIFIED))
@@ -621,7 +626,7 @@ add_item_to_menu (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   last_menu = token;
   rest = GetNextToken (rest, &item);
 
-  AddToMenu (mr, item, rest);
+  AddToMenu (mr, (strlen (item) ? _(item) : item), rest);
   free (item);
 
   MakeMenu (mr);
@@ -704,14 +709,17 @@ movecursor (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 {
   int x, y;
   int val1, val2, val1_unit, val2_unit, n;
-
-  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit);
+  int warpx, warpy;
 
   XQueryPointer (dpy, Scr.Root, &JunkRoot, &JunkChild,
 		 &x, &y, &JunkX, &JunkY, &JunkMask);
-  XWarpPointer (dpy, Scr.Root, Scr.Root, 0, 0, Scr.MyDisplayWidth,
-		Scr.MyDisplayHeight, x + val1 * val1_unit / 100,
-		y + val2 * val2_unit / 100);
+  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit, x, y);
+  warpx = x + val1 * val1_unit / 100; 
+  warpy = y + val2 * val2_unit / 100;
+  XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+		my_min(MyDisplayMaxX(warpx,warpy) - 1, warpx),
+		my_min(MyDisplayMaxY(warpx,warpy) - 1, warpy));
 }
 
 
@@ -725,7 +733,7 @@ iconify_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   if (DeferExecution (eventp, &w, &tmp_win, &context, SELECT, ButtonRelease))
     return;
 
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
 
   if (tmp_win->flags & ICONIFIED)
     {
@@ -736,6 +744,33 @@ iconify_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
     Iconify (tmp_win, eventp->xbutton.x_root - 5, eventp->xbutton.y_root - 5);
 }
 
+void
+Iconify_all (XEvent * eventp, Window w, XfwmWindow * tmp_win,
+	     unsigned long context, char *action, int *Module)
+{
+  XfwmWindow *t;
+  unsigned int opt;
+  
+  opt = Scr.Options & AnimateWin;
+  Scr.Options &= ~AnimateWin;
+
+  t = &Scr.XfwmRoot;
+  while ((t) && (t->next != NULL))
+    {
+      t = t->next;
+      if (!(t->flags & ICONIFIED) &&
+          !(t->flags & TRANSIENT) &&
+          (t->flags & TITLE) &&
+          (t->Desk == Scr.CurrentDesk))
+        {
+          Iconify (t, 0, 0);
+          /* Restart from scratch */
+          t = &Scr.XfwmRoot;
+        } 
+    }
+  Scr.Options |= opt;
+}
+
 void
 raise_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		unsigned long context, char *action, int *Module)
@@ -824,7 +859,7 @@ void
 restart_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		  unsigned long context, char *action, int *Module)
 {
-  Done (1, action);
+  Done (XFWM_RESTART, action);
 }
 
 void
@@ -854,6 +889,7 @@ exec_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 	       unsigned long context, char *action, int *Module)
 {
   char *cmd = NULL;
+  int nulldev;
 
   /* if it doesn't already have an 'exec' as the first word, add that
    * to keep down number of procs started */
@@ -875,6 +911,12 @@ exec_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
    * on the screen */
   if (!(fork ()))		/* child process */
     {
+      /* The following is to avoid X locking when executing 
+         terminal based application that requires user input */
+      if ((nulldev = open ("/dev/null", O_RDWR)))
+        {
+          close (0); dup (nulldev);
+        }
       if (execl (exec_shell_name, exec_shell_name, "-c", cmd, NULL) == -1)
 	{
 	  xfwm_msg (ERR, "exec_function", "execl failed (%s)",
@@ -1058,7 +1100,7 @@ warp_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   if (DeferExecution (eventp, &w, &tmp_win, &context, SELECT, ButtonRelease))
     return;
 
-  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit);
+  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit, 0, 0);
 
   if (n == 2)
     WarpOn (tmp_win, val1, val1_unit, val2, val2_unit);
@@ -1217,7 +1259,7 @@ SetClick (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int val1;
   int val1_unit, n;
 
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
   if (n != 1)
     {
       xfwm_msg (ERR, "SetClick", "ClickTime requires 1 argument");
@@ -1236,7 +1278,7 @@ SetXOR (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   XGCValues gcv;
   unsigned long gcm;
 
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
   if (n != 1)
     {
       xfwm_msg (ERR, "SetXOR", "XORValue requires 1 argument");
@@ -1546,7 +1588,6 @@ SetMenuFont (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   char *font = NULL;
 
   action = GetNextToken (action, &font);
-
   if (Scr.StdFont.font)
     XFreeFont (dpy, Scr.StdFont.font);
   if (Scr.StdFont.fontset)
@@ -1637,8 +1678,8 @@ LoadIconFont (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 
   if (Scr.StdFont.font)
     XFreeFont (dpy, Scr.IconFont.font);
-  if (Scr.StdFont.fontset)
-    XFreeFontSet (dpy, Scr.StdFont.fontset);
+  if (Scr.IconFont.fontset)
+    XFreeFontSet (dpy, Scr.IconFont.fontset);
   if ((Scr.IconFont.font = GetFontOrFixed (dpy, font, &Scr.IconFont.fontset))
       == NULL && Scr.IconFont.fontset == NULL)
     {
@@ -1751,7 +1792,8 @@ LoadWindowFont (XEvent * eventp, Window win, XfwmWindow * tmp_win,
 	  SetTitleBar (tmp, False, True);
 	  tmp = tmp->next;
 	}
-      SetTitleBar (hi, True, True);
+      if (hi)
+        SetTitleBar (hi, True, True);
 
     }
   else
@@ -2165,10 +2207,10 @@ Circulate (char *action, int Direction, char **restofline)
 	      ((useCirculateHitIcon && fw->flags & ICONIFIED) ||
 	       !(fw->flags & CirculateSkipIcon && fw->flags & ICONIFIED)) &&
 	      (!needsCurrentDesk || fw->Desk == Scr.CurrentDesk) &&
-	      (!needsCurrentPage || (fw->frame_x < Scr.MyDisplayWidth &&
-				     fw->frame_y < Scr.MyDisplayHeight &&
-				     fw->frame_x + fw->frame_width > 0 &&
-				     fw->frame_y + fw->frame_height > 0)) &&
+	      (!needsCurrentPage || (fw->frame_x < MyDisplayMaxX (fw->frame_x, fw->frame_y) &&
+				     fw->frame_y < MyDisplayMaxY (fw->frame_x, fw->frame_y) &&
+				     fw->frame_x + fw->frame_width > MyDisplayX (fw->frame_x, fw->frame_y) &&
+				     fw->frame_y + fw->frame_height > MyDisplayY (fw->frame_x, fw->frame_y))) &&
 	      ((!needsName ||
 		matchWildcards (name, fw->name) ||
 		matchWildcards (name, fw->icon_name) ||
@@ -2415,7 +2457,7 @@ SetAutoRaiseDelay (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int val1;
   int val1_unit, n;
 
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
   if (n != 1)
     {
       xfwm_msg (ERR, "SetAutoRaiseDelay",
@@ -2551,7 +2593,7 @@ Arrange_Icons (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   XfwmWindow *t;
   int n, val1, val1_unit, val2, val2_unit;
 
-  if (!GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit))
+  if (!GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit, 0, 0))
     val1 = val2 = Scr.CurrentDesk;
   MyXGrabServer (dpy);
   for (n = val1; n <= val2; n++)
@@ -2576,7 +2618,7 @@ SetSnapSize (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int val1;
   int val1_unit, n;
 
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
   if (n != 1)
     {
       xfwm_msg (ERR, "SetSnapSize", "Snap Size requires 1 argument");
@@ -2593,7 +2635,7 @@ wait_session (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int val1;
   int val1_unit, n;
 
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
   if (n != 1)
     {
       xfwm_msg (ERR, "WaitSession", "WaitSession requires 1 argument");
@@ -2635,7 +2677,7 @@ SetIconGrid (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int val1;
   int val1_unit, n;
 
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
   if (n != 1)
     {
       xfwm_msg (ERR, "SetIconGrid", "Icon grid requires 1 argument");
@@ -2652,7 +2694,7 @@ SetIconSpacing (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int val1;
   int val1_unit, n;
 
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
   if (n != 1)
     {
       xfwm_msg (ERR, "SetIconSpacing", "Icon spacing requires 1 argument");
@@ -2721,7 +2763,7 @@ show_buttons (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       return;
     }
 
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
   if (n != 1)
     {
       xfwm_msg (ERR, "ShowButtons", "Missing argument !");
