@@ -20,6 +20,10 @@
 #include "screen.h"
 #include "module.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 /*****************************************************************************
  *
  * Waits Scr.ClickTime, or until it is evident that the user is not
@@ -112,7 +116,6 @@ ComplexFunction (XEvent * eventp, Window w, XfwmWindow * tmp_win,
    * These do not:
    * The function code is < 100
    * F_NOP
-   * F_TITLE
    * F_BEEP
    * F_SCROLL
    * F_MOVECURSOR
@@ -178,7 +181,8 @@ ComplexFunction (XEvent * eventp, Window w, XfwmWindow * tmp_win,
    * a window to operate on */
   if (NeedsTarget)
     {
-      if (DeferExecution (eventp, &w, &tmp_win, &context, SELECT, ButtonPress))
+      if (DeferExecution
+	  (eventp, &w, &tmp_win, &context, SELECT, ButtonPress))
 	{
 	  WaitForButtonsUp ();
 	  for (i = 0; i < 10; i++)
@@ -191,6 +195,7 @@ ComplexFunction (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   if (!GrabEm (-1))
     {
       XBell (dpy, Scr.screen);
+      xfwm_msg (WARN, "ComplexFunction", "Can't grab mouse/kbd\n");
       for (i = 0; i < 10; i++)
 	if (arguments[i] != NULL)
 	  free (arguments[i]);
