@@ -73,6 +73,7 @@
 unsigned int mods_used = (ShiftMask | ControlMask | Mod1Mask |
 			  Mod2Mask | Mod3Mask | Mod4Mask | Mod5Mask);
 extern int menuFromFrameOrWindowOrTitlebar;
+extern int runlevel;
 
 int Context = C_NO_CONTEXT;	/* current button press context */
 int Button = 0;
@@ -179,7 +180,7 @@ DispatchEvent ()
 void
 HandleEvents ()
 {
-  while (TRUE)
+  while (!runlevel)
     {
       last_event_type = 0;
       if (My_XNextEvent (dpy, &Event))
@@ -341,7 +342,7 @@ HandleFocusOut ()
   int rt;
 
   XGetInputFocus (dpy, &focusBug, &rt);
-  if ((Tmp_win == NULL) && (Scr.Focus != NULL) && (focusBug == None))
+  if ((Tmp_win == NULL) && (Scr.Focus != NULL) && (focusBug == None) && (Scr.Options & ClickToFocus))
     {
       XSetInputFocus (dpy, Scr.Focus->w, RevertToParent, CurrentTime);
     }
@@ -426,6 +427,10 @@ HandlePropertyNotify ()
 	  if (prop != NULL)
 	    {
 	      Scr.ndesks = *(unsigned long *) prop;
+              if (Scr.ndesks < 1) 
+                Scr.ndesks = 1;
+              if (Scr.ndesks > NBSCREENS) 
+                Scr.ndesks = NBSCREENS;
 	      XFree (prop);
 	    }
 	}
@@ -660,7 +665,7 @@ HandleClientMessage ()
 
   if ((Event.xclient.message_type == _XA_WM_CHANGE_STATE) &&
       (Tmp_win) && (Event.xclient.data.l[0] == IconicState) &&
-      !(Tmp_win->flags & ICONIFIED))
+      !(Tmp_win->flags & TRANSIENT) && !(Tmp_win->flags & ICONIFIED))
     {
       XQueryPointer (dpy, Scr.Root, &JunkRoot, &JunkChild,
 		     &(button.xmotion.x_root),
@@ -760,13 +765,17 @@ HandleMapRequest ()
       if (isIconicState != DontCareState)
 	state = isIconicState;
 
+      /* Force state to NormalState for transients to comply with ICCCM */
+      if (Tmp_win->flags & TRANSIENT)
+	state = NormalState;
+
       MyXGrabServer (dpy);
       switch (state)
 	{
 	case IconicState:
 	  if (Tmp_win->wmhints)
 	    Iconify (Tmp_win, Tmp_win->wmhints->icon_x,
-		     Tmp_win->wmhints->icon_y);
+	             Tmp_win->wmhints->icon_y);
 	  else
 	    Iconify (Tmp_win, 0, 0);
 	  break;
@@ -781,10 +790,12 @@ HandleMapRequest ()
 	      Tmp_win->flags |= MAP_PENDING;
 	      SetFocus (Tmp_win->w, Tmp_win, 1);
 	    }
-	  if (Tmp_win->flags & SHADED)
+	  /*
+          if (Tmp_win->flags & SHADED)
 	    {
 	      XUnmapWindow (dpy, Tmp_win->Parent);
 	    }
+           */
 	  SetMapStateProp (Tmp_win, NormalState);
 	  break;
 	}
@@ -832,17 +843,23 @@ HandleMapNotify ()
   if (Tmp_win->Desk == Scr.CurrentDesk)
     XMapWindow (dpy, Tmp_win->frame);
 
+  /*
   if (Tmp_win->flags & SHADED)
     XUnmapWindow (dpy, Tmp_win->Parent);
-
+   */
   if (Tmp_win->flags & ICONIFIED)
     Broadcast (XFCE_M_DEICONIFY, 3, Tmp_win->w, Tmp_win->frame,
 	       (unsigned long) Tmp_win, 0, 0, 0, 0);
   else
     Broadcast (XFCE_M_MAP, 3, Tmp_win->w, Tmp_win->frame,
 	       (unsigned long) Tmp_win, 0, 0, 0, 0);
-  SetFocus (Tmp_win->w, Tmp_win, 1);
-  SetBorder (Tmp_win, True, True, True, Tmp_win->frame);
+
+  if (Tmp_win->Desk == Scr.CurrentDesk)
+    {
+      SetFocus (Tmp_win->w, Tmp_win, 1);
+      SetBorder (Tmp_win, True, True, True, Tmp_win->frame);
+    }
+    
   Tmp_win->flags |= MAPPED;
   Tmp_win->flags &= ~MAP_PENDING;
   Tmp_win->flags &= ~ICONIFIED;
@@ -1320,8 +1337,8 @@ _xfwm_deskwrap (int horz, int vert)
   int ndesks = Scr.ndesks;
   int desk = Scr.CurrentDesk;
 
-  if (!ndesks)
-    ndesks = 1;
+  if (ndesks < 2)
+    return 0;
 
   /*assumes that the desk-layout is alway 2 rows in height -gud */
 
@@ -1371,28 +1388,35 @@ sendclient_event (XfwmWindow * tmp_win, int x, int y, int w, int h)
 void
 HandleRootMotionNotify ()
 {
+
+  int evx, evy;
+  int warpx, warpy;
+  
   if (Scr.SnapSize < MINRESISTANCE)
     {
       return;
     }
   else
-    {				/* check if the pointer is pushed onto the screen border,
-				   if so, increment the corresponding X or Y counter (until Snapsize),
-				   otherwise reset them to null.
-				 */
-      if (Event.xmotion.x_root == 0)
+    {
+      /* check if the pointer is pushed onto the screen border,                 
+         if so, increment the corresponding X or Y counter (until Snapsize),
+         otherwise reset them to null.
+       */
+      evx = Event.xmotion.x_root;
+      evy = Event.xmotion.y_root;
+      if (evx == 0)
 	{
 	  Scr.EdgeScrollX--;
 	}
-      else if (Event.xmotion.y_root == 0)
+      else if (evy == 0)
 	{
 	  Scr.EdgeScrollY--;
 	}
-      else if (Event.xmotion.x_root >= Scr.MyDisplayWidth - 1)
+      else if (evx >= Scr.MyDisplayWidth - 1)
 	{
 	  Scr.EdgeScrollX++;
 	}
-      else if (Event.xmotion.y_root >= Scr.MyDisplayHeight - 1)
+      else if (evy >= Scr.MyDisplayHeight - 1)
 	{
 	  Scr.EdgeScrollY++;
 	}
@@ -1409,32 +1433,48 @@ HandleRootMotionNotify ()
 	{			/* move desktop left */
 	  changeDesks (0, _xfwm_deskwrap (-1, 0), 1, 1, 1);
 	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-	  XWarpPointer (dpy, None, None, 0, 0, 0, 0,
-			+(Scr.MyDisplayWidth - Scr.SnapSize), (0));
+          warpx = Scr.MyDisplayWidth;
+          warpy = evy;
+	  XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                        0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+			my_min(MyDisplayMaxX(warpx,warpy) - 1, warpx) - Scr.SnapSize,
+                        my_min(MyDisplayMaxY(warpx,warpy) - 1, warpy));
 	  return;
 	}
       if (Scr.EdgeScrollX >= (EDGEFACTOR * Scr.SnapSize))
 	{			/* move desktop right */
 	  changeDesks (0, _xfwm_deskwrap (+1, 0), 1, 1, 1);
 	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-	  XWarpPointer (dpy, None, None, 0, 0, 0, 0,
-			-(Scr.MyDisplayWidth - Scr.SnapSize), (0));
+          warpx = 0;
+          warpy = evy;
+	  XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                        0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+			my_min(MyDisplayX(warpx,warpy), warpx) + Scr.SnapSize,
+                        my_min(MyDisplayMaxY(warpx,warpy) - 1, warpy));
 	  return;
 	}
       if (Scr.EdgeScrollY <= (-EDGEFACTOR * Scr.SnapSize))
 	{			/* move desktop upper */
 	  changeDesks (0, _xfwm_deskwrap (0, -1), 1, 1, 1);
 	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-	  XWarpPointer (dpy, None, None, 0, 0, 0, 0, (0),
-			+(Scr.MyDisplayHeight - Scr.SnapSize));
+          warpx = evx;
+          warpy = Scr.MyDisplayHeight;
+	  XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                        0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+			my_min(MyDisplayMaxX(warpx,warpy) - 1, warpx),
+                        my_min(MyDisplayMaxY(warpx,warpy) - 1, warpy) - Scr.SnapSize);
 	  return;
 	}
       if (Scr.EdgeScrollY >= (EDGEFACTOR * Scr.SnapSize))
 	{			/* move desktop lower */
 	  changeDesks (0, _xfwm_deskwrap (0, +1), 1, 1, 1);
 	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-	  XWarpPointer (dpy, None, None, 0, 0, 0, 0, (0),
-			-(Scr.MyDisplayHeight - Scr.SnapSize));
+          warpx = evx;
+          warpy = 0;
+	  XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                        0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+			my_min(MyDisplayMaxX(warpx,warpy) - 1, warpx),
+                        my_min(MyDisplayY(warpx,warpy), warpy) + Scr.SnapSize);
 	  return;
 	}
     }
