@@ -26,6 +26,10 @@
 #include "screen.h"
 #include "module.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 
 /********************************************************************
  *
@@ -39,7 +43,6 @@ SetFocus (Window w, XfwmWindow * Fw, Bool FocusByMouse)
   extern Time lastTimestamp;
 
   XSync (dpy, 0);
-  MyXGrabServer (dpy);
   if ((FocusByMouse) && (Fw && Fw != Scr.Focus && Fw != &Scr.XfwmRoot))
     {
       XfwmWindow *tmp_win1, *tmp_win2;
@@ -68,10 +71,10 @@ SetFocus (Window w, XfwmWindow * Fw, Bool FocusByMouse)
 	  if (Scr.Focus != NULL)
 	    {
 	      Scr.Focus = NULL;
-	      XSetInputFocus (dpy, Scr.NoFocusWin, RevertToParent, lastTimestamp);
+	      XSetInputFocus (dpy, Scr.NoFocusWin, RevertToParent,
+			      lastTimestamp);
 	    }
-          MyXUngrabServer (dpy);
-          XSync (dpy, 0); 
+	  XSync (dpy, 0);
 	  return;
 	}
     }
@@ -92,6 +95,5 @@ SetFocus (Window w, XfwmWindow * Fw, Bool FocusByMouse)
   if ((Fw) && (Fw->flags & DoesWmTakeFocus))
     send_clientmessage (dpy, w, _XA_WM_TAKE_FOCUS, lastTimestamp);
 
-  MyXUngrabServer (dpy);
   XSync (dpy, 0);
 }
