@@ -46,6 +46,10 @@
 #  include "dmalloc.h"
 #endif
 
+#ifdef HAVE_IMLIB
+extern ImlibData *imlib_id;
+#endif
+
 void GrabIconButtons (XfwmWindow *, Window);
 void GrabIconKeys (XfwmWindow *, Window);
 
@@ -130,15 +134,15 @@ CreateIconWindow (XfwmWindow * tmp_win, int def_x, int def_y)
 
   final_x = def_x;
   final_y = def_y;
-  if (final_x < 0)
-    final_x = 0;
-  if (final_y < 0)
-    final_y = 0;
+  if (final_x < MyDisplayX(final_x, final_y))
+    final_x = MyDisplayX(final_x, final_y);
+  if (final_y < MyDisplayY(final_x, final_y))
+    final_y = MyDisplayY(final_x, final_y);
 
-  if (final_x + tmp_win->icon_w_width >= Scr.MyDisplayWidth)
-    final_x = Scr.MyDisplayWidth - tmp_win->icon_w_width - 1;
-  if (final_y + tmp_win->icon_w_height >= Scr.MyDisplayHeight)
-    final_y = Scr.MyDisplayHeight - tmp_win->icon_w_height - 1;
+  if (final_x + tmp_win->icon_w_width >= MyDisplayMaxX(final_x, final_y))
+    final_x = MyDisplayMaxX(final_x, final_y) - tmp_win->icon_w_width - 1;
+  if (final_y + tmp_win->icon_w_height >= MyDisplayMaxY(final_x, final_y))
+    final_y = MyDisplayMaxY(final_x, final_y) - tmp_win->icon_w_height - 1;
 
   tmp_win->icon_x_loc = final_x;
   tmp_win->icon_xl_loc = final_x;
@@ -243,19 +247,24 @@ DrawIconWindow (XfwmWindow * Tmp_win)
 	  Tmp_win->icon_xl_loc = Tmp_win->icon_x_loc -
 	    (Tmp_win->icon_w_width - Tmp_win->icon_p_width) / 2;
 	  /* start keep label on screen. dje 8/7/97 */
-	  if (Tmp_win->icon_xl_loc < 0)
-	    {			/* if new loc neg (off left edge) */
-	      Tmp_win->icon_xl_loc = 0;	/* move to edge */
+	  if (Tmp_win->icon_xl_loc < 
+                MyDisplayX(Tmp_win->icon_x_loc + (Tmp_win->icon_p_width / 2),
+                           Tmp_win->icon_y_loc + Tmp_win->icon_p_height))
+	    { /* if new loc neg (off left edge) move to edge */
+	      Tmp_win->icon_xl_loc = 
+                MyDisplayX(Tmp_win->icon_x_loc + (Tmp_win->icon_p_width / 2),
+                           Tmp_win->icon_y_loc + Tmp_win->icon_p_height);
 	    }
 	  else
-	    {			/* if not on left edge */
-	      /* if (new loc + width) > screen width (off edge on right) */
+	    { /* if (new loc + width) > screen width (off edge on right) */
 	      if ((Tmp_win->icon_xl_loc + Tmp_win->icon_w_width) >
-		  Scr.MyDisplayWidth)
-		{		/* off right */
-		  /* position up against right edge */
+                MyDisplayMaxX(Tmp_win->icon_x_loc + (Tmp_win->icon_p_width / 2),
+                              Tmp_win->icon_y_loc + Tmp_win->icon_p_height))
+		{/* position up against right edge */
 		  Tmp_win->icon_xl_loc =
-		    Scr.MyDisplayWidth - Tmp_win->icon_w_width;
+		    MyDisplayMaxX(Tmp_win->icon_x_loc + (Tmp_win->icon_p_width / 2),
+                                  Tmp_win->icon_y_loc + Tmp_win->icon_p_height) 
+                    - Tmp_win->icon_w_width;
 		}
 	      /* end keep label on screen. dje 8/7/97 */
 	    }
@@ -392,16 +401,16 @@ RedoIconName (XfwmWindow * Tmp_win)
 #define TEST_1 \
       (((Scr.iconbox == 0) || (Scr.iconbox == 2)) \
       ? \
-          ((test_y + temp_h) < (Scr.MyDisplayHeight+base_y)) \
+          ((test_y + temp_h) < (MyDisplayMaxY(base_x, base_y) + base_y)) \
       : \
-          ((test_x + temp_w) < (Scr.MyDisplayWidth+base_x)))
+          ((test_x + temp_w) < (MyDisplayMaxX(base_x, base_y) + base_x)))
 
 #define TEST_2 \
       (((Scr.iconbox == 0) || (Scr.iconbox == 2)) \
       ? \
-          ((test_x + temp_w) < (Scr.MyDisplayWidth+base_x)) \
+          ((test_x + temp_w) < (MyDisplayMaxX(base_x, base_y) + base_x)) \
       : \
-          ((test_y + temp_h) < (Scr.MyDisplayHeight+base_y)))
+          ((test_y + temp_h) < (MyDisplayMaxY(base_x, base_y) + base_y)))
 
 /* Test overlapping windows */
 #define OVERLAP(x1, y1, x2, y2, x3, y3, x4, y4) \
@@ -459,35 +468,39 @@ AutoPlace (XfwmWindow * t, Bool rearrange)
   Bool loc_ok;
   int real_x = 10, real_y = 10;
   int step_x, step_y;
+  int center_x, center_y;
 
   width = t->icon_p_width;
   height = t->icon_w_height + t->icon_p_height;
+  
+  center_x = t->frame_x + (t->frame_width / 2);
+  center_y = t->frame_y + (t->frame_height / 2);
 
   switch (Scr.iconbox)
     {
     case 1:
-      base_x = 0;
-      base_y = 0;
+      base_x = MyDisplayX(center_x, center_y);
+      base_y = MyDisplayY(center_x, center_y);
       step_x = Scr.icongrid;
       step_y = Scr.icongrid;
       break;
     case 2:
-      base_x = 0;
+      base_x = MyDisplayX(center_x, center_y);
       base_y =
-	((int) (Scr.MyDisplayHeight - height) / Scr.icongrid) * Scr.icongrid;
+	((int) (MyDisplayMaxY(center_x, center_y) - height) / Scr.icongrid) * Scr.icongrid;
       step_x = Scr.icongrid;
       step_y = -Scr.icongrid;
       break;
     case 3:
       base_x =
-	((int) (Scr.MyDisplayWidth - width) / Scr.icongrid) * Scr.icongrid;
-      base_y = 0;
+	((int) (MyDisplayMaxX(center_x, center_y) - width) / Scr.icongrid) * Scr.icongrid;
+      base_y = MyDisplayY(center_x, center_y);
       step_x = -Scr.icongrid;
       step_y = Scr.icongrid;
       break;
     default:
-      base_x = 0;
-      base_y = 0;
+      base_x = MyDisplayX(center_x, center_y);
+      base_y = MyDisplayY(center_x, center_y);
       step_x = Scr.icongrid;
       step_y = Scr.icongrid;
       break;
@@ -495,16 +508,16 @@ AutoPlace (XfwmWindow * t, Bool rearrange)
   if (t->flags & ICON_MOVED)
     {
       /* just make sure the icon is on this screen */
-      t->icon_x_loc = t->icon_x_loc % Scr.MyDisplayWidth + base_x;
-      t->icon_y_loc = t->icon_y_loc % Scr.MyDisplayHeight + base_y;
-      if (t->icon_x_loc < 0)
-	t->icon_x_loc += Scr.MyDisplayWidth;
-      if (t->icon_y_loc < 0)
-	t->icon_y_loc += Scr.MyDisplayHeight;
-      if (t->icon_x_loc > Scr.MyDisplayWidth)
-	t->icon_x_loc -= Scr.MyDisplayWidth;
-      if (t->icon_y_loc > Scr.MyDisplayHeight)
-	t->icon_y_loc -= Scr.MyDisplayHeight;
+      t->icon_x_loc = t->icon_x_loc % MyDisplayMaxX(t->icon_x_loc, t->icon_y_loc) + base_x;
+      t->icon_y_loc = t->icon_y_loc % MyDisplayMaxY(t->icon_x_loc, t->icon_y_loc) + base_y;
+      if (t->icon_x_loc < MyDisplayX(t->icon_x_loc, t->icon_y_loc))
+	t->icon_x_loc += MyDisplayX(t->icon_x_loc, t->icon_y_loc);
+      if (t->icon_y_loc < MyDisplayY(t->icon_x_loc, t->icon_y_loc))
+	t->icon_y_loc += MyDisplayY(t->icon_x_loc, t->icon_y_loc);
+      if (t->icon_x_loc > MyDisplayMaxX(t->icon_x_loc, t->icon_y_loc))
+	t->icon_x_loc -= MyDisplayMaxX(t->icon_x_loc, t->icon_y_loc);
+      if (t->icon_y_loc > MyDisplayMaxY(t->icon_x_loc, t->icon_y_loc))
+	t->icon_y_loc -= MyDisplayMaxY(t->icon_x_loc, t->icon_y_loc);
     }
   loc_ok = False;
 
@@ -813,6 +826,8 @@ void
 DeIconify (XfwmWindow * tmp_win)
 {
   XfwmWindow *t;
+  XWindowAttributes winattrs;
+  unsigned long eventMask;
 
   if (!tmp_win)
     return;
@@ -839,11 +854,11 @@ DeIconify (XfwmWindow * tmp_win)
 	  if (Scr.Hilite == t)
 	    SetBorder (t, False, True, True, None);
 
-	  if (!(t->flags & SHADED))
-	    {
-	      XMapWindow (dpy, t->w);
-	      XMapWindow (dpy, t->Parent);
-	    }
+          XGetWindowAttributes (dpy, t->w, &winattrs);
+          eventMask = winattrs.your_event_mask;
+	  XSelectInput (dpy, t->w, eventMask & ~StructureNotifyMask);
+	  XMapWindow (dpy, t->w);
+	  XMapWindow (dpy, t->Parent);
 	  if (t->Desk == Scr.CurrentDesk)
 	    {
 	      XMapWindow (dpy, t->frame);
@@ -853,8 +868,8 @@ DeIconify (XfwmWindow * tmp_win)
 	  t->flags &= ~ICONIFIED;
 	  t->flags &= ~ICON_UNMAPPED;
 	  t->flags &= ~STARTICONIC;
-	  if (!(t->flags & SHADED))
-	    XRaiseWindow (dpy, t->w);
+          XRaiseWindow (dpy, t->w);
+	  XSelectInput (dpy, t->w, eventMask);
 	  if (t->icon_w)
 	    XUnmapWindow (dpy, t->icon_w);
 	  if (t->icon_pixmap_w)
@@ -864,11 +879,8 @@ DeIconify (XfwmWindow * tmp_win)
 	}
     }
 
-  if (!(tmp_win->flags & SHADED))
-    {
-      RaiseWindow (tmp_win);
-      FocusOn (tmp_win, 1);
-    }
+  RaiseWindow (tmp_win);
+  FocusOn (tmp_win, 1);
   MyXUngrabServer (dpy);
   return;
 }
@@ -889,8 +901,10 @@ Iconify (XfwmWindow * tmp_win, int def_x, int def_y)
   if (!tmp_win)
     return;
 
-  XGetWindowAttributes (dpy, tmp_win->w, &winattrs);
-  eventMask = winattrs.your_event_mask;
+  /* Transient can't be iconified separately */
+  if ((tmp_win->flags & TRANSIENT))
+    return;
+    
   if ((tmp_win->Desk == Scr.CurrentDesk) && (tmp_win)
       && (tmp_win == Scr.Hilite))
     {
@@ -912,10 +926,12 @@ Iconify (XfwmWindow * tmp_win, int def_x, int def_y)
 	   * cause a transition to the Withdrawn state.
 	   */
 	  t->flags &= ~MAPPED;
+          XGetWindowAttributes (dpy, t->w, &winattrs);
+          eventMask = winattrs.your_event_mask;
 	  XSelectInput (dpy, t->w, eventMask & ~StructureNotifyMask);
 	  XUnmapWindow (dpy, t->w);
-	  XSelectInput (dpy, t->w, eventMask);
 	  XUnmapWindow (dpy, t->frame);
+	  XSelectInput (dpy, t->w, eventMask);
 	  t->DeIconifyDesk = t->Desk;
 	  if (t->icon_w)
 	    XUnmapWindow (dpy, t->icon_w);
@@ -1015,8 +1031,6 @@ Iconify (XfwmWindow * tmp_win, int def_x, int def_y)
   return;
 }
 
-
-
 /****************************************************************************
  *
  * This is used to tell applications which windows on the screen are
