@@ -95,7 +95,7 @@ do_menu (MenuRoot * menu, int style)
       if (ActiveMenu)
 	{
 	  if ((Stashed_X + (ActiveMenu->width >> 1) + menu->width) <
-	      Scr.MyDisplayWidth)
+	      MyDisplayMaxX (Stashed_X, Stashed_Y))
 	    x = Stashed_X + (ActiveMenu->width >> 1) + (menu->width >> 1);
 	  else
 	    x = Stashed_X - (ActiveMenu->width >> 1) - (menu->width >> 1);
@@ -113,7 +113,7 @@ do_menu (MenuRoot * menu, int style)
           xfwm_msg (WARN, "do_menu", "Can't grab mouse/kbd\n");
 	  return MENU_DONE;
 	}
-      if ((x + menu->width + 5) < Scr.MyDisplayWidth)
+      if ((x + menu->width + 5) < MyDisplayMaxX (x, y))
 	x += ((menu->width >> 1) + 5);
       else
 	x -= ((menu->width >> 1) + 5);
@@ -282,6 +282,7 @@ PaintEntry (MenuRoot * mr, MenuItem * mi)
 	XDrawString (dpy, mr->w, currentGC, mi->x2, text_y, mi->item2,
 		     mi->strlen2);
     }
+    
   if (mi->hotkey > 0)
     DrawUnderline (mr->w, currentGC, mi->x, text_y, mi->item, mi->hotkey - 1);
   if (mi->hotkey < 0)
@@ -736,14 +737,14 @@ PopUpMenu (MenuRoot * menu, int x, int y)
     }
 
   /* clip to screen */
-  if (x + menu->width > Scr.MyDisplayWidth - 2)
-    x = Scr.MyDisplayWidth - menu->width - 2;
+  if (x + menu->width > MyDisplayMaxX (x, y) - 2)
+    x = MyDisplayMaxX (x, y) - menu->width - 2;
   if (x < 0)
     x = 0;
 
-  if (y + menu->height > Scr.MyDisplayHeight - 2)
+  if (y + menu->height > MyDisplayMaxY (x, y) - 2)
     {
-      y = Scr.MyDisplayHeight - menu->height - 2;
+      y = MyDisplayMaxY (x, y) - menu->height - 2;
     }
   if (y < 0)
     y = 0;
@@ -890,6 +891,7 @@ MakeMenus (void)
       MakeMenu (mr);
       mr = mr->next;
     }
+  XFlush(dpy);
 }
 
 /****************************************************************************
@@ -903,6 +905,7 @@ MakeMenu (MenuRoot * mr)
   MenuItem *cur;
   unsigned long valuemask;
   XSetWindowAttributes attributes;
+  XFontSet fontset = Scr.StdFont.fontset;
   int y, width;
 
   if ((mr->func != F_POPUP) || (!Scr.flags & WindowsCaptured))
@@ -913,7 +916,6 @@ MakeMenu (MenuRoot * mr)
   mr->width2 = 0;
   for (cur = mr->first; cur != NULL; cur = cur->next)
     {
-      XFontSet fontset = Scr.StdFont.fontset;
       if (fontset)
 	{
 	  XRectangle rect1, rect2;
@@ -960,7 +962,6 @@ MakeMenu (MenuRoot * mr)
 	  /* Title */
 	  if (cur->strlen2 == 0)
 	    {
-	      XFontSet fontset = Scr.StdFont.fontset;
 	      int width;
 	      if (fontset)
 		{
@@ -997,7 +998,6 @@ MakeMenu (MenuRoot * mr)
   mr->in_use = 0;
   mr->height = y + 2;
 
-
   valuemask = (CWBackPixel | CWEventMask | CWCursor | CWSaveUnder);
   attributes.background_pixel = Scr.MenuColors.back;
   attributes.event_mask = (ExposureMask | EnterWindowMask);
@@ -1012,7 +1012,6 @@ MakeMenu (MenuRoot * mr)
 			 CopyFromParent, (unsigned int) InputOutput,
 			 (Visual *) CopyFromParent, valuemask, &attributes);
   XSaveContext (dpy, mr->w, MenuContext, (caddr_t) mr);
-
   return;
 }
 
