@@ -42,6 +42,10 @@
 #include <Imlib.h>
 #endif
 
+#ifdef HAVE_X11_EXTENSIONS_XINERAMA_H
+#  include <X11/extensions/Xinerama.h>
+#endif
+
 #ifdef DMALLOC
 #  include "dmalloc.h"
 #endif
@@ -50,6 +54,10 @@ char NoName[] = "Untitled";	/* name if no name in XA_WM_NAME */
 char NoClass[] = "NoClass";	/* Class if no res_class in class hints */
 char NoResource[] = "NoResource";	/* Class if no res_name in class hints */
 
+#ifdef HAVE_IMLIB
+extern ImlibData *imlib_id;
+#endif
+
 int
 check_existfile (char *filename)
 {
@@ -407,15 +415,15 @@ StashEventTime (XEvent * ev)
 
 int
 GetTwoArguments (char *action, int *val1, int *val2, int *val1_unit,
-		 int *val2_unit)
+		 int *val2_unit, int x, int y)
 {
   char c1, c2;
   int n;
 
   *val1 = 0;
   *val2 = 0;
-  *val1_unit = Scr.MyDisplayWidth;
-  *val2_unit = Scr.MyDisplayHeight;
+  *val1_unit = MyDisplayWidth (x, y);
+  *val2_unit = MyDisplayHeight (x, y);
 
   n = sscanf (action, "%d %d", val1, val2);
   if (n == 2)
@@ -439,13 +447,13 @@ GetTwoArguments (char *action, int *val1, int *val2, int *val1_unit,
 
 
 int
-GetOneArgument (char *action, long *val1, int *val1_unit)
+GetOneArgument (char *action, long *val1, int *val1_unit, int x, int y)
 {
   char c1;
   int n;
 
   *val1 = 0;
-  *val1_unit = Scr.MyDisplayWidth;
+  *val1_unit = MyDisplayWidth (x, y);
 
   n = sscanf (action, "%ld", val1);
   if (n == 1)
@@ -709,10 +717,7 @@ UnmapIt (XfwmWindow * t)
 {
   XWindowAttributes winattrs;
   unsigned long eventMask;
-  /*
-   * Prevent the receipt of an UnmapNotify, since that would
-   * cause a transition to the Withdrawn state.
-   */
+
   XGetWindowAttributes (dpy, t->w, &winattrs);
   eventMask = winattrs.your_event_mask;
   XSelectInput (dpy, t->w, eventMask & ~StructureNotifyMask);
@@ -725,6 +730,7 @@ UnmapIt (XfwmWindow * t)
     }
   else if (t->flags & (MAPPED | MAP_PENDING))
     {
+      XUnmapWindow (dpy, t->w);
       XUnmapWindow (dpy, t->frame);
     }
   XSelectInput (dpy, t->w, eventMask);
@@ -738,6 +744,12 @@ UnmapIt (XfwmWindow * t)
 void
 MapIt (XfwmWindow * t)
 {
+  XWindowAttributes winattrs;
+  unsigned long eventMask;
+
+  XGetWindowAttributes (dpy, t->w, &winattrs);
+  eventMask = winattrs.your_event_mask;
+  XSelectInput (dpy, t->w, eventMask & ~StructureNotifyMask);
   if (t->flags & ICONIFIED)
     {
       if (t->icon_pixmap_w != None)
@@ -747,11 +759,12 @@ MapIt (XfwmWindow * t)
     }
   else if (t->flags & MAPPED)
     {
+      XMapWindow (dpy, t->w);
+      XMapWindow (dpy, t->Parent);
       XMapWindow (dpy, t->frame);
       t->flags |= MAP_PENDING;
-      if (!(t->flags & SHADED))
-	XMapWindow (dpy, t->Parent);
     }
+  XSelectInput (dpy, t->w, eventMask);
 }
 
 void
@@ -796,7 +809,8 @@ RaiseWindow (XfwmWindow * t)
   /* ONTOP windows on top */
   for (t2 = Scr.XfwmRoot.next; t2 != NULL; t2 = t2->next)
     {
-      if ((t2->flags & ONTOP) && !(t2->flags & ICONIFIED))
+      if ((t2->flags & ONTOP) && !(t2->flags & ICONIFIED) && (t2 != t) &&
+          !((t->flags & TRANSIENT) && (t->transientfor == t2->w)))
 	{
 	  Broadcast (XFCE_M_RAISE_WINDOW, 3, t2->w, t2->frame,
 		     (unsigned long) t2, 0, 0, 0, 0);
@@ -807,8 +821,7 @@ RaiseWindow (XfwmWindow * t)
   /* now raise transients */
   for (t2 = Scr.XfwmRoot.next; t2 != NULL; t2 = t2->next)
     {
-      if ((t2->flags & TRANSIENT) &&
-	  (t2->transientfor == t->w) && (t2 != t) && (!(t2->flags & ONTOP)))
+      if ((t2->flags & TRANSIENT) && (t2->transientfor == t->w) && (t2 != t))
 	{
 	  wins[i++] = t2->frame;
 	  if ((t2->flags & ICONIFIED) && (!(t2->flags & SUPPRESSICON)))
@@ -910,3 +923,196 @@ xfwm_msg (int type, char *id, char *msg, ...)
 
   va_end (args);
 }				/* xfwm_msg */
+
+/* Xinerama handling routines */
+
+#if defined(HAVE_X11_EXTENSIONS_XINERAMA_H) || defined(EMULATE_XINERAMA)
+static int findhead(int x, int y)
+{
+  extern XineramaScreenInfo *xinerama_infos;
+  extern int xinerama_heads;
+  extern Bool enable_xinerama;
+  static int cache_x;
+  static int cache_y;
+  static int cache_head;
+  static Bool cache_init = False;
+  
+  int head, closest_head;
+  int dx, dy;
+  int center_x, center_y;
+  int distsquare, min_distsquare;
+  
+  /* Cache system */
+  if ((cache_init) && (x == cache_x) && (y == cache_y))
+    return (cache_head);
+    
+  /* Okay, now we consider the cache has been initialized */
+  cache_init = True;
+  cache_x = x;
+  cache_y = y;
+    
+  if ((xinerama_heads == 0) || (xinerama_infos == NULL) || (!enable_xinerama))
+    /* Xinerama extensions are disabled */
+    {
+      cache_head = 0;
+      return (0);
+    }
+    
+  for (head = 0; head < xinerama_heads; head++)
+    {
+      if ((xinerama_infos[head].x_org <= x)
+	  && ((xinerama_infos[head].x_org + xinerama_infos[head].width) > x)
+          && (xinerama_infos[head].y_org <= y)
+	  && ((xinerama_infos[head].y_org + xinerama_infos[head].height) > y))
+        {
+          cache_head = head;
+          return (head);
+	}
+    }
+  /* No head has been eligible, use the closest one*/
+
+  center_x = xinerama_infos[0].x_org + (xinerama_infos[0].width / 2);
+  center_y = xinerama_infos[0].y_org + (xinerama_infos[0].height / 2);
+
+  dx = x - center_x;
+  dy = y - center_y;
+  
+  min_distsquare = (dx * dx) + (dy * dy);
+  closest_head   = 0;
+
+  for (head = 1; head < xinerama_heads; head++)
+    {
+      center_x = xinerama_infos[head].x_org + (xinerama_infos[head].width / 2);
+      center_y = xinerama_infos[head].y_org + (xinerama_infos[head].height / 2);
+
+      dx = x - center_x;
+      dy = y - center_y;
+      
+      distsquare = (dx * dx) + (dy * dy);
+      
+      if (distsquare < min_distsquare)
+        {
+          min_distsquare = distsquare;
+          closest_head   = head;
+        }
+    }
+  cache_head = closest_head;
+  return (closest_head);
+}
+#endif
+
+int MyDisplayHeight (int x, int y)
+{
+#if defined(HAVE_X11_EXTENSIONS_XINERAMA_H) || defined(EMULATE_XINERAMA)
+  extern XineramaScreenInfo *xinerama_infos;
+  extern int xinerama_heads;
+  extern Bool enable_xinerama;
+  int head;
+
+  if ((xinerama_heads == 0) || (xinerama_infos == NULL) || (!enable_xinerama))
+    /* Xinerama extensions are disabled */
+    return (Scr.MyDisplayHeight);
+
+  head = findhead (x, y);    
+  return (xinerama_infos[head].height);
+#else
+  return (Scr.MyDisplayHeight);
+#endif
+}
+
+int MyDisplayWidth (int x, int y)
+{
+#if defined(HAVE_X11_EXTENSIONS_XINERAMA_H) || defined(EMULATE_XINERAMA)
+  extern XineramaScreenInfo *xinerama_infos;
+  extern int xinerama_heads;
+  extern Bool enable_xinerama;
+  int head;
+  
+  if ((xinerama_heads == 0) || (xinerama_infos == NULL) || (!enable_xinerama))
+    /* Xinerama extensions are disabled */
+    return (Scr.MyDisplayWidth);
+    
+  head = findhead (x, y);    
+  return (xinerama_infos[head].width);
+#else
+  return (Scr.MyDisplayWidth);
+#endif
+}
+
+int MyDisplayX (int x, int y)
+{
+#if defined(HAVE_X11_EXTENSIONS_XINERAMA_H) || defined(EMULATE_XINERAMA)
+  extern XineramaScreenInfo *xinerama_infos;
+  extern int xinerama_heads;
+  extern Bool enable_xinerama;
+  int head;
+  
+  if ((xinerama_heads == 0) || (xinerama_infos == NULL) || (!enable_xinerama))
+    /* Xinerama extensions are disabled */
+    return (0);
+    
+  head = findhead (x, y);    
+  return (xinerama_infos[head].x_org);
+#else
+  return (0);
+#endif
+}
+
+
+int MyDisplayY (int x, int y)
+{
+#if defined(HAVE_X11_EXTENSIONS_XINERAMA_H) || defined(EMULATE_XINERAMA)
+  extern XineramaScreenInfo *xinerama_infos;
+  extern int xinerama_heads;
+  extern Bool enable_xinerama;
+  int head;
+  
+  if ((xinerama_heads == 0) || (xinerama_infos == NULL) || (!enable_xinerama))
+    /* Xinerama extensions are disabled */
+    return (0);
+    
+  head = findhead (x, y);    
+  return (xinerama_infos[head].y_org);
+#else
+  return (0);
+#endif
+}
+
+int MyDisplayMaxX (int x, int y)
+{
+#if defined(HAVE_X11_EXTENSIONS_XINERAMA_H) || defined(EMULATE_XINERAMA)
+  extern XineramaScreenInfo *xinerama_infos;
+  extern int xinerama_heads;
+  extern Bool enable_xinerama;
+  int head;
+  
+  if ((xinerama_heads == 0) || (xinerama_infos == NULL) || (!enable_xinerama))
+    /* Xinerama extensions are disabled */
+    return (Scr.MyDisplayWidth);
+    
+  head = findhead (x, y);    
+  return (xinerama_infos[head].x_org + xinerama_infos[head].width);
+#else
+  return (Scr.MyDisplayWidth);
+#endif
+}
+
+int MyDisplayMaxY (int x, int y)
+{
+#if defined(HAVE_X11_EXTENSIONS_XINERAMA_H) || defined(EMULATE_XINERAMA)
+  extern XineramaScreenInfo *xinerama_infos;
+  extern int xinerama_heads;
+  extern Bool enable_xinerama;
+  int head;
+  
+  if ((xinerama_heads == 0) || (xinerama_infos == NULL) || (!enable_xinerama))
+    /* Xinerama extensions are disabled */
+    return (Scr.MyDisplayHeight);
+
+  head = findhead (x, y);    
+  return (xinerama_infos[head].y_org + xinerama_infos[head].height);
+#else
+  return (Scr.MyDisplayHeight);
+#endif
+}
+
