@@ -11,10 +11,12 @@
  * ReapChildren - wait() for all dead child processes
  ************************************************************************/
 #include <sys/wait.h>
-#ifdef HAVE_WAITPID
-#define ReapChildren()  while ((waitpid(-1, NULL, WNOHANG)) > 0);
+#if HAVE_WAITPID
+  #define ReapChildren() while (waitpid (-1, NULL, WNOHANG) > 0);
+#elif HAVE_WAIT3
+  #define ReapChildren() while (wait3 (NULL, WNOHANG, NULL) > 0);
 #else
-#define ReapChildren()  while ((wait3(NULL, WNOHANG, NULL)) > 0);
+  #error One of waitpid or wait3 is needed.
 #endif
 
 #define my_max(a,b) ((a > b) ? a : b)
@@ -95,6 +97,7 @@ struct functions
 #define MWM_FUNCTIONS_FLAG   (1<<22)
 #define MWM_OVERRIDE_FLAG    (1<<23)
 #define NO_PPOSITION_FLAG    (1<<24)
+#define TRANSLATE_FLAG       (1<<25)
 
 /* some fancy font handling stuff */
 #define NewFontAndColor(newfont,color,backcolor) {\
@@ -262,6 +265,7 @@ extern int DeferExecution (XEvent *, Window *, XfwmWindow **, unsigned long *,
 			   int, int);
 void my_sleep (int);
 void Animate (int, int, int, int, int, int, int, int);
+void ShowMeMouse (XEvent *, Window, XfwmWindow *, unsigned long, char *, int *);
 void SetBorder (XfwmWindow *, Bool, Bool, Bool, Window);
 void move_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		  unsigned long context, char *action, int *Module);
@@ -272,6 +276,7 @@ void SetMapStateProp (XfwmWindow *, int);
 void SetStickyProp (XfwmWindow *, int, int, int);
 void SetClientProp (XfwmWindow *);
 void Iconify (XfwmWindow *, int, int);
+void Iconify_all (XEvent *, Window, XfwmWindow *, unsigned long, char *, int *);
 void DeIconify (XfwmWindow *);
 void PopDownMenu (void);
 void KeepOnTop (void);
@@ -373,10 +378,11 @@ void changeDesks_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 void changeDesks (int, int, Bool, Bool, Bool);
 void changeWindowsDesk (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 			unsigned long context, char *action, int *Module);
+void sendWindowsDesk (int desk, XfwmWindow *t);
 
 int GetTwoArguments (char *action, int *val1, int *val2, int *val1_unit,
-		     int *val2_unit);
-int GetOneArgument (char *action, long *val1, int *val1_unit);
+		     int *val2_unit, int x, int y);
+int GetOneArgument (char *action, long *val1, int *val1_unit, int x, int y);
 void wait_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		unsigned long context, char *action, int *Module);
 void flip_focus_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
@@ -519,6 +525,15 @@ int check_existfile (char *filename);
 #define ERR  2
 void xfwm_msg (int type, char *id, char *msg, ...);
 
+/* Xinerama stuff */
+int MyDisplayHeight (int x, int y);
+int MyDisplayWidth (int x, int y);
+int MyDisplayX (int x, int y);
+int MyDisplayY (int x, int y);
+int MyDisplayMaxX (int x, int y);
+int MyDisplayMaxY (int x, int y);
+
+
 #ifdef BROKEN_SUN_HEADERS
 #include "sun_headers.h"
 #endif
