@@ -299,7 +299,7 @@ HandleModuleInput (Window w, int channel)
   if (size > 255)
     {
       xfwm_msg (ERR, "HandleModuleInput",
-		"Module command is too big (%d)", (void *) size);
+		"Module command is too big (%d)", (void *) ((long) size));
       size = 255;
     }
 
@@ -728,14 +728,17 @@ send_list_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 	  SendName (*Module, XFCE_M_RES_NAME, t->w, t->frame,
 		    (unsigned long) t, t->class.res_name);
 
-	  if ((t->flags & ICONIFIED) && (!(t->flags & ICON_UNMAPPED)))
-	    SendPacket (*Module, XFCE_M_ICONIFY, 7, t->w, t->frame,
-			(unsigned long) t,
-			t->icon_x_loc, t->icon_y_loc,
-			t->icon_w_width, t->icon_w_height + t->icon_p_height);
-	  if ((t->flags & ICONIFIED) && (t->flags & ICON_UNMAPPED))
-	    SendPacket (*Module, XFCE_M_ICONIFY, 7, t->w, t->frame,
-			(unsigned long) t, 0, 0, 0, 0);
+	  if (t->flags & ICONIFIED)
+            {
+              if (!(t->flags & ICON_UNMAPPED))
+ 	        SendPacket (*Module, XFCE_M_ICONIFY, 7, t->w, t->frame,
+			    (unsigned long) t,
+			    t->icon_x_loc, t->icon_y_loc,
+			    t->icon_w_width, t->icon_w_height + t->icon_p_height);
+              else
+	        SendPacket (*Module, XFCE_M_ICONIFY, 7, t->w, t->frame,
+			    (unsigned long) t, 0, 0, 0, 0);
+            }
 	}
       if (Scr.Hilite == NULL)
 	{
@@ -759,6 +762,6 @@ set_mask_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 {
   int n, val1_unit;
   int val1;
-  n = GetOneArgument (action, (long *) &val1, &val1_unit);
+  n = GetOneArgument (action, (long *) &val1, &val1_unit, 0, 0);
   PipeMask[*Module] = (unsigned long) val1;
 }
