@@ -52,13 +52,18 @@ move_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int FinalX, FinalY;
   int val1, val2, val1_unit, val2_unit, n;
   int startDesk;
+  int center_x;
+  int center_y;
   Bool window_deleted = FALSE;
 
-  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit);
-
   if (DeferExecution (eventp, &w, &tmp_win, &context, MOVE, ButtonPress))
     return;
 
+  center_x = tmp_win->frame_x + (tmp_win->frame_width / 2);
+  center_y = tmp_win->frame_y + (tmp_win->frame_height / 2);
+
+  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit, center_x, center_y);
+
   startDesk = Scr.CurrentDesk;
   /* gotta have a window */
   w = tmp_win->frame;
@@ -357,7 +362,7 @@ Keyboard_shortcuts (XEvent * Event, int ReturnEvent)
   if ((x_move != 0) || (y_move != 0))
     {
       /* beat up the event */
-      XWarpPointer (dpy, None, Scr.Root, 0, 0, 0, 0, x_root + x_move,
+      XWarpPointer (dpy, Scr.Root, Scr.Root, 0, 0, 0, 0, x_root + x_move,
 		    y_root + y_move);
 
       /* beat up the event */
@@ -388,7 +393,7 @@ InteractiveMove (Window * win, XfwmWindow * tmp_win, int *FinalX, int *FinalY,
   InstallRootColormap ();
   if (menuFromFrameOrWindowOrTitlebar)
     {
-      XWarpPointer (dpy, None, Scr.Root, 0, 0, 0, 0, Stashed_X, Stashed_Y);
+      XWarpPointer (dpy, Scr.Root, Scr.Root, 0, 0, 0, 0, Stashed_X, Stashed_Y);
       XFlush (dpy);
     }
 
@@ -459,29 +464,31 @@ XFwmMoveWindow (XfwmWindow * tmp_win, int xl, int yt, int Width,
 		int Height, int desk, Bool opaque_move)
 {
   int newdesk = desk;
+  int evx, evy;
+  int warpx, warpy;
+
   if (Scr.SnapSize < MINRESISTANCE)
     {				/* do the standard stuff */
       domove (tmp_win, xl, yt, Width, Height, opaque_move);
       return (tmp_win->Desk);
     }
   else
-    {				/* check if the pointer is pushed onto the screen border,
-				   if so, increment the corresponding X or Y counter (until Snapsize),
-				   otherwise reset them to null.
-				 */
-      if (Event.xmotion.x_root == 0)
+    {
+      evx = Event.xmotion.x_root;
+      evy = Event.xmotion.y_root;
+      if (evx == 0)
 	{
 	  Scr.EdgeScrollX--;
 	}
-      else if (Event.xmotion.y_root == 0)
+      else if (evy == 0)
 	{
 	  Scr.EdgeScrollY--;
 	}
-      else if (Event.xmotion.x_root >= Scr.MyDisplayWidth - 1)
+      else if (evx >= Scr.MyDisplayWidth - 1)
 	{
 	  Scr.EdgeScrollX++;
 	}
-      else if (Event.xmotion.y_root >= Scr.MyDisplayHeight - 1)
+      else if (evy >= Scr.MyDisplayHeight - 1)
 	{
 	  Scr.EdgeScrollY++;
 	}
@@ -490,6 +497,7 @@ XFwmMoveWindow (XfwmWindow * tmp_win, int xl, int yt, int Width,
 	  Scr.EdgeScrollY = Scr.EdgeScrollX = 0;
 	}
 
+
       /* now check if some EdgeCounter has reached Snapsize, so that
          we shall emit signals to switch to the next desk (computed in 
          the deskwrap-helper)
@@ -497,8 +505,12 @@ XFwmMoveWindow (XfwmWindow * tmp_win, int xl, int yt, int Width,
       if (Scr.EdgeScrollX <= -Scr.SnapSize)
 	{			/* move desktop left */
 	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-	  XWarpPointer (dpy, None, None, 0, 0, 0, 0,
-			+(Scr.MyDisplayWidth - Scr.SnapSize), (0));
+          warpx = Scr.MyDisplayWidth;
+          warpy = evy;
+	  XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                        0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+			my_min(MyDisplayMaxX(warpx,warpy) - 1, warpx) - Scr.SnapSize,
+                        my_min(MyDisplayMaxY(warpx,warpy) - 1, warpy));
 	  if (!opaque_move)
 	    MoveOutline (tmp_win, 0, 0, 0, 0);
 	  newdesk = _xfwm_deskwrap (-1, 0);
@@ -513,8 +525,12 @@ XFwmMoveWindow (XfwmWindow * tmp_win, int xl, int yt, int Width,
       if (Scr.EdgeScrollX >= +Scr.SnapSize)
 	{			/* move desktop right */
 	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-	  XWarpPointer (dpy, None, None, 0, 0, 0, 0,
-			-(Scr.MyDisplayWidth - Scr.SnapSize), (0));
+          warpx = 0;
+          warpy = evy;
+	  XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                        0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+			my_min(MyDisplayX(warpx,warpy), warpx) + Scr.SnapSize,
+                        my_min(MyDisplayMaxY(warpx,warpy) - 1, warpy));
 	  if (!opaque_move)
 	    MoveOutline (tmp_win, 0, 0, 0, 0);
 	  newdesk = _xfwm_deskwrap (+1, 0);
@@ -529,8 +545,12 @@ XFwmMoveWindow (XfwmWindow * tmp_win, int xl, int yt, int Width,
       if (Scr.EdgeScrollY <= -Scr.SnapSize)
 	{			/* move desktop upper */
 	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-	  XWarpPointer (dpy, None, None, 0, 0, 0, 0, (0),
-			+(Scr.MyDisplayHeight - Scr.SnapSize));
+          warpx = evx;
+          warpy = Scr.MyDisplayHeight;
+	  XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                        0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+			my_min(MyDisplayMaxX(warpx,warpy) - 1, warpx),
+                        my_min(MyDisplayMaxY(warpx,warpy) - 1, warpy) - Scr.SnapSize);
 	  if (!opaque_move)
 	    MoveOutline (tmp_win, 0, 0, 0, 0);
 	  newdesk = _xfwm_deskwrap (0, -1);
@@ -545,8 +565,12 @@ XFwmMoveWindow (XfwmWindow * tmp_win, int xl, int yt, int Width,
       if (Scr.EdgeScrollY >= +Scr.SnapSize)
 	{			/* move desktop lower */
 	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-	  XWarpPointer (dpy, None, None, 0, 0, 0, 0, (0),
-			-(Scr.MyDisplayHeight - Scr.SnapSize));
+          warpx = evx;
+          warpy = 0;
+	  XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                        0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+			my_min(MyDisplayMaxX(warpx,warpy) - 1, warpx),
+                        my_min(MyDisplayY(warpx,warpy), warpy) + Scr.SnapSize);
 	  if (!opaque_move)
 	    MoveOutline (tmp_win, 0, 0, 0, 0);
 	  newdesk = _xfwm_deskwrap (0, +1);
