@@ -22,31 +22,35 @@
 #include "module.h"
 #include "constant.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 char *xfwm_file = NULL;
 
 char *
-build_path(char *value)
+build_path (char *value)
 {
   static char filename[MAXSTRLEN];
   char *path;
-  
+
   path = (char *) getenv ("XFCE_DATA");
-  if (path) 
+  if (path)
     strcpy (filename, path);
   else
     strcpy (filename, XFCE_DIR);
-    
-  if ((value) && strlen(value))
+
+  if ((value) && strlen (value))
     strcat (filename, value);
-    
+
   return filename;
 }
 
 struct moduleInfoList
-  {
-    char *data;
-    struct moduleInfoList *next;
-  };
+{
+  char *data;
+  struct moduleInfoList *next;
+};
 
 struct moduleInfoList *modlistroot = NULL;
 
@@ -65,8 +69,7 @@ extern void StartupStuff (void);
  */
 static void
 ReadSubFunc (XEvent * eventp, Window junk, XfwmWindow * tmp_win,
-	     unsigned long context, char *action, int *Module,
-	     int piperead)
+	     unsigned long context, char *action, int *Module, int piperead)
 {
   char *filename = NULL, *Home = NULL, *home_file, *ofilename = NULL;
   char *rest, *tline, line[1000];
@@ -128,7 +131,8 @@ ReadSubFunc (XEvent * eventp, Window junk, XfwmWindow * tmp_win,
     {
       xfwm_msg (INFO,
 		piperead ? "PipeRead" : "Read",
-		piperead ? "command '%s' not run from %s" : "Skipping '%s': not in $HOME nor %s", ofilename, 
+		piperead ? "command '%s' not run from %s" :
+		"Skipping '%s': not in $HOME nor %s", ofilename,
 		(Home ? Home : XFCE_DIR));
       if ((ofilename != filename) && (filename != NULL))
 	{
@@ -228,7 +232,8 @@ AddToModList (char *tline)
       t = t->next;
     }
 
-  this = (struct moduleInfoList *) safemalloc (sizeof (struct moduleInfoList));
+  this =
+    (struct moduleInfoList *) safemalloc (sizeof (struct moduleInfoList));
   this->data = (char *) safemalloc (strlen (tline) + 1);
   this->next = NULL;
   strcpy (this->data, tline);
@@ -301,13 +306,13 @@ SendDataToModule (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   char msg2[32];
 
   sprintf (msg2, "ClickTime %d\n", Scr.ClickTime);
-  SendName (*Module, M_CONFIG_INFO, 0, 0, 0, msg2);
+  SendName (*Module, XFCE_M_CONFIG_INFO, 0, 0, 0, msg2);
 
   t = modlistroot;
   while (t != NULL)
     {
-      SendName (*Module, M_CONFIG_INFO, 0, 0, 0, t->data);
+      SendName (*Module, XFCE_M_CONFIG_INFO, 0, 0, 0, t->data);
       t = t->next;
     }
-  SendPacket (*Module, M_END_CONFIG_INFO, 0, 0, 0, 0, 0, 0, 0, 0);
+  SendPacket (*Module, XFCE_M_END_CONFIG_INFO, 0, 0, 0, 0, 0, 0, 0, 0);
 }
