@@ -60,18 +60,23 @@ resize_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   Window ResizeWindow;
   extern int Stashed_X, Stashed_Y;
   int val1, val2, val1_unit, val2_unit, n;
+  int center_x;
+  int center_y;
   XGCValues gcv;
 
 
   if (DeferExecution (eventp, &w, &tmp_win, &context, MOVE, ButtonPress))
     return;
 
-  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit);
+  if (tmp_win->flags & ICONIFIED)
+    return;
 
   tmp_win->flags &= ~MAXIMIZED;
 
-  if (tmp_win->flags & ICONIFIED)
-    return;
+  center_x = tmp_win->frame_x + (tmp_win->frame_width / 2);
+  center_y = tmp_win->frame_y + (tmp_win->frame_height / 2);
+
+  n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit, center_x, center_y);
 
   ResizeWindow = tmp_win->frame;
 
@@ -100,7 +105,10 @@ resize_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   InstallRootColormap ();
   if (menuFromFrameOrWindowOrTitlebar)
     {
-      XWarpPointer (dpy, None, Scr.Root, 0, 0, 0, 0, Stashed_X, Stashed_Y);
+      XWarpPointer (dpy, Scr.Root, Scr.Root, 
+                    0, 0, Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+                    my_min(MyDisplayMaxX(Stashed_X,Stashed_Y) - 1, Stashed_X),
+                    my_min(MyDisplayMaxY(Stashed_X,Stashed_Y) - 1, Stashed_Y));
       XFlush (dpy);
     }
 
