@@ -15,7 +15,9 @@
 
 /* Initially inspired by fvwm2, enlightment and twm implementations */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif 
 
 #include <stdio.h>
 #include <string.h>
@@ -32,46 +34,51 @@
 #include "utils.h"
 #include "constant.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 extern int master_pid;
 
 
 typedef struct _match
 {
-  unsigned long      win;
-  unsigned long      client_leader;
-  char               *client_id;
-  char               *res_name;
-  char               *res_class;
-  char               *window_role;
-  char               *wm_name;
-  int                wm_command_count;
-  char               **wm_command;
-  int                x, y, w, h, icon_x, icon_y;
-  int                desktop;
-  unsigned long      flags;
-  int                used;
+  unsigned long win;
+  unsigned long client_leader;
+  char *client_id;
+  char *res_name;
+  char *res_class;
+  char *window_role;
+  char *wm_name;
+  int wm_command_count;
+  char **wm_command;
+  int x, y, w, h, icon_x, icon_y;
+  int desktop;
+  unsigned long flags;
+  int used;
 }
 Match;
 
-int                 sm_fd = -1;
+int sm_fd = -1;
 
-static char         *sm_client_id = NULL;
-static int          num_match = 0;
-static Match        *matches = NULL;
-static Bool         sent_save_done = 0;
+static char *sm_client_id = NULL;
+static int num_match = 0;
+static Match *matches = NULL;
+static Bool sent_save_done = 0;
 
 extern Bool Restarting;
 
-static
-char *duplicate(char *s)
+static char *
+duplicate (char *s)
 {
   int l;
   char *r;
 
-  if (!s) return NULL;
-  l = strlen(s);
-  r = (char *) malloc (sizeof(char)*(l+1));
-  strncpy(r, s, l+1);
+  if (!s)
+    return NULL;
+  l = strlen (s);
+  r = (char *) malloc (sizeof (char) * (l + 1));
+  strncpy (r, s, l + 1);
   return r;
 }
 
@@ -85,16 +92,14 @@ extern int g_argc;
 
 SmcConn sm_conn = NULL;
 
-static void
-set_sm_properties (SmcConn sm_conn, char *filename, char hint);
+static void set_sm_properties (SmcConn sm_conn, char *filename, char hint);
 
-static int
-save_session_state (SmcConn sm_conn, char *filename, FILE *f);
+static int save_session_state (SmcConn sm_conn, char *filename, FILE * f);
 
 #endif /* HAVE_SESSION */
 
 static char *
-GetWindowRole(Window window)
+GetWindowRole (Window window)
 {
   XTextProperty tp;
 
@@ -108,7 +113,7 @@ GetWindowRole(Window window)
 }
 
 static Window
-GetClientLeader(Window window)
+GetClientLeader (Window window)
 {
   Window client_leader = 0;
   Atom actual_type;
@@ -117,18 +122,21 @@ GetClientLeader(Window window)
   unsigned long bytes_after;
   unsigned char *prop = NULL;
 
-  if (XGetWindowProperty(dpy, window, _XA_WM_CLIENT_LEADER,
-			 0L, 1L, False, AnyPropertyType, &actual_type,
-			 &actual_format, &nitems, &bytes_after, &prop) == Success)
+  if (XGetWindowProperty (dpy, window, _XA_WM_CLIENT_LEADER,
+			  0L, 1L, False, AnyPropertyType, &actual_type,
+			  &actual_format, &nitems, &bytes_after,
+			  &prop) == Success)
     {
-      if (actual_type == XA_WINDOW && actual_format == 32 && nitems == 1 && bytes_after == 0)
-	  client_leader = *((Window *) prop);
+      if (actual_type == XA_WINDOW && actual_format == 32 && nitems == 1
+	  && bytes_after == 0)
+	client_leader = *((Window *) prop);
+      XFree (prop);
     }
   return client_leader;
 }
 
 static char *
-GetClientID(Window window)
+GetClientID (Window window)
 {
   char *client_id = NULL;
   Window client_leader;
@@ -139,9 +147,9 @@ GetClientID(Window window)
   unsigned long bytes_after;
   unsigned char *prop = NULL;
 
-  if (XGetWindowProperty(dpy, window, _XA_WM_CLIENT_LEADER,
-			 0L, 1L, False, AnyPropertyType, &actual_type,
-			 &actual_format, &nitems, &bytes_after, &prop)
+  if (XGetWindowProperty (dpy, window, _XA_WM_CLIENT_LEADER,
+			  0L, 1L, False, AnyPropertyType, &actual_type,
+			  &actual_format, &nitems, &bytes_after, &prop)
       == Success)
     {
       if (actual_type == XA_WINDOW && actual_format == 32 &&
@@ -165,21 +173,23 @@ GetClientID(Window window)
 }
 
 /* The following tries to get the command line from the XfwmWindow */
-static int 
-GetWindowCommand (XfwmWindow *tmp_win, char ***argv, int *argc)
+static int
+GetWindowCommand (XfwmWindow * tmp_win, char ***argv, int *argc)
 {
-      int id;
+  int id;
 
-      if (XGetCommand (dpy, tmp_win->w, argv, argc) && (*argc > 0)) return 1;
-      if ((id = GetClientLeader(tmp_win->w)))
-        {
-          if (XGetCommand (dpy, id, argv, argc) && (*argc > 0)) return 1;
-        }
-      return 0;
+  if (XGetCommand (dpy, tmp_win->w, argv, argc) && (*argc > 0))
+    return 1;
+  if ((id = GetClientLeader (tmp_win->w)))
+    {
+      if (XGetCommand (dpy, id, argv, argc) && (*argc > 0))
+	return 1;
+    }
+  return 0;
 }
 
 static int
-SaveWindowStates(FILE *f)
+SaveWindowStates (FILE * f)
 {
   char *client_id;
   char *window_role;
@@ -195,83 +205,88 @@ SaveWindowStates(FILE *f)
       /*
        * Skip transient windows
        */
-      if ((tmp_win->flags & TRANSIENT) && (tmp_win->transientfor != tmp_win->w))
-        continue;
-        
-      fprintf(f, "[CLIENT] %lx\n", tmp_win->w);
+      if ((tmp_win->flags & TRANSIENT)
+	  && (tmp_win->transientfor != tmp_win->w))
+	continue;
 
-      client_id = GetClientID(tmp_win->w);
+      fprintf (f, "[CLIENT] %lx\n", tmp_win->w);
+
+      client_id = GetClientID (tmp_win->w);
       if (client_id)
 	{
-	  fprintf(f, "  [CLIENT_ID] %s\n", client_id);
-	  XFree(client_id);
+	  fprintf (f, "  [CLIENT_ID] %s\n", client_id);
+	  XFree (client_id);
 	}
 
-      client_leader = GetClientLeader(tmp_win->w);
+      client_leader = GetClientLeader (tmp_win->w);
       if (client_leader)
-        fprintf(f, "  [CLIENT_LEADER] %li\n", client_leader);
+	fprintf (f, "  [CLIENT_LEADER] %li\n", client_leader);
 
-      window_role = GetWindowRole(tmp_win->w);
+      window_role = GetWindowRole (tmp_win->w);
       if (window_role)
 	{
-	  fprintf(f, "  [WINDOW_ROLE] %s\n", window_role);
-	  XFree(window_role);
+	  fprintf (f, "  [WINDOW_ROLE] %s\n", window_role);
+	  XFree (window_role);
 	}
 
       if (tmp_win->class.res_class)
-        fprintf(f, "  [RES_NAME] %s\n", tmp_win->class.res_name);
+	fprintf (f, "  [RES_NAME] %s\n", tmp_win->class.res_name);
 
       if (tmp_win->class.res_name)
-        fprintf(f, "  [RES_CLASS] %s\n", tmp_win->class.res_class);
+	fprintf (f, "  [RES_CLASS] %s\n", tmp_win->class.res_class);
 
       if (tmp_win->name)
-        fprintf(f, "  [WM_NAME] %s\n", tmp_win->name);
+	fprintf (f, "  [WM_NAME] %s\n", tmp_win->name);
 
-      if (GetWindowCommand (tmp_win, &wm_command, &wm_command_count) && (wm_command_count > 0))
-        {
-          fprintf(f, "  [WM_COMMAND] %i", wm_command_count);
-          for (i = 0; i < wm_command_count; i++)
-            fprintf(f, " %s", wm_command[i]);
-          fprintf(f, "\n");
-          XFreeStringList (wm_command);
-        }
+      if (GetWindowCommand (tmp_win, &wm_command, &wm_command_count)
+	  && (wm_command_count > 0))
+	{
+	  fprintf (f, "  [WM_COMMAND] %i", wm_command_count);
+	  for (i = 0; i < wm_command_count; i++)
+	    fprintf (f, " %s", wm_command[i]);
+	  fprintf (f, "\n");
+	  XFreeStringList (wm_command);
+	}
 
-      fprintf(f, "  [GEOMETRY] %i %i %i %i %i %i\n",
-	      tmp_win->orig_x,
-              tmp_win->orig_y,
-	      tmp_win->orig_wd - 2*tmp_win->boundary_width ,
-	      tmp_win->orig_ht -2*tmp_win->boundary_width-tmp_win->title_height,
-              tmp_win->icon_x_loc,
-              tmp_win->icon_y_loc);
-      fprintf(f, "  [DESK] %i\n", ((tmp_win->flags & (STICKY)) ? 0 : tmp_win->Desk));
-      fprintf(f, "  [FLAGS] %li\n", (tmp_win->flags & (STICKY | ICONIFIED| ICON_MOVED | SHADED | WM_NAME_CHANGED)));
+      fprintf (f, "  [GEOMETRY] %i %i %i %i %i %i\n",
+	       tmp_win->orig_x,
+	       tmp_win->orig_y,
+	       tmp_win->orig_wd - 2 * tmp_win->boundary_width,
+	       tmp_win->orig_ht - 2 * tmp_win->boundary_width -
+	       tmp_win->title_height, tmp_win->icon_x_loc,
+	       tmp_win->icon_y_loc);
+      fprintf (f, "  [DESK] %i\n",
+	       ((tmp_win->flags & (STICKY)) ? 0 : tmp_win->Desk));
+      fprintf (f, "  [FLAGS] %li\n",
+	       (tmp_win->flags & (STICKY | ICONIFIED | ICON_MOVED | SHADED |
+				  WM_NAME_CHANGED)));
     }
   MyXUngrabServer (dpy);
   return 1;
 }
 
 void
-LoadWindowStates(char *filename)
+LoadWindowStates (char *filename)
 {
-  FILE               *f;
-  char                s[4096], s1[4096];
+  FILE *f;
+  char s[4096], s1[4096];
   int i, pos, pos1;
   unsigned long w;
-  
+
   /* We just ignore session management if restarting xfwm */
   if (Restarting)
     return;
 
   if (filename && (f = fopen (filename, "r")))
     {
-      while (fgets(s, sizeof(s), f))
+      while (fgets (s, sizeof (s), f))
 	{
-	  sscanf(s, "%4000s", s1);
-	  if (!strcmp(s1, "[CLIENT]"))
+	  sscanf (s, "%4000s", s1);
+	  if (!strcmp (s1, "[CLIENT]"))
 	    {
-	      sscanf(s, "%*s %lx", &w);
+	      sscanf (s, "%*s %lx", &w);
 	      num_match++;
-	      matches = realloc(matches, sizeof(Match) * num_match);
+	      matches = realloc (matches, sizeof (Match) * num_match);
 	      matches[num_match - 1].win = w;
 	      matches[num_match - 1].client_id = NULL;
 	      matches[num_match - 1].res_name = NULL;
@@ -288,73 +303,72 @@ LoadWindowStates(char *filename)
 	      matches[num_match - 1].icon_y = 0;
 	      matches[num_match - 1].desktop = 0;
 	      matches[num_match - 1].used = 0;
-              matches[num_match - 1].flags = 0; 
+	      matches[num_match - 1].flags = 0;
 	    }
-	  else if (!strcmp(s1, "[GEOMETRY]"))
+	  else if (!strcmp (s1, "[GEOMETRY]"))
 	    {
-	      sscanf(s, "%*s %i %i %i %i %i %i",
-		     &(matches[num_match - 1].x),
-		     &(matches[num_match - 1].y),
-		     &(matches[num_match - 1].w),
-		     &(matches[num_match - 1].h),
-		     &(matches[num_match - 1].icon_x),
-		     &(matches[num_match - 1].icon_y));
+	      sscanf (s, "%*s %i %i %i %i %i %i",
+		      &(matches[num_match - 1].x),
+		      &(matches[num_match - 1].y),
+		      &(matches[num_match - 1].w),
+		      &(matches[num_match - 1].h),
+		      &(matches[num_match - 1].icon_x),
+		      &(matches[num_match - 1].icon_y));
 	    }
-	  else if (!strcmp(s1, "[DESK]"))
+	  else if (!strcmp (s1, "[DESK]"))
 	    {
-	      sscanf(s, "%*s %i",
-		     &(matches[num_match - 1].desktop));
+	      sscanf (s, "%*s %i", &(matches[num_match - 1].desktop));
 	    }
-	  else if (!strcmp(s1, "[CLIENT_LEADER]"))
+	  else if (!strcmp (s1, "[CLIENT_LEADER]"))
 	    {
-	      sscanf(s, "%*s %li",
-		     &(matches[num_match - 1].client_leader));
+	      sscanf (s, "%*s %li", &(matches[num_match - 1].client_leader));
 	    }
-	  else if (!strcmp(s1, "[FLAGS]"))
+	  else if (!strcmp (s1, "[FLAGS]"))
 	    {
-	      sscanf(s, "%*s %li",
-		     &(matches[num_match - 1].flags));
+	      sscanf (s, "%*s %li", &(matches[num_match - 1].flags));
 	    }
-	  else if (!strcmp(s1, "[CLIENT_ID]"))
+	  else if (!strcmp (s1, "[CLIENT_ID]"))
 	    {
-              sscanf(s, "%*s %[^\n]", s1);
-	      matches[num_match - 1].client_id = duplicate(s1);
+	      sscanf (s, "%*s %[^\n]", s1);
+	      matches[num_match - 1].client_id = duplicate (s1);
 	    }
-	  else if (!strcmp(s1, "[WINDOW_ROLE]"))
+	  else if (!strcmp (s1, "[WINDOW_ROLE]"))
 	    {
-              sscanf(s, "%*s %[^\n]", s1);
-	      matches[num_match - 1].window_role = duplicate(s1);
+	      sscanf (s, "%*s %[^\n]", s1);
+	      matches[num_match - 1].window_role = duplicate (s1);
 	    }
-	  else if (!strcmp(s1, "[RES_NAME]"))
+	  else if (!strcmp (s1, "[RES_NAME]"))
 	    {
-              sscanf(s, "%*s %[^\n]", s1);
-	      matches[num_match - 1].res_name = duplicate(s1);
+	      sscanf (s, "%*s %[^\n]", s1);
+	      matches[num_match - 1].res_name = duplicate (s1);
 	    }
-	  else if (!strcmp(s1, "[RES_CLASS]"))
+	  else if (!strcmp (s1, "[RES_CLASS]"))
 	    {
-              sscanf(s, "%*s %[^\n]", s1);
-	      matches[num_match - 1].res_class = duplicate(s1);
+	      sscanf (s, "%*s %[^\n]", s1);
+	      matches[num_match - 1].res_class = duplicate (s1);
 	    }
-	  else if (!strcmp(s1, "[WM_NAME]"))
+	  else if (!strcmp (s1, "[WM_NAME]"))
 	    {
-              sscanf(s, "%*s %[^\n]", s1);
-	      matches[num_match - 1].wm_name = duplicate(s1);
+	      sscanf (s, "%*s %[^\n]", s1);
+	      matches[num_match - 1].wm_name = duplicate (s1);
 	    }
-	  else if (!strcmp(s1, "[WM_COMMAND]"))
+	  else if (!strcmp (s1, "[WM_COMMAND]"))
 	    {
-              sscanf(s, "%*s %i%n", &matches[num_match - 1].wm_command_count, &pos);
-              matches[num_match - 1].wm_command =
-	      (char **) malloc (matches[num_match - 1].wm_command_count * sizeof (char *));
-              for (i = 0; i < matches[num_match - 1].wm_command_count; i++)
-              {
-                sscanf (s+pos, "%s%n", s1, &pos1);
-                pos += pos1;
-                matches[num_match - 1].wm_command[i] = duplicate (s1);
-              }
+	      sscanf (s, "%*s %i%n", &matches[num_match - 1].wm_command_count,
+		      &pos);
+	      matches[num_match - 1].wm_command =
+		(char **) malloc (matches[num_match - 1].wm_command_count *
+				  sizeof (char *));
+	      for (i = 0; i < matches[num_match - 1].wm_command_count; i++)
+		{
+		  sscanf (s + pos, "%s%n", s1, &pos1);
+		  pos += pos1;
+		  matches[num_match - 1].wm_command[i] = duplicate (s1);
+		}
 	    }
 
 	}
-      fclose(f);
+      fclose (f);
     }
 }
 
@@ -363,30 +377,30 @@ void
 FreeWindowStates (void)
 {
   int i;
-  
+
   for (i = 0; i < num_match; i++)
     {
       if (matches[i].client_id)
-        free(matches[i].client_id);
+	free (matches[i].client_id);
       if (matches[i].res_name)
-        free(matches[i].res_name);
+	free (matches[i].res_name);
       if (matches[i].res_class)
-        free(matches[i].res_class);
-      if (matches[i].window_role);
-        free(matches[i].window_role);
+	free (matches[i].res_class);
+      if (matches[i].window_role)
+        free (matches[i].window_role);
       if (matches[i].wm_name)
-        free(matches[i].wm_name);
+	free (matches[i].wm_name);
       if (matches[i].wm_command_count)
-        XFreeStringList (matches[i].wm_command);
+	XFreeStringList (matches[i].wm_command);
     }
-    free(matches);
 }
 
 /* This complicated logic is from twm, where it is explained */
 
 #define xstreq(a,b) ((!a && !b) || (a && b && (strcmp(a,b)==0)))
 
-static Bool matchWin(XfwmWindow *w, Match *m)
+static Bool
+matchWin (XfwmWindow * w, Match * m)
 {
   char *client_id = NULL;
   char *window_role = NULL;
@@ -396,69 +410,70 @@ static Bool matchWin(XfwmWindow *w, Match *m)
 
   found = 0;
 
-  client_id = GetClientID(w->w);
+  client_id = GetClientID (w->w);
 
-  if (xstreq(client_id, m->client_id))
+  if (xstreq (client_id, m->client_id))
     {
 
       /* client_id's match */
 
-      window_role = GetWindowRole(w->w);
+      window_role = GetWindowRole (w->w);
 
       if (window_role || m->window_role)
-        {
-          /* We have or had a window role, base decision on it */
+	{
+	  /* We have or had a window role, base decision on it */
 
-          found = xstreq(window_role, m->window_role);
+	  found = xstreq (window_role, m->window_role);
 
-        }
+	}
       else
 	{
-          /* Compare res_class, res_name and WM_NAME, unless the
-           * WM_NAME has changed
-           */
-	  if (xstreq(w->class.res_name, m->res_name) &&
+	  /* Compare res_class, res_name and WM_NAME, unless the
+	   * WM_NAME has changed
+	   */
+	  if (xstreq (w->class.res_name, m->res_name) &&
 	      /* Some GNOME applications do not report the following correctly */
 	      /* xstreq(w->class.res_class, m->res_class) && */
-              ((w->flags & WM_NAME_CHANGED) || (m->flags & WM_NAME_CHANGED) || xstreq(w->name, m->wm_name)))
+	      ((w->flags & WM_NAME_CHANGED) || (m->flags & WM_NAME_CHANGED)
+	       || xstreq (w->name, m->wm_name)))
 
-            {
-              if (client_id)
-                {
-                  /* If we have a client_id, we don't compare
-                     WM_COMMAND, since it will be different. */
-                  found = 1;
-                }
-              else
-	        {
-                  /* for non-SM-aware clients we also compare WM_COMMAND */
-	          GetWindowCommand (w, &wm_command, &wm_command_count);
-	          if (wm_command_count == m->wm_command_count)
+	    {
+	      if (client_id)
+		{
+		  /* If we have a client_id, we don't compare
+		     WM_COMMAND, since it will be different. */
+		  found = 1;
+		}
+	      else
+		{
+		  /* for non-SM-aware clients we also compare WM_COMMAND */
+		  GetWindowCommand (w, &wm_command, &wm_command_count);
+		  if (wm_command_count == m->wm_command_count)
 		    {
 		      for (i = 0; i < wm_command_count; i++)
-		        {
-		          if (strcmp (wm_command[i], m->wm_command[i]) != 0)
+			{
+			  if (strcmp (wm_command[i], m->wm_command[i]) != 0)
 			    break;
-		        }
+			}
 
-                      if ((i == wm_command_count) && (wm_command_count))
-                        {
-                          found = 1;
-                        }
-		    } /* if (wm_command_count ==... */
-                    /* We have to deal with a now-SM-aware client, it means that it won't probably
-                     * restore its state in a proper manner.
-                     * Thus, we also mark all other instances of this application as used, to avoid
-                     * dummy side effects in case we found a matching entry.
-                     */
-                    if (found)
-                      for (i = 0; i < num_match; i++)
-                       {
-                         if (!(matches[i].used) && !(&matches[i] == m) 
-			      && (m->client_leader)
-			      && (matches[i].client_leader == m->client_leader))
-                         matches[i].used = 1;
-                       }
+		      if ((i == wm_command_count) && (wm_command_count))
+			{
+			  found = 1;
+			}
+		    }		/* if (wm_command_count ==... */
+		  /* We have to deal with a now-SM-aware client, it means that it won't probably
+		   * restore its state in a proper manner.
+		   * Thus, we also mark all other instances of this application as used, to avoid
+		   * dummy side effects in case we found a matching entry.
+		   */
+		  if (found)
+		    for (i = 0; i < num_match; i++)
+		      {
+			if (!(matches[i].used) && !(&matches[i] == m)
+			    && (m->client_leader)
+			    && (matches[i].client_leader == m->client_leader))
+			  matches[i].used = 1;
+		      }
 		}
 	    }
 	}
@@ -476,14 +491,14 @@ static Bool matchWin(XfwmWindow *w, Match *m)
 }
 
 void
-MatchWinToSM(XfwmWindow *tmp_win)
+MatchWinToSM (XfwmWindow * tmp_win)
 {
   int i;
   int gravx, gravy;
 
   for (i = 0; i < num_match; i++)
     {
-      if (!matches[i].used && matchWin(tmp_win, &matches[i]))
+      if (!matches[i].used && matchWin (tmp_win, &matches[i]))
 	{
 	  matches[i].used = 1;
 
@@ -496,11 +511,12 @@ MatchWinToSM(XfwmWindow *tmp_win)
 	  tmp_win->xdiff = tmp_win->attr.x;
 	  tmp_win->ydiff = tmp_win->attr.y;
 
-          GetGravityOffsets (tmp_win, &gravx, &gravy);
+	  GetGravityOffsets (tmp_win, &gravx, &gravy);
 	  tmp_win->attr.y -= gravy * (tmp_win->bw - tmp_win->old_bw);
 	  tmp_win->attr.x -= gravx * (tmp_win->bw - tmp_win->old_bw);
 	  if (gravy > 0)
-	    tmp_win->attr.y -= 2 * tmp_win->boundary_width + tmp_win->title_height;
+	    tmp_win->attr.y -=
+	      2 * tmp_win->boundary_width + tmp_win->title_height;
 	  if (gravx > 0)
 	    tmp_win->attr.x -= 2 * tmp_win->boundary_width;
 
@@ -508,13 +524,14 @@ MatchWinToSM(XfwmWindow *tmp_win)
 	     put icons on the current page */
 	  tmp_win->icon_x_loc = matches[i].icon_x;
 	  tmp_win->icon_y_loc = matches[i].icon_y;
-          tmp_win->Desk = matches[i].desktop;
-          tmp_win->flags |= (matches[i].flags & (STICKY | ICON_MOVED | SHADED));
-          if (matches[i].flags & ICONIFIED)
-            {
-              tmp_win->flags |= ICON_MOVED;
-              tmp_win->flags |= STARTICONIC;
-            }
+	  tmp_win->Desk = matches[i].desktop;
+	  tmp_win->flags |=
+	    (matches[i].flags & (STICKY | ICON_MOVED | SHADED));
+	  if (matches[i].flags & ICONIFIED)
+	    {
+	      tmp_win->flags |= ICON_MOVED;
+	      tmp_win->flags |= STARTICONIC;
+	    }
 	  return;
 	}
     }
@@ -524,40 +541,40 @@ void
 RestartInSession (char *filename)
 {
   FILE *f;
-  
+
 #ifdef HAVE_SESSION
   if (sm_conn)
     {
       if (Scr.Options & SessionMgt)
 	{
-          f = fopen (filename, "w");
+	  f = fopen (filename, "w");
 	  if (last_used_filename)
 	    fprintf (f, "[SESSION_STATE] %s\n", last_used_filename);
-          save_session_state (sm_conn, filename, f);
-          fclose (f);
+	  save_session_state (sm_conn, filename, f);
+	  fclose (f);
 	}
       set_sm_properties (sm_conn, filename, SmRestartImmediately);
 
-      XSelectInput(dpy, Scr.Root, 0);
-      XSync(dpy, 0);
-      XCloseDisplay(dpy);
+      XSelectInput (dpy, Scr.Root, 0);
+      XSync (dpy, 0);
+      XCloseDisplay (dpy);
 
-      SmcCloseConnection(sm_conn, 0, NULL);
+      SmcCloseConnection (sm_conn, 0, NULL);
 
-      exit (0); /* let the SM restart us */
+      exit (0);			/* let the SM restart us */
     }
 #endif
   if (Scr.Options & SessionMgt)
     {
       f = fopen (filename, "w");
       SaveWindowStates (f);
-      fclose (f); /* return and let Done restart us */
+      fclose (f);		/* return and let Done restart us */
     }
 }
 
 #ifdef HAVE_SESSION
 static void
-callback_save_yourself2(SmcConn sm_conn, SmPointer client_data)
+callback_save_yourself2 (SmcConn sm_conn, SmPointer client_data)
 {
   char *path = NULL;
   char *filename = NULL;
@@ -572,7 +589,7 @@ callback_save_yourself2(SmcConn sm_conn, SmPointer client_data)
       path = pwd->pw_dir;
     }
 
-  filename = tempnam(path, ".fs-");
+  filename = tempnam (path, ".fs-");
 
   if (Scr.Options & SessionMgt)
     {
@@ -580,12 +597,12 @@ callback_save_yourself2(SmcConn sm_conn, SmPointer client_data)
       success = save_session_state (sm_conn, filename, f);
       fclose (f);
     }
-  if (!success) 
+  if (!success)
     xfwm_msg (WARN, "SaveSession", "Can't save session\n");
   /* also save session for builtin session mgt, so user will get
    * back to his environmnent even if he doesn't use ICE
    */
-  builtin_save_session();
+  builtin_save_session ();
   SmcSaveYourselfDone (sm_conn, success);
   sent_save_done = 1;
 }
@@ -602,9 +619,10 @@ set_sm_properties (SmcConn sm_conn, char *filename, char hint)
   char *user_id;
   int numVals, i, priority = 30;
 
-  if (!sm_conn) return;
+  if (!sm_conn)
+    return;
 
-  pwd = getpwuid (getuid());
+  pwd = getpwuid (getuid ());
   user_id = pwd->pw_name;
 
   prop1.name = SmProgram;
@@ -625,14 +643,14 @@ set_sm_properties (SmcConn sm_conn, char *filename, char hint)
   prop3.type = SmCARD8;
   prop3.num_vals = 1;
   prop3.vals = &prop3val;
-  prop3val.value = (SmPointer) &hint;
+  prop3val.value = (SmPointer) & hint;
   prop3val.length = 1;
 
   prop4.name = "_GSM_Priority";
   prop4.type = SmCARD8;
   prop4.num_vals = 1;
   prop4.vals = &prop4val;
-  prop4val.value = (SmPointer) &priority;
+  prop4val.value = (SmPointer) & priority;
   prop4val.length = 1;
 
   prop5.name = SmRestartCommand;
@@ -649,7 +667,9 @@ set_sm_properties (SmcConn sm_conn, char *filename, char hint)
 	  strcmp (g_argv[i], "-d") == 0)
 	{
 	  i++;
-	} else if (strcmp (g_argv[i], "-s") != 0) {
+	}
+      else if (strcmp (g_argv[i], "-s") != 0)
+	{
 	  prop5.vals[numVals].value = (SmPointer) g_argv[i];
 	  prop5.vals[numVals++].length = strlen (g_argv[i]);
 	}
@@ -683,7 +703,7 @@ set_sm_properties (SmcConn sm_conn, char *filename, char hint)
   /* the protocol spec says that the discard command
      should be LISTofARRAY8 on posix systems, but xsm
      demands that it be ARRAY8.
-  */
+   */
   sprintf (discardCommand, "rm -f %s", filename);
   prop6.type = SmARRAY8;
   prop6.num_vals = 1;
@@ -718,26 +738,28 @@ set_sm_properties (SmcConn sm_conn, char *filename, char hint)
 }
 
 static int
-save_session_state (SmcConn sm_conn, char *filename, FILE *cfg_file)
+save_session_state (SmcConn sm_conn, char *filename, FILE * cfg_file)
 {
   Bool success = 0;
-  if (!filename || !cfg_file) return 0;
+  if (!filename || !cfg_file)
+    return 0;
 
   success = (SaveWindowStates (cfg_file));
 
   set_sm_properties (sm_conn, filename, SmRestartIfRunning);
-  if (last_used_filename) free (last_used_filename);
+  if (last_used_filename)
+    free (last_used_filename);
   last_used_filename = filename;
 
   return success;
 }
 
 static void
-callback_save_yourself(SmcConn sm_conn, SmPointer client_data,
-		       int save_style, Bool shutdown, int interact_style,
-		       Bool fast)
+callback_save_yourself (SmcConn sm_conn, SmPointer client_data,
+			int save_style, Bool shutdown, int interact_style,
+			Bool fast)
 {
-  if (!SmcRequestSaveYourselfPhase2(sm_conn, callback_save_yourself2, NULL))
+  if (!SmcRequestSaveYourselfPhase2 (sm_conn, callback_save_yourself2, NULL))
     {
       SmcSaveYourselfDone (sm_conn, False);
       sent_save_done = 1;
@@ -747,27 +769,27 @@ callback_save_yourself(SmcConn sm_conn, SmPointer client_data,
 }
 
 static void
-callback_die(SmcConn sm_conn, SmPointer client_data)
+callback_die (SmcConn sm_conn, SmPointer client_data)
 {
-  SmcCloseConnection(sm_conn, 0, NULL);
+  SmcCloseConnection (sm_conn, 0, NULL);
   sm_fd = -1;
 
-  if (master_pid != getpid())
-    kill(master_pid, SIGTERM);
-  Done(XFWM_END, NULL);
+  if (master_pid != getpid ())
+    kill (master_pid, SIGTERM);
+  Done (XFWM_END, NULL);
 }
 
 static void
-callback_save_complete(SmcConn sm_conn, SmPointer client_data)
+callback_save_complete (SmcConn sm_conn, SmPointer client_data)
 {
 }
 
 static void
-callback_shutdown_cancelled(SmcConn sm_conn, SmPointer client_data)
+callback_shutdown_cancelled (SmcConn sm_conn, SmPointer client_data)
 {
   if (!sent_save_done)
     {
-      SmcSaveYourselfDone(sm_conn, False);
+      SmcSaveYourselfDone (sm_conn, False);
       sent_save_done = 1;
     }
 }
@@ -797,14 +819,14 @@ InstallIOErrorHandler (void)
 #endif /* HAVE_SESSION */
 
 void
-SessionInit(char *previous_client_id)
+SessionInit (char *previous_client_id)
 {
 #ifdef HAVE_SESSION
-  char                error_string_ret[4096] = "";
-  static SmPointer    context;
-  SmcCallbacks        callbacks;
+  char error_string_ret[4096] = "";
+  static SmPointer context;
+  SmcCallbacks callbacks;
 
-  InstallIOErrorHandler();
+  InstallIOErrorHandler ();
 
   callbacks.save_yourself.callback = callback_save_yourself;
   callbacks.die.callback = callback_die;
@@ -816,47 +838,48 @@ SessionInit(char *previous_client_id)
     callbacks.save_complete.client_data =
     callbacks.shutdown_cancelled.client_data = (SmPointer) NULL;
 
-  sm_conn = SmcOpenConnection(NULL, &context, SmProtoMajor, SmProtoMinor,
-			      SmcSaveYourselfProcMask | SmcDieProcMask |
-			      SmcSaveCompleteProcMask |
-			      SmcShutdownCancelledProcMask,
-			      &callbacks, previous_client_id, &sm_client_id,
-			      4096, error_string_ret);
+  sm_conn = SmcOpenConnection (NULL, &context, SmProtoMajor, SmProtoMinor,
+			       SmcSaveYourselfProcMask | SmcDieProcMask |
+			       SmcSaveCompleteProcMask |
+			       SmcShutdownCancelledProcMask,
+			       &callbacks, previous_client_id, &sm_client_id,
+			       4096, error_string_ret);
 
   if (!sm_conn)
     {
-      xfwm_msg(INFO, "SessionInit", "X Session Manager not available\n"
-                     "Using builtin session management instead\n");
+      xfwm_msg (INFO, "SessionInit", "X Session Manager not available\n"
+		"Using builtin session management instead\n");
       if (previous_client_id)
-        {
-	  xfwm_msg(WARN, "SessionInit","While connecting to session manager:\n%s.",
-		   error_string_ret);
-        }
+	{
+	  xfwm_msg (WARN, "SessionInit",
+		    "While connecting to session manager:\n%s.",
+		    error_string_ret);
+	}
       sm_fd = -1;
     }
   else
     {
       xfwm_msg (INFO, "SessionInit", "Connected to session manager.\n");
-      sm_fd = IceConnectionNumber(SmcGetIceConnection(sm_conn));
+      sm_fd = IceConnectionNumber (SmcGetIceConnection (sm_conn));
     }
 #endif
   if (sm_fd < 0)
-    builtin_session_startup();
+    builtin_session_startup ();
 }
 
 void
-ProcessICEMsgs(void)
+ProcessICEMsgs (void)
 {
 #ifdef HAVE_SESSION
   IceProcessMessagesStatus status;
 
   if ((sm_fd < 0) || (!sm_conn))
     return;
-  status = IceProcessMessages(SmcGetIceConnection(sm_conn), NULL, NULL);
+  status = IceProcessMessages (SmcGetIceConnection (sm_conn), NULL, NULL);
   if (status == IceProcessMessagesIOError)
     {
-      xfwm_msg(WARN, "ProcessICEMSGS",
-	       "Connection to session manager lost\n");
+      xfwm_msg (WARN, "ProcessICEMSGS",
+		"Connection to session manager lost\n");
       sm_conn = NULL;
       sm_fd = -1;
     }
@@ -864,17 +887,17 @@ ProcessICEMsgs(void)
 }
 
 void
-CloseICEConn(void)
+CloseICEConn (void)
 {
 #ifdef HAVE_SESSION
   if ((sm_fd < 0) || (!sm_conn))
     return;
-  IceCloseConnection(SmcGetIceConnection(sm_conn));
+  IceCloseConnection (SmcGetIceConnection (sm_conn));
 #endif
 }
 
 void
-LogoutICEConn(void)
+LogoutICEConn (void)
 {
 #ifdef HAVE_SESSION
   if ((sm_fd < 0) || (!sm_conn))
@@ -884,66 +907,71 @@ LogoutICEConn(void)
 }
 
 void
-builtin_session_startup(void)
+builtin_session_startup (void)
 {
   int i, j, len;
   char *command;
   Bool found;
 
   /* Ignore session management if restarting xfwm */
-  if (Restarting) 
+  if (Restarting)
     return;
 
   for (i = 0; i < num_match; i++)
     {
       if (matches[i].wm_command_count)
-        {
-          /* Do not restart internal modules */
-          if ((matches[i].wm_command_count > 6) && (!mystrncasecmp (matches[i].wm_command[6], "XFwm", 4)))
-            continue;
-          /* Determine whether or not an action as already been perfored for a given client
-           * It's based on the client leader (do not restart several instances of the same
-           * client leader
-           */
-          found = False;
-          for (j = 0; j < i; j++)
-            if ((matches[i].client_leader)
-	        && (matches[j].client_leader == matches[i].client_leader))
-	        
-              {
-                found = True;
-                break;
-              }
-          if (found) continue;
-          /* Compute command line length and allocate memory */
-          len = 1;
-          for (j = 0; j < matches[i].wm_command_count; j++)
-            len += strlen (matches[i].wm_command[j]) + 1;
-          /* build command line */
-          command = (char *) malloc (sizeof (char) * (len));
-          strcpy (command, matches[i].wm_command[0]);
-          for (j = 1; j < matches[i].wm_command_count; j++)
-            {
-              strcat (command, " ");
-              strcat (command, matches[i].wm_command[j]);
-            }
-          /* Execute command line */
-          if (!(fork ()))		/* child process */
-          {
-            /*
-             * We shall have a rest before starting the actual command,
-             * that will give time for other modules to complete and
-             * it will definitely decrease the server load at startup
-             */
-            sleep_a_little (Scr.sessionwait * 1000000);
-            if (execl (DEFAULT_SHELL, DEFAULT_SHELL, "-c", command, NULL) == -1)
-    	    {
-	      xfwm_msg (WARN, "builtin_session_startup", "Startup of %s failed", matches[num_match].wm_command);
-	      exit (100);
+	{
+	  /* Do not restart internal modules */
+	  if ((matches[i].wm_command_count > 6)
+	      && (!mystrncasecmp (matches[i].wm_command[6], "XFwm", 4)))
+	    continue;
+	  /* Determine whether or not an action as already been perfored for a given client
+	   * It's based on the client leader (do not restart several instances of the same
+	   * client leader
+	   */
+	  found = False;
+	  for (j = 0; j < i; j++)
+	    if ((matches[i].client_leader)
+		&& (matches[j].client_leader == matches[i].client_leader))
+
+	      {
+		found = True;
+		break;
+	      }
+	  if (found)
+	    continue;
+	  /* Compute command line length and allocate memory */
+	  len = 1;
+	  for (j = 0; j < matches[i].wm_command_count; j++)
+	    len += strlen (matches[i].wm_command[j]) + 1;
+	  /* build command line */
+	  command = (char *) malloc (sizeof (char) * (len));
+	  strcpy (command, matches[i].wm_command[0]);
+	  for (j = 1; j < matches[i].wm_command_count; j++)
+	    {
+	      strcat (command, " ");
+	      strcat (command, matches[i].wm_command[j]);
 	    }
-          }
-          free (command);
-        }
+	  /* Execute command line */
+	  if (!(fork ()))	/* child process */
+	    {
+	      /*
+	       * We shall have a rest before starting the actual command,
+	       * that will give time for other modules to complete and
+	       * it will definitely decrease the server load at startup
+	       */
+	      sleep_a_little (Scr.sessionwait * 1000000);
+	      if (execl (DEFAULT_SHELL, DEFAULT_SHELL, "-c", command, NULL) ==
+		  -1)
+		{
+		  xfwm_msg (WARN, "builtin_session_startup",
+			    "Startup of %s failed",
+			    matches[num_match].wm_command);
+		  exit (100);
+		}
+	    }
+	  free (command);
+	}
     }
 }
 
@@ -973,13 +1001,13 @@ builtin_save_session (void)
   if (Scr.screen != 0)
     {
       char temp[4];
-      
+
       sprintf (temp, "-%i", (int) Scr.screen);
       strcat (filename, temp);
     }
 
   f = fopen (filename, "w");
-  if (!f) 
+  if (!f)
     {
       free (filename);
       return 0;
@@ -988,8 +1016,6 @@ builtin_save_session (void)
   fclose (f);
 
   free (filename);
-  
+
   return success;
 }
-
-
