@@ -55,6 +55,14 @@
 #include <fcntl.h>
 #endif
 
+#ifndef HAVE_GETHOSTNAME_PROTO
+extern int gethostname (char *, int);
+#endif
+
+#ifdef HAVE_X11_EXTENSIONS_XINERAMA_H
+  #include <X11/extensions/Xinerama.h>
+#endif
+
 #ifdef DMALLOC
 #  include "dmalloc.h"
 #endif
@@ -71,6 +79,48 @@
 
 #define MAXHOSTNAME 255
 
+#ifdef EMULATE_XINERAMA
+   /* NOTE : Look in xfwm.h to define EMULATE_XINERAMA 
+    * (do not do it here)
+    * 
+    * We simulate 2 screens side by side on a 1024x768 screen :
+    * Left screen is 512x768 pixels wide
+    * Right screen is 512x600 pixels wide with 84 unused pixels 
+    *   on top and bottom of screen (this is to simulate the
+    *   black holes as show below :
+    *
+    *  +-----------------+//////////////////
+    *  |                 |///BLACK HOLE/////
+    *  |                 |//////////////////
+    *  |                 |-----------------+
+    *  |                 |                 |
+    *  |                 |                 |
+    *  |      First      |      Second     |
+    *  |     Screen      |      Screen     |
+    *  |                 |                 |
+    *  |                 |                 |
+    *  |                 |-----------------+
+    *  |                 |//////////////////
+    *  |                 |///BLACK HOLE/////
+    *  +-----------------+//////////////////
+    *
+    */
+
+    static XineramaScreenInfo emulate_infos[2] = 
+    {
+      { 0, 0, 0, 512, 768 },
+      { 0, 512, 84, 512, 600 }
+    };
+    static int emulate_heads = 2;
+#endif
+
+#if defined(HAVE_X11_EXTENSIONS_XINERAMA_H) || defined(EMULATE_XINERAMA)
+  XineramaScreenInfo *xinerama_infos;
+  int xinerama_heads;
+  Bool enable_xinerama;
+#endif
+
+int runlevel;
 int master_pid;			/* process number of 1st xfwm process */
 
 ScreenInfo Scr;			/* structures for the screen */
@@ -96,7 +146,7 @@ static XErrorHandler XfwmErrorHandler (Display *, XErrorEvent *);
 static XIOErrorHandler CatchFatal (Display *);
 static XErrorHandler CatchRedirectError (Display *, XErrorEvent *);
 static void newhandler (int sig);
-static void on_signal (int sig_num);
+static RETSIGTYPE on_signal (int sig_num);
 void CreateCursors (void);
 void ChildDied (int nonsense);
 static void SaveDesktopState (void);
@@ -200,6 +250,10 @@ main (int argc, char **argv)
   char *temp_path = NULL;
   struct passwd *pwd;
 
+#if defined(HAVE_X11_EXTENSIONS_XINERAMA_H)
+  int xinerama_major, xinerama_minor;
+#endif
+
 #ifdef  ENABLE_NLS
   setlocale (LC_ALL, "");
 #endif
@@ -315,20 +369,20 @@ main (int argc, char **argv)
     {
       usage ();
     }
+  ReapChildren ();
 
   newhandler (SIGINT);
   newhandler (SIGHUP);
   newhandler (SIGQUIT);
   newhandler (SIGTERM);
   signal (SIGABRT, on_signal);
-  signal (SIGBUS, on_signal);
+  signal (SIGBUS,  on_signal);
   signal (SIGSEGV, on_signal);
-  signal (SIGFPE, on_signal);
-  signal (SIGUSR1, Restart);
+  signal (SIGFPE,  on_signal);
   signal (SIGPIPE, DeadPipe);
   signal (SIGALRM, enterAlarm);
-
-  ReapChildren ();
+  signal (SIGUSR1, Restart);
+  signal (SIGUSR2, Restart);
 
   if (!(dpy = XOpenDisplay (display_name)))
     {
@@ -338,7 +392,7 @@ main (int argc, char **argv)
     }
   Scr.screen = DefaultScreen (dpy);
   Scr.NumberOfScreens = ScreenCount (dpy);
-
+  
   initModifiers ();
   master_pid = getpid ();
 
@@ -351,7 +405,7 @@ main (int argc, char **argv)
 
       for (i = 0; i < Scr.NumberOfScreens; i++)
 	{
-	  if (i != Scr.screen && fork () == 0)
+	  if ((i != Scr.screen) && (fork () == 0))
 	    {
 	      myscreen = i;
 
@@ -383,6 +437,25 @@ main (int argc, char **argv)
 	}
     }
 
+#ifdef EMULATE_XINERAMA
+  xinerama_infos = emulate_infos;
+  xinerama_heads = emulate_heads;
+  enable_xinerama = True;
+#else
+  #ifdef HAVE_X11_EXTENSIONS_XINERAMA_H
+    if (!XineramaQueryExtension(dpy, &xinerama_major, &xinerama_minor))
+      {
+	enable_xinerama = False;
+        xfwm_msg (INFO, "main", "Xinerama extension disabled\n");
+      }
+    else 
+      {
+        enable_xinerama = True;
+	xinerama_infos = XineramaQueryScreens (dpy, &xinerama_heads);
+      }
+  #endif
+#endif
+
   x_fd = XConnectionNumber (dpy);
   fd_width = GetFdWidth ();
 
@@ -392,7 +465,7 @@ main (int argc, char **argv)
       exit (1);
     }
 
-  /*  Add a DISPLAY entry to the environment, incase we were started
+  /* Add a DISPLAY entry to the environment, in case we were started
    * with xfwm -display term:0.0
    */
   len = strlen (XDisplayString (dpy));
@@ -509,7 +582,19 @@ main (int argc, char **argv)
   if (Scr.Options & SessionMgt)
     LoadWindowStates (restore_filename);
   SessionInit (client_id);
+  SetRunLevel (XFWM_RUNNING);
   HandleEvents ();
+  switch (runlevel)
+  {
+    case XFWM_RESTART:
+      Done (XFWM_RESTART, *g_argv);
+      break;
+    case XFWM_HALT:
+    case XFWM_END:
+    default:
+      Done (XFWM_HALT, NULL);
+      break;
+  }
   return (0);
 }
 
@@ -689,10 +774,11 @@ SetRCDefaults ()
   char *defaults[] = {
     "XORValue 0",
     "ModulePath $PATH",
-    "ActiveColor white #C0C0C0",
-    "InactiveColor black #C0C0C0",
-    "TitleStyle Active Solid #005B80",
-    "TitleStyle Inactive Solid #A4A4A4",
+    "ActiveColor white #B4B2B0",
+    "InactiveColor black #B4B2B0",
+    "TitleStyle Active Solid #9181A0",
+    "TitleStyle Inactive Solid #C5BDB6",
+    "MenuColor black #B4B2B0 black #C5BDB6",
     "CursorColor red white",
     "FocusMode Click",
     "AnimateWin On",
@@ -703,12 +789,9 @@ SetRCDefaults ()
     "SnapSize 10",
     "SessionManagement On",
     "WaitSession 10",
-    "MenuColor black #c0c0c0 white #c0c0c0",
     "IconFont fixed",
     "IconGrid 10",
     "IconSpacing 5",
-    "WindowFont fixed",
-    "MenuFont fixed",
     "Style \"*\" Title, BorderWidth 6",
     "Style \"XFce*\" Sticky",
     "Style \"XFbd*\" Sticky",
@@ -719,16 +802,16 @@ SetRCDefaults ()
     "+ \"\" Nop",
     "+ \"" N_("&Cancel") "\" Nop",
     "AddToMenu \"__builtin_sendtodesk_menu__\"",
-    "+ \"" N_("Workspace &1") "\" WindowsDesk 0 0",
-    "+ \"" N_("Workspace &2") "\" WindowsDesk 0 1",
-    "+ \"" N_("Workspace &3") "\" WindowsDesk 0 2",
-    "+ \"" N_("Workspace &4") "\" WindowsDesk 0 3",
-    "+ \"" N_("Workspace &5") "\" WindowsDesk 0 4",
-    "+ \"" N_("Workspace &6") "\" WindowsDesk 0 5",
-    "+ \"" N_("Workspace &7") "\" WindowsDesk 0 6",
-    "+ \"" N_("Workspace &8") "\" WindowsDesk 0 7",
-    "+ \"" N_("Workspace &9") "\" WindowsDesk 0 8",
-    "+ \"" N_("Workspace 1&0") "\" WindowsDesk 0 9",
+    "+ \"" N_("Workspace") " 1\" WindowsDesk 0 0",
+    "+ \"" N_("Workspace") " 2\" WindowsDesk 0 1",
+    "+ \"" N_("Workspace") " 3\" WindowsDesk 0 2",
+    "+ \"" N_("Workspace") " 4\" WindowsDesk 0 3",
+    "+ \"" N_("Workspace") " 5\" WindowsDesk 0 4",
+    "+ \"" N_("Workspace") " 6\" WindowsDesk 0 5",
+    "+ \"" N_("Workspace") " 7\" WindowsDesk 0 6",
+    "+ \"" N_("Workspace") " 8\" WindowsDesk 0 7",
+    "+ \"" N_("Workspace") " 9\" WindowsDesk 0 8",
+    "+ \"" N_("Workspace") " 10\" WindowsDesk 0 9",
     "AddToMenu \"__builtin_window_menu__\"",
     "+ \"" N_("&Move") "\" Move",
     "+ \"" N_("&Resize") "\" Resize",
@@ -741,12 +824,17 @@ SetRCDefaults ()
     "+ \"" N_("S&witch to...") "\" WindowList",
     "+ \"\" Nop",
     "+ \"" N_("&Close") "\" Delete",
+    "AddToMenu \"user_menu\" \"" N_("User Menu") "\" Title",
     "AddToMenu \"__builtin_root_menu__\"",
     "+ \"" N_("&New window") "\" Exec xfterm",
+    "+ \"" N_("&User Menu") "\" popup user_menu",
     "+ \"" N_("Shuffle &Up") "\" Next [*] focus",
     "+ \"" N_("Shuffle &Down") "\"  Prev [*] focus",
     "+ \"" N_("&Refresh") "\" Refresh",
     "+ \"" N_("&Arrange icons") "\" ArrangeIcons",
+    "+ \"" N_("&Iconify all") "\" IconifyAll",
+    "+ \"\" Nop",
+    "+ \"" N_("Run program ...") "\" Exec xfrun",
     "+ \"\" Nop",
     "+ \"" N_("&Mouse...") "\" Exec xfmouse -i",
     "+ \"\" Nop",
@@ -775,6 +863,9 @@ SetRCDefaults ()
     "+ \"D\" Maximize",
     "AddToFunc \"__Resize__\"",
     "+ \"M\" Resize",
+    "AddToFunc \"__builtin_showmemouse_or_move__\"",
+    "+ \"M\" Move",
+    "+ \"C\" ShowMeMouse",
     "AddToFunc \"__builtin_windowops_or_die__\"",
     "+ \"M\" PopUp \"__builtin_window_menu__\"",
     "+ \"C\" PopUp \"__builtin_window_menu__\"",
@@ -809,7 +900,8 @@ SetRCDefaults ()
     "Mouse 2 R A Menu __builtin_window_menu__ Nop",
     "Mouse 3 I A Menu __builtin_window_menu__ Nop",
     "Mouse 3 R A WindowList",
-    "Mouse 1 W M Move",
+    "Mouse 1 W M __builtin_showmemouse_or_move__",
+    "Mouse 1 R M ShowMeMouse",
     "Key Tab A M Prev [CurrentDesk] __builtin_focus_raise__",
     "Key Tab A SM Next [CurrentDesk] __builtin_focus_raise__",
     "Key Escape A S __builtin_iconify_and_focus__",
@@ -833,6 +925,7 @@ SetRCDefaults ()
     "Key F9 A M Iconify",
     "Key F10 A M Maximize",
     "Key F11 A M Shade",
+    "Key F12 A M Exec xfrun",
     "Key F1 A C Desk 0 0",
     "Key F2 A C Desk 0 1",
     "Key F3 A C Desk 0 2",
@@ -850,6 +943,9 @@ SetRCDefaults ()
     "Key L5 IW S Lower",
     "Key L5 IW C Raise",
     "Key L7 IW A Iconify",
+    "WindowFont "DEFAULTFONT,
+    "MenuFont "DEFAULTFONT,
+    "IconFont "DEFAULTFONT,
     NULL
   };
   int i = 0;
@@ -1103,10 +1199,11 @@ on_signal (int sig_num)
 /*************************************************************************
  * Restart on a signal
  ************************************************************************/
-void
+RETSIGTYPE
 Restart (int nonsense)
 {
-  Done (XFWM_RESTART, *g_argv);
+  xfwm_msg (INFO, "Restart", "Restart signal caught\n");
+  SetRunLevel (XFWM_RESTART);
   SIGNAL_RETURN;
 }
 
@@ -1645,11 +1742,17 @@ InitVariables (void)
 	  {
 	    Restarting = True;
 	    Scr.ndesks = *(unsigned long *) prop;
+	    if (Scr.ndesks < 1)
+	      Scr.ndesks = 1;
 	    if (Scr.ndesks > NBSCREENS)
 	      Scr.ndesks = NBSCREENS;
 	    XFree (prop);
 	  }
+        else
+          Scr.ndesks = NBSCREENS;
       }
+    else
+      Scr.ndesks = NBSCREENS;
   }
 
   Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
@@ -1707,10 +1810,10 @@ Reborder (void)
  *
  ***********************************************************************
  */
-void
+RETSIGTYPE
 SigDone (int nonsense)
 {
-  Done (XFWM_HALT, NULL);
+  SetRunLevel (XFWM_END);
   SIGNAL_RETURN;
 }
 
@@ -1771,6 +1874,11 @@ Done (int restart, char *command)
     XFreeGC (dpy, Scr.BlackGC);
   if (Scr.HintsGC)
     XFreeGC (dpy, Scr.HintsGC);
+#ifndef EMULATE_XINERAMA
+  #ifdef HAVE_X11_EXTENSIONS_XINERAMA_H
+  XFree (xinerama_infos);
+  #endif
+#endif
 
   mr = Scr.AllMenus;
   while (mr)
@@ -1805,47 +1913,46 @@ Done (int restart, char *command)
 
   if (restart)
     {
+      char *my_argv[10];
+      int i, done, j;
       SaveDesktopState ();
 
       /* Really make sure that the connection is closed and cleared! */
       XSelectInput (dpy, Scr.Root, 0);
       XSync (dpy, 0);
       XCloseDisplay (dpy);
+      i = 0;
+      j = 0;
+      done = 0;
+      while ((g_argv[j] != NULL) && (i < 8))
+        {
+          if (strcmp (g_argv[j], "-s") != 0)
+            {
+              my_argv[i] = g_argv[j];
+              i++;
+              j++;
+            }
+          else
+            j++;
+        }
+      if (strstr (command, "xfwm") != NULL)
+        my_argv[i++] = "-s";
+      while (i < 10)
+        my_argv[i++] = NULL;
 
-      {
-	char *my_argv[10];
-	int i, done, j;
-
-	i = 0;
-	j = 0;
-	done = 0;
-	while ((g_argv[j] != NULL) && (i < 8))
-	  {
-	    if (strcmp (g_argv[j], "-s") != 0)
-	      {
-		my_argv[i] = g_argv[j];
-		i++;
-		j++;
-	      }
-	    else
-	      j++;
-	  }
-	if (strstr (command, "xfwm") != NULL)
-	  my_argv[i++] = "-s";
-	while (i < 10)
-	  my_argv[i++] = NULL;
-
-	/* really need to destroy all windows, explicitly,
-	 * not sleep, but this is adequate for now */
-	sleep (1);
-	ReapChildren ();
-	execvp (command, my_argv);
-      }
+      /* really need to destroy all windows, explicitly,
+       * not sleep, but this is adequate for now */
+      sleep (1);
+      ReapChildren ();
+      execvp (command, my_argv);
       xfwm_msg (ERR, "Done",
 		"Call of '%s' failed!!!! (restarting '%s' instead)", command,
 		g_argv[0]);
       execvp (g_argv[0], g_argv);	/* that _should_ work */
       xfwm_msg (ERR, "Done", "Call of '%s' failed!!!!", g_argv[0]);
+      /* We definitely should not get there ... */
+      XCloseDisplay (dpy);
+      exit (0);
     }
   else
     {
@@ -1857,7 +1964,8 @@ Done (int restart, char *command)
 static XErrorHandler
 CatchRedirectError (Display * dpy, XErrorEvent * event)
 {
-  xfwm_msg (ERR, "CatchRedirectError", "another WM is running");
+  fprintf (stderr, "Cannot start xfwm, another window manager is already ");
+  fprintf (stderr, "running on screen %s\n", getenv("DISPLAY"));
   exit (1);
 }
 
@@ -1945,10 +2053,11 @@ SaveDesktopState ()
       data[0] = (unsigned long) t->Desk;
       XChangeProperty (dpy, t->w, _XA_WM_DESKTOP, _XA_WM_DESKTOP, 32,
 		       PropModeReplace, (unsigned char *) data, 1);
+      t->flags |= RECAPTURE;
       data[0] =
 	(unsigned long) (t->flags &
 			 (STICKY | ICONIFIED | ICON_MOVED | SHADED |
-			  WM_NAME_CHANGED));
+			  WM_NAME_CHANGED | RECAPTURE));
       XChangeProperty (dpy, t->w, _XA_XFWM_FLAGS, _XA_XFWM_FLAGS, 32,
 		       PropModeReplace, (unsigned char *) data, 1);
       data[0] = (unsigned long) t->icon_x_loc;
@@ -2020,3 +2129,9 @@ UnBlackoutScreen ()
       BlackoutWin = None;
     }
 }				/* UnBlackoutScreen */
+
+void
+SetRunLevel (int level)
+{
+  runlevel = level;
+}
